(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    589099,      16171]
NotebookOptionsPosition[    568211,      15866]
NotebookOutlinePosition[    568549,      15881]
CellTagsIndexPosition[    568506,      15878]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
This Notebook contains the proofs of all the results in the paper
\"When Triangle Centers Lie Inside the Triangle\" by Stanley Rabinowitz,
submitted to the International Journal of Computer Discovered Mathematics 
(http : // www.journal - 1. eu/) on Dec. 2021.
 
This Notebook is Copyright \[Copyright] December 2021 by Stanley Rabinowitz \
(stan.rabinowitz@comcast.net) and is published with open access. This \
Notebook is distributed under the terms of the Creative Commons Attribution \
License which permits any use, distribution, and reproduction in any medium, \
provided the original author and the source are credited.\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.823362867312365*^9, 3.823362892123764*^9}, {
   3.823362940554699*^9, 3.823363012293025*^9}, {3.823423241988761*^9, 
   3.8234232521964083`*^9}, 3.8247296830582123`*^9, {3.829304183998571*^9, 
   3.829304184727605*^9}, {3.847010924219548*^9, 3.847011078875139*^9}, {
   3.847353790508037*^9, 3.847353817877302*^9}, {3.847472574619526*^9, 
   3.847472576443408*^9}},ExpressionUUID->"efc13449-d829-40e5-a520-\
40b6e62a69ca"],

Cell[CellGroupData[{

Cell["Barycentric Coordinates for Centers X1-X100", "Section",
 CellChangeTimes->{{3.824729704472291*^9, 
  3.8247297231587954`*^9}},ExpressionUUID->"ef755c8a-0e25-48d6-ac78-\
b33a61727a24"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ETC1", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"X1", ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X2", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X3", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X4", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X5", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "2"]}], " ", 
           SuperscriptBox["b", "2"]}], "+", 
          SuperscriptBox["b", "4"], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "2"]}], "+", 
          SuperscriptBox["c", "4"]}], ",", 
         RowBox[{
          SuperscriptBox["a", "4"], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "2"]}], "+", 
          SuperscriptBox["c", "4"]}], ",", 
         RowBox[{
          SuperscriptBox["a", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"]}], "+", 
          SuperscriptBox["b", "4"], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "2"]}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X6", ",", 
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["a", "2"], ",", 
         SuperscriptBox["b", "2"], ",", 
         SuperscriptBox["c", "2"]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X7", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X8", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "-", "b", "-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", "b", "-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "-", "b", "+", "c"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X9", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c"}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}]}]}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X10", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"b", "+", "c"}], ",", 
         RowBox[{"a", "+", "c"}], ",", 
         RowBox[{"a", "+", "b"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X11", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "-", "c"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "c"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "-", "b"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}]}]}], "}"}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"X12", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "+", "c"}], ")"}], "2"]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "+", "c"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X13", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"]}], ")"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"], "+", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}]}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "+", 
              SuperscriptBox["c", "2"]}], ")"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["c", "2"], "+", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              SuperscriptBox["b", "2"]}], ")"}], "2"]}], "+", 
          SuperscriptBox["c", "4"], "+", 
          RowBox[{
           SuperscriptBox["c", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"], "+", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}]}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X14", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"]}], ")"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"], "-", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}]}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "+", 
              SuperscriptBox["c", "2"]}], ")"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["c", "2"], "-", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              SuperscriptBox["b", "2"]}], ")"}], "2"]}], "+", 
          SuperscriptBox["c", "4"], "+", 
          RowBox[{
           SuperscriptBox["c", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"], "-", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}]}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X15", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["a", "2"], "-", 
               SuperscriptBox["b", "2"], "-", 
               SuperscriptBox["c", "2"]}], ")"}]}], "-", 
            RowBox[{"2", " ", "S"}]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["b", "2"], "-", 
               SuperscriptBox["c", "2"], "-", 
               SuperscriptBox["a", "2"]}], ")"}]}], "-", 
            RowBox[{"2", " ", "S"}]}], ")"}]}], "\[InvisibleSpace]", ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["c", "2"], "-", 
               SuperscriptBox["a", "2"], "-", 
               SuperscriptBox["b", "2"]}], ")"}]}], "-", 
            RowBox[{"2", " ", "S"}]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X16", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["a", "2"], "-", 
               SuperscriptBox["b", "2"], "-", 
               SuperscriptBox["c", "2"]}], ")"}]}], "+", 
            RowBox[{"2", " ", "S"}]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["b", "2"], "-", 
               SuperscriptBox["c", "2"], "-", 
               SuperscriptBox["a", "2"]}], ")"}]}], "+", 
            RowBox[{"2", " ", "S"}]}], ")"}]}], "\[InvisibleSpace]", ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["c", "2"], "-", 
               SuperscriptBox["a", "2"], "-", 
               SuperscriptBox["b", "2"]}], ")"}]}], "+", 
            RowBox[{"2", " ", "S"}]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X17", ",", 
       FormBox[
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"], "-", 
             SuperscriptBox["c", "2"], "+", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"], "+", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}]}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"], "-", 
             SuperscriptBox["c", "2"], "+", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], "+", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"], "+", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}]}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"], "+", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], "+", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"], "+", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}]}]}], "}"}],
        TraditionalForm]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X18", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], "S"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", "S"}]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", "S"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], "S"}]}], ")"}]}], "\[InvisibleSpace]", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", "S"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", "S"}]}], ")"}]}]}], "\[InvisibleSpace]", 
        "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X19", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X20", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["a", "4"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"]}], "-", 
          SuperscriptBox["b", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["c", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          SuperscriptBox["c", "4"]}], ",", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "4"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["b", "4"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          SuperscriptBox["c", "4"]}], ",", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "4"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"]}], "-", 
          SuperscriptBox["b", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "2"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["c", "4"]}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X21", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X22", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            SuperscriptBox["b", "4"], "-", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "-", 
            SuperscriptBox["b", "4"], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X23", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "4"], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X24", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X25", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X26", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "8"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "6"]}], "-", 
            SuperscriptBox["b", "8"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "6"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "4"], " ", 
             SuperscriptBox["c", "4"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "6"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "6"]}], "-", 
            SuperscriptBox["c", "8"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "8"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "6"]}], "+", 
            SuperscriptBox["b", "8"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "6"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "4"], " ", 
             SuperscriptBox["c", "4"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "6"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "6"]}], "-", 
            SuperscriptBox["c", "8"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "8"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "4"], " ", 
             SuperscriptBox["b", "4"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "6"]}], "-", 
            SuperscriptBox["b", "8"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "6"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "6"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "6"]}], "+", 
            SuperscriptBox["c", "8"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X27", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X28", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X29", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X30", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["a", "4"]}], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"]}], "-", 
          SuperscriptBox["b", "4"], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["c", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          SuperscriptBox["c", "4"]}], ",", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "4"]}], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "4"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          SuperscriptBox["c", "4"]}], ",", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "4"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"]}], "-", 
          SuperscriptBox["b", "4"], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["c", "4"]}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X31", ",", 
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["a", "3"], ",", 
         SuperscriptBox["b", "3"], ",", 
         SuperscriptBox["c", "3"]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X32", ",", 
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["a", "4"], ",", 
         SuperscriptBox["b", "4"], ",", 
         SuperscriptBox["c", "4"]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X33", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X34", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X35", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"b", " ", "c"}], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"a", " ", "c"}], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            RowBox[{"a", " ", "b"}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X36", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"b", " ", "c"}], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"a", " ", "c"}], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            RowBox[{"a", " ", "b"}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X37", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", "c"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X38", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"]}], ")"}], " ", "c"}]}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X39", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"]}], ")"}], " ", 
          SuperscriptBox["c", "2"]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X40", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "-", 
            RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "3"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "3"]}], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "-", 
            RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "3"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "3"]}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "-", 
            RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X41", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}]}]}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X42", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          SuperscriptBox["c", "2"]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X43", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", "b"}], "+", 
            RowBox[{"a", " ", "c"}], "-", 
            RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", "b"}], "-", 
            RowBox[{"a", " ", "c"}], "+", 
            RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "b"}], "+", 
            RowBox[{"a", " ", "c"}], "+", 
            RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X44", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "-", "b", "-", "c"}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", 
            RowBox[{"2", " ", "b"}], "-", "c"}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", 
            RowBox[{"2", " ", "c"}]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X45", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", 
            RowBox[{"2", " ", "b"}], "-", 
            RowBox[{"2", " ", "c"}]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "a"}], "+", "b", "-", 
            RowBox[{"2", " ", "c"}]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "a"}], "-", 
            RowBox[{"2", " ", "b"}], "+", "c"}], ")"}]}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"X46", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "3"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "3"]}], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "3"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "3"]}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X47", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X48", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X49", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X50", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"b", " ", "c"}], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"b", " ", "c"}], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"a", " ", "c"}], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"a", " ", "c"}], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            RowBox[{"a", " ", "b"}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            RowBox[{"a", " ", "b"}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X51", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X52", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X53", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X54", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X55", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}]}]}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X56", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X57", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X58", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X59", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "-", "b"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "c"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "-", "b"}], ")"}], "2"], " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "-", "c"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "-", "c"}], ")"}], "2"], " ", 
          SuperscriptBox["c", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "c"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X60", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "+", "c"}], ")"}], "2"]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "+", "c"}], ")"}], "2"]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "+", "c"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "+", "c"}], ")"}], "2"]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X61", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["a", "2"], " ", "S"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["b", "2"], " ", "S"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["c", "2"], " ", "S"}]}], ")"}]}], ",", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["a", "2"], " ", "S"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["b", "2"], " ", "S"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["c", "2"], " ", "S"}]}], ")"}]}], 
         "\[InvisibleSpace]", ",", 
         RowBox[{"2", " ", 
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["a", "2"], " ", "S"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["b", "2"], " ", "S"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["c", "2"], " ", "S"}]}], ")"}]}]}], 
        "\[InvisibleSpace]", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X62", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["a", "2"], " ", "S"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["b", "2"], " ", "S"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["c", "2"], " ", "S"}]}], ")"}]}], ",", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["a", "2"], " ", "S"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["b", "2"], " ", "S"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["c", "2"], " ", "S"}]}], ")"}]}], 
         "\[InvisibleSpace]", ",", "\[InvisibleSpace]", 
         RowBox[{"2", " ", 
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["a", "2"], " ", "S"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["b", "2"], " ", "S"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["c", "2"], " ", "S"}]}], ")"}]}]}], 
        "\[InvisibleSpace]", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X63", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X64", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["c", "4"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["b", "4"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["c", "4"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["b", "4"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X65", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X66", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            SuperscriptBox["b", "4"], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            SuperscriptBox["b", "4"], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X67", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X68", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X69", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          SuperscriptBox["b", "2"], "-", 
          SuperscriptBox["c", "2"]}], ",", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "+", 
          SuperscriptBox["b", "2"], "-", 
          SuperscriptBox["c", "2"]}], ",", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "-", 
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox["c", "2"]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X70", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "8"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "4"], " ", 
             SuperscriptBox["b", "4"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "6"]}], "+", 
            SuperscriptBox["b", "8"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "6"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "6"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "6"]}], "-", 
            SuperscriptBox["c", "8"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "8"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "6"]}], "-", 
            SuperscriptBox["b", "8"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "6"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "4"], " ", 
             SuperscriptBox["c", "4"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "6"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "6"]}], "+", 
            SuperscriptBox["c", "8"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "8"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "4"], " ", 
             SuperscriptBox["b", "4"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "6"]}], "+", 
            SuperscriptBox["b", "8"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "6"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "6"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "6"]}], "-", 
            SuperscriptBox["c", "8"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "8"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "6"]}], "+", 
            SuperscriptBox["b", "8"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "6"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "4"], " ", 
             SuperscriptBox["c", "4"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "6"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "6"]}], "+", 
            SuperscriptBox["c", "8"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "8"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "6"]}], "-", 
            SuperscriptBox["b", "8"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "6"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "4"], " ", 
             SuperscriptBox["c", "4"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "6"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "6"]}], "+", 
            SuperscriptBox["c", "8"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "8"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "6"]}], "+", 
            SuperscriptBox["b", "8"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "6"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "4"], " ", 
             SuperscriptBox["c", "4"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "6"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "6"]}], "+", 
            SuperscriptBox["c", "8"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X71", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X72", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X73", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X74", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["c", "4"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "4"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["c", "4"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "4"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X75", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"b", " ", "c"}], ",", 
         RowBox[{"a", " ", "c"}], ",", 
         RowBox[{"a", " ", "b"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X76", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "2"]}], ",", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["c", "2"]}], ",", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X77", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X78", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X79", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            RowBox[{"a", " ", "b"}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"a", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            RowBox[{"a", " ", "b"}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"b", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"a", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"b", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X80", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            RowBox[{"a", " ", "b"}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"a", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            RowBox[{"a", " ", "b"}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"b", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"a", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"b", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X81", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X82", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X83", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X84", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "3"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "3"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "3"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "3"]}], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "3"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "3"]}], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "3"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X85", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{"a", " ", "b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}]}]}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X86", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X87", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", "b"}], "-", 
            RowBox[{"a", " ", "c"}], "-", 
            RowBox[{"b", " ", "c"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "b"}], "+", 
            RowBox[{"a", " ", "c"}], "-", 
            RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", "b"}], "-", 
            RowBox[{"a", " ", "c"}], "-", 
            RowBox[{"b", " ", "c"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "b"}], "-", 
            RowBox[{"a", " ", "c"}], "+", 
            RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "b"}], "+", 
            RowBox[{"a", " ", "c"}], "-", 
            RowBox[{"b", " ", "c"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "b"}], "-", 
            RowBox[{"a", " ", "c"}], "+", 
            RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X88", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", 
            RowBox[{"2", " ", "c"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", 
            RowBox[{"2", " ", "b"}], "+", "c"}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", 
            RowBox[{"2", " ", "c"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}], ")"}]}], 
         ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", 
            RowBox[{"2", " ", "b"}], "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}], ")"}]}]}], 
        "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X89", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "+", 
            RowBox[{"2", " ", "b"}], "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "-", "b", "+", 
            RowBox[{"2", " ", "c"}]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "+", 
            RowBox[{"2", " ", "b"}], "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", 
            RowBox[{"2", " ", "b"}], "+", 
            RowBox[{"2", " ", "c"}]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "-", "b", "+", 
            RowBox[{"2", " ", "c"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", 
            RowBox[{"2", " ", "b"}], "+", 
            RowBox[{"2", " ", "c"}]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X90", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "3"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "3"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "3"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "3"]}], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "3"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "3"]}], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "3"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X91", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"b", " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{"a", " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{"a", " ", "b", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X92", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"b", " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"a", " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"a", " ", "b", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X93", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X94", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            RowBox[{"a", " ", "b"}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            RowBox[{"a", " ", "b"}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"a", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"a", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            RowBox[{"a", " ", "b"}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            RowBox[{"a", " ", "b"}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"b", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"b", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"a", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"a", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"b", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"b", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X95", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X96", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X97", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X98", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X99", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "-", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "-", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X100", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "-", "b"}], ")"}], " ", "b", " ", 
          RowBox[{"(", 
           RowBox[{"b", "-", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"b", "-", "c"}], ")"}], " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "c"}], ")"}]}]}], "}"}]}], "}"}]}], 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8243788225371437`*^9, 3.824378825377088*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"fbc3a809-de22-4d8c-9ba8-10a1a9fbf15d"]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Section",
 CellChangeTimes->{{3.824729768409182*^9, 
  3.8247297787826977`*^9}},ExpressionUUID->"9f10404a-060d-4023-b1ed-\
cb0e490194b3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "100"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "i", "]"}], "=", 
       RowBox[{"ETC1", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "2"}], "]"}], "]"}]}], ";"}]}], 
    "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Function", " ", "to", " ", "find", " ", "the", " ", "distance", " ", 
    "between", " ", "two", " ", "points", " ", "given", " ", "in", " ", 
    "Barycentric", " ", "coordinates"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"normed", "[", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}], "/", 
    RowBox[{"(", 
     RowBox[{"x", "+", "y", "+", "z"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"squaredDistance", "[", 
    RowBox[{"p1_", ",", "p2_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Total", "[", "p2", "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{"Return", "[", "Infinity", "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}], "=", 
       RowBox[{
        RowBox[{"normed", "[", "p1", "]"}], "-", 
        RowBox[{"normed", "[", "p2", "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Return", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "^", "2"}]}], "*", "y", "*", "z"}], "-", 
        RowBox[{
         RowBox[{"b", "^", "2"}], "*", "z", "*", "x"}], "-", 
        RowBox[{
         RowBox[{"c", "^", "2"}], "*", "x", "*", "y"}]}], "]"}], ";"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.82446823405422*^9, 3.824468238813963*^9}, {
   3.824639364376914*^9, 3.824639366254614*^9}, {3.824639489697496*^9, 
   3.824639501047118*^9}, {3.824730489171135*^9, 3.824730550273574*^9}, 
   3.829305063612216*^9, {3.829305236004871*^9, 3.829305240731523*^9}, {
   3.847472611253355*^9, 3.8474726126522408`*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"302b605f-5435-4cad-ab15-5f5d143d5473"]
}, Closed]],

Cell[CellGroupData[{

Cell["Centers Inside/Outside Triangle", "Section",
 CellChangeTimes->{{3.824729812416472*^9, 3.824729830635277*^9}, {
  3.82472987891963*^9, 3.824729880399238*^9}, {3.824729921591786*^9, 
  3.824729944583457*^9}, {3.824730183592462*^9, 3.824730194584065*^9}, {
  3.824815791230557*^9, 
  3.824815814654079*^9}},ExpressionUUID->"53670d4d-5e61-49f3-9240-\
35a20dac235d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "centers", " ", "that", " ", "must", " ", "lie", " ", 
    "strictly", " ", "inside", " ", "the", " ", "triangle"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"insideTriangle", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "100"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "[", "i", "]"}], "/.", 
          RowBox[{"S", "\[Rule]", 
           RowBox[{"2", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"s", 
              RowBox[{"(", 
               RowBox[{"s", "-", "a"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"s", "-", "b"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
         RowBox[{"s", "\[Rule]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"triang", "=", 
        RowBox[{
         RowBox[{"a", ">", "0"}], "&&", 
         RowBox[{"b", ">", "0"}], "&&", 
         RowBox[{"c", ">", "0"}], "&&", 
         RowBox[{
          RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
         RowBox[{
          RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
         RowBox[{
          RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"inst", "=", 
        RowBox[{"FindInstance", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"u", "*", "v"}], "\[LessEqual]", "0"}], "||", 
             RowBox[{
              RowBox[{"v", "*", "w"}], "\[LessEqual]", "0"}], "||", 
             RowBox[{
              RowBox[{"w", "*", "u"}], "\[LessEqual]", "0"}]}], ")"}], "&&", 
           "triang", "&&", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"u", ",", "v", ",", "w"}], "}"}], "\[NotEqual]", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"inst", "\[Equal]", 
          RowBox[{"{", "}"}]}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"insideTriangle", ",", "i"}], "]"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Inside: \>\"", ",", "insideTriangle"}], "]"}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.824818792568433*^9, 3.824818813080359*^9}, {
   3.82481925065005*^9, 3.82481927608951*^9}, {3.847368760175802*^9, 
   3.8473687625746326`*^9}, 3.847463703024087*^9},
 CellLabel->"In[5]:=",ExpressionUUID->"4ff0d522-c877-4f89-9f20-38d2b2f09705"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Inside: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "6", ",", "7", ",", "8", ",", "9", ",", "10", ",", 
     "12", ",", "21", ",", "31", ",", "32", ",", "37", ",", "38", ",", "39", 
     ",", "41", ",", "42", ",", "45", ",", "55", ",", "56", ",", "57", ",", 
     "58", ",", "60", ",", "65", ",", "75", ",", "76", ",", "81", ",", "82", 
     ",", "83", ",", "85", ",", "86", ",", "89"}], "}"}]}],
  SequenceForm[
  "Inside: ", {1, 2, 6, 7, 8, 9, 10, 12, 21, 31, 32, 37, 38, 39, 41, 42, 45, 
   55, 56, 57, 58, 60, 65, 75, 76, 81, 82, 83, 85, 86, 89}],
  Editable->False]], "Print",
 CellChangeTimes->{3.8248192844266043`*^9, 3.847181782207224*^9, 
  3.8473573143127623`*^9, 3.847429593031516*^9, 3.847455106185326*^9, 
  3.847463708236808*^9, 3.847472838634944*^9},
 CellLabel->
  "During evaluation of \
In[5]:=",ExpressionUUID->"29d2bbd5-a07d-4124-bb47-dd133a7f120f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "centers", " ", "that", " ", "must", " ", "lie", " ", 
    "inside", " ", "or", " ", "on", " ", "the", " ", "triangle"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"insideOrOnTriangle", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "100"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "[", "i", "]"}], "/.", 
          RowBox[{"S", "\[Rule]", 
           RowBox[{"2", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"s", 
              RowBox[{"(", 
               RowBox[{"s", "-", "a"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"s", "-", "b"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
         RowBox[{"s", "\[Rule]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"triang", "=", 
        RowBox[{
         RowBox[{"a", ">", "0"}], "&&", 
         RowBox[{"b", ">", "0"}], "&&", 
         RowBox[{"c", ">", "0"}], "&&", 
         RowBox[{
          RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
         RowBox[{
          RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
         RowBox[{
          RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"inst", "=", 
        RowBox[{"FindInstance", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"u", "*", "v"}], "<", "0"}], "||", 
             RowBox[{
              RowBox[{"v", "*", "w"}], "<", "0"}], "||", 
             RowBox[{
              RowBox[{"w", "*", "u"}], "<", "0"}]}], ")"}], "&&", "triang"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"inst", "\[Equal]", 
          RowBox[{"{", "}"}]}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"insideOrOnTriangle", ",", "i"}], "]"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Inside or on: \>\"", ",", "insideOrOnTriangle"}], "]"}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.824817927221381*^9, 3.824817964461843*^9}, {
  3.824818125279163*^9, 3.824818125790278*^9}, {3.824818159534236*^9, 
  3.824818183206259*^9}, {3.82481830376898*^9, 3.824818323440798*^9}, {
  3.8248183766004057`*^9, 3.824818378430915*^9}, {3.824819465106736*^9, 
  3.824819514146171*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"eb9c273e-ce75-4348-953f-f3faff2723f5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Inside or on: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "6", ",", "7", ",", "8", ",", "9", ",", "10", ",", 
     "11", ",", "12", ",", "21", ",", "31", ",", "32", ",", "37", ",", "38", 
     ",", "39", ",", "41", ",", "42", ",", "45", ",", "55", ",", "56", ",", 
     "57", ",", "58", ",", "59", ",", "60", ",", "65", ",", "75", ",", "76", 
     ",", "81", ",", "82", ",", "83", ",", "85", ",", "86", ",", "89"}], 
    "}"}]}],
  SequenceForm[
  "Inside or on: ", {1, 2, 6, 7, 8, 9, 10, 11, 12, 21, 31, 32, 37, 38, 39, 41,
    42, 45, 55, 56, 57, 58, 59, 60, 65, 75, 76, 81, 82, 83, 85, 86, 89}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8248181954138527`*^9, {3.824818317655662*^9, 3.8248183244127493`*^9}, 
   3.8248183792354794`*^9, {3.824819501708647*^9, 3.824819516678465*^9}, 
   3.847181788583066*^9, 3.847357359959268*^9, 3.847369141024056*^9, 
   3.8474295944613256`*^9, 3.8474551076862087`*^9, 3.847472840094757*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"3d9ba66a-73c3-49c2-84c2-7ec3efcd8d3a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "centers", " ", "that", " ", "must", " ", "lie", " ", 
    "outside", " ", "or", " ", "on", " ", "the", " ", "triangle"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"outsideOrOnTriangle", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "100"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "[", "i", "]"}], "/.", 
          RowBox[{"S", "\[Rule]", 
           RowBox[{"2", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"s", 
              RowBox[{"(", 
               RowBox[{"s", "-", "a"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"s", "-", "b"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
         RowBox[{"s", "\[Rule]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"triang", "=", 
        RowBox[{
         RowBox[{"a", ">", "0"}], "&&", 
         RowBox[{"b", ">", "0"}], "&&", 
         RowBox[{"c", ">", "0"}], "&&", 
         RowBox[{
          RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
         RowBox[{
          RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
         RowBox[{
          RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"inst", "=", 
        RowBox[{"FindInstance", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"u", ">", "0"}], "&&", 
               RowBox[{"v", ">", "0"}], "&&", 
               RowBox[{"w", ">", "0"}]}], ")"}], "||", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"u", "<", "0"}], "&&", 
               RowBox[{"v", "<", "0"}], "&&", 
               RowBox[{"w", "<", "0"}]}], ")"}]}], ")"}], "&&", "triang"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"inst", "\[Equal]", 
          RowBox[{"{", "}"}]}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"outsideOrOnTriangle", ",", "i"}], "]"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Outside or on: \>\"", ",", "outsideOrOnTriangle"}], "]"}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.824816521953588*^9, 3.824816590617114*^9}, {
   3.824816664139619*^9, 3.824816665921824*^9}, 3.8248168107305593`*^9, {
   3.82481709556339*^9, 3.824817149186946*^9}, {3.824817782822356*^9, 
   3.824817792144402*^9}, {3.847367574644258*^9, 3.847367590242766*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"45a2478b-55f7-4a40-a39c-59b95e08b00b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Outside or on: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "14", ",", "16", ",", "23", ",", "30", ",", "36", ",", "44", ",", "67", 
     ",", "74", ",", "80", ",", "88", ",", "98", ",", "99", ",", "100"}], 
    "}"}]}],
  SequenceForm[
  "Outside or on: ", {14, 16, 23, 30, 36, 44, 67, 74, 80, 88, 98, 99, 100}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824816572502006*^9, 3.82481659152953*^9}, 
   3.824816666940893*^9, {3.824817127394652*^9, 3.824817154257947*^9}, 
   3.824817797846272*^9, 3.8471817860127687`*^9, 3.847357324933978*^9, 
   3.8473670540430307`*^9, 3.847367597878066*^9, 3.847429598191622*^9, 
   3.8474551115155478`*^9, 3.847472843860115*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"8c3c6426-9f59-4b1b-827b-3089deee49e7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "centers", " ", "that", " ", "must", " ", "lie", " ", 
    "strictly", " ", "outside", " ", "the", " ", "triangle"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"outsideTriangle", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "100"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "[", "i", "]"}], "/.", 
          RowBox[{"S", "\[Rule]", 
           RowBox[{"2", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"s", 
              RowBox[{"(", 
               RowBox[{"s", "-", "a"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"s", "-", "b"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
         RowBox[{"s", "\[Rule]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"triang", "=", 
        RowBox[{
         RowBox[{"a", ">", "0"}], "&&", 
         RowBox[{"b", ">", "0"}], "&&", 
         RowBox[{"c", ">", "0"}], "&&", 
         RowBox[{
          RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
         RowBox[{
          RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
         RowBox[{
          RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"inst", "=", 
        RowBox[{"FindInstance", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"u", ">=", "0"}], "&&", 
               RowBox[{"v", ">=", "0"}], "&&", 
               RowBox[{"w", ">=", "0"}]}], ")"}], "||", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"u", "<=", "0"}], "&&", 
               RowBox[{"v", "<=", "0"}], "&&", 
               RowBox[{"w", "<=", "0"}]}], ")"}]}], ")"}], "&&", "triang", "&&", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"u", ",", "v", ",", "w"}], "}"}], "\[NotEqual]", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"inst", "\[Equal]", 
          RowBox[{"{", "}"}]}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"outsideTriangle", ",", "i"}], "]"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Outside: \>\"", ",", "outsideTriangle"}], "]"}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.824816521953588*^9, 3.824816590617114*^9}, {
   3.824816664139619*^9, 3.824816665921824*^9}, 3.8248168107305593`*^9, {
   3.82481709556339*^9, 3.824817149186946*^9}, {3.824817782822356*^9, 
   3.824817792144402*^9}, {3.847367574644258*^9, 3.847367590242766*^9}, {
   3.847367631596344*^9, 3.847367648059429*^9}, {3.847367680525478*^9, 
   3.8473676891880827`*^9}, {3.847369186721343*^9, 3.847369189432329*^9}, {
   3.847369538577456*^9, 3.8473695596516943`*^9}, {3.847463343143035*^9, 
   3.8474633560058317`*^9}, {3.847463524599065*^9, 3.84746353110146*^9}, {
   3.84746357288665*^9, 3.847463601174201*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"1104a228-c2a2-4394-bb1b-fdd7cd05016f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Outside: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"16", ",", "23", ",", "30", ",", "36", ",", "44"}], "}"}]}],
  SequenceForm["Outside: ", {16, 23, 30, 36, 44}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824816572502006*^9, 3.82481659152953*^9}, 
   3.824816666940893*^9, {3.824817127394652*^9, 3.824817154257947*^9}, 
   3.824817797846272*^9, 3.8471817860127687`*^9, 3.847357324933978*^9, 
   3.8473670540430307`*^9, 3.847367597878066*^9, 3.847367653270376*^9, 
   3.847367693579657*^9, 3.8473692120954027`*^9, 3.8473695737762747`*^9, 
   3.847429606975235*^9, 3.847455120545223*^9, {3.847463517984132*^9, 
   3.847463535274633*^9}, 3.847463611755208*^9, 3.847472850110224*^9},
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"f46968ab-9752-4957-9bed-dab74fa9adde"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\"\<Outside: \>\"", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "14", ",", "16", ",", "23", ",", "30", ",", "36", ",", "44", ",", "67", 
     ",", "74", ",", "80", ",", "88", ",", "98", ",", "99", ",", "100"}], 
    "}"}]}],
  SequenceForm[
  "Outside: ", {14, 16, 23, 30, 36, 44, 67, 74, 80, 88, 98, 99, 100}],
  Editable->False]], "Input",
 CellLabel->"In[17]:=",ExpressionUUID->"b38dea24-40ed-4f46-9016-2c99621e3321"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Outside: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "14", ",", "16", ",", "23", ",", "30", ",", "36", ",", "44", ",", "67", 
     ",", "74", ",", "80", ",", "88", ",", "98", ",", "99", ",", "100"}], 
    "}"}]}],
  SequenceForm[
  "Outside: ", {14, 16, 23, 30, 36, 44, 67, 74, 80, 88, 98, 99, 100}],
  Editable->False]], "Output",
 CellChangeTimes->{3.847472850165269*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"9ced83f1-d4e5-49bd-93a4-904dd252311e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "centers", " ", "that", " ", "must", " ", "lie", " ", "on", 
    " ", "the", " ", "perimeter", " ", "of", " ", "the", " ", "triangle"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"onList", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "100"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "[", "i", "]"}], "/.", 
          RowBox[{"S", "\[Rule]", 
           RowBox[{"2", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"s", 
              RowBox[{"(", 
               RowBox[{"s", "-", "a"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"s", "-", "b"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
         RowBox[{"s", "\[Rule]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"triang", "=", 
        RowBox[{
         RowBox[{"a", ">", "0"}], "&&", 
         RowBox[{"b", ">", "0"}], "&&", 
         RowBox[{"c", ">", "0"}], "&&", 
         RowBox[{
          RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
         RowBox[{
          RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
         RowBox[{
          RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"inst", "=", 
        RowBox[{"FindInstance", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"u", "\[NotEqual]", "0"}], "&&", 
           RowBox[{"v", "\[NotEqual]", "0"}], "&&", 
           RowBox[{"w", "\[NotEqual]", "0"}], "&&", "triang"}], ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"inst", "\[Equal]", 
          RowBox[{"{", "}"}]}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"onList", ",", "i"}], "]"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<On: \>\"", ",", "onList"}], "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.824817335499839*^9, 3.8248173549312983`*^9}, {
  3.824817386196165*^9, 3.824817423419971*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"169434d7-af20-4ebf-ad60-7a53cc156552"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"On: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["On: ", {}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824817410448738*^9, 3.824817425657366*^9}, 
   3.847181787110611*^9, 3.8473573361752567`*^9, 3.8474296080790787`*^9, 
   3.8474551216939983`*^9, 3.847472851226801*^9},
 CellLabel->
  "During evaluation of \
In[18]:=",ExpressionUUID->"c78b2416-67f8-4e47-9ad0-1b99f0c5c5b2"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Conditions for center to be inside the triangle", "Section",
 CellChangeTimes->{{3.824729812416472*^9, 3.824729830635277*^9}, {
  3.82472987891963*^9, 3.824729880399238*^9}, {3.824729921591786*^9, 
  3.824729944583457*^9}, {3.824730183592462*^9, 3.824730194584065*^9}, {
  3.824815791230557*^9, 3.824815814654079*^9}, {3.8473711983486757`*^9, 
  3.847371208228066*^9}},ExpressionUUID->"31951922-4886-4bc8-80b6-\
3f2ea321db67"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], "/.", 
     RowBox[{"S", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"s", 
         RowBox[{"(", 
          RowBox[{"s", "-", "a"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "b"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"triang", "=", 
   RowBox[{
    RowBox[{"a", ">", "0"}], "&&", 
    RowBox[{"b", ">", "0"}], "&&", 
    RowBox[{"c", ">", "0"}], "&&", 
    RowBox[{
     RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
    RowBox[{
     RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
    RowBox[{
     RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"u", ">=", "0"}], "&&", 
        RowBox[{"v", ">=", "0"}], "&&", 
        RowBox[{"w", ">=", "0"}]}], ")"}], "||", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"u", "<=", "0"}], "&&", 
        RowBox[{"v", "<=", "0"}], "&&", 
        RowBox[{"w", "<=", "0"}]}], ")"}]}], ")"}], "&&", "triang", "&&", 
    RowBox[{"a", ">", "b"}], "&&", 
    RowBox[{"a", ">", "c"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.847371250869623*^9, 3.847371317389648*^9}, {
  3.847371351958679*^9, 3.847371419502243*^9}, {3.847373041741787*^9, 
  3.847373087644783*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"f109f0ec-c583-430f-8fc7-45995182aa3f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", ">", "0"}], "&&", 
  RowBox[{"0", "<", "b", "<", "a"}], "&&", 
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox["a", "2"], "-", 
     SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c", "<", "a"}]}]], "Output",\

 CellChangeTimes->{
  3.847371422213717*^9, {3.8473730711840353`*^9, 3.847373089317464*^9}, 
   3.8474296083158417`*^9, 3.847455121907805*^9, 3.847472851451857*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"5f3db211-213c-42e7-8c18-237fbd04026c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "4", "]"}], "/.", 
     RowBox[{"S", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"s", 
         RowBox[{"(", 
          RowBox[{"s", "-", "a"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "b"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"triang", "=", 
   RowBox[{
    RowBox[{"a", ">", "0"}], "&&", 
    RowBox[{"b", ">", "0"}], "&&", 
    RowBox[{"c", ">", "0"}], "&&", 
    RowBox[{
     RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
    RowBox[{
     RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
    RowBox[{
     RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"u", ">=", "0"}], "&&", 
        RowBox[{"v", ">=", "0"}], "&&", 
        RowBox[{"w", ">=", "0"}]}], ")"}], "||", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"u", "<=", "0"}], "&&", 
        RowBox[{"v", "<=", "0"}], "&&", 
        RowBox[{"w", "<=", "0"}]}], ")"}]}], ")"}], "&&", "triang", "&&", 
    RowBox[{"a", ">", "b"}], "&&", 
    RowBox[{"a", ">", "c"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{3.8473731033646393`*^9},
 CellLabel->"In[24]:=",ExpressionUUID->"46610b6c-e87e-4ef3-b836-a878f084f2a4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", ">", "0"}], "&&", 
  RowBox[{"0", "<", "b", "<", "a"}], "&&", 
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox["a", "2"], "-", 
     SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c", "<", "a"}]}]], "Output",\

 CellChangeTimes->{3.8473731040051003`*^9, 3.847429608357727*^9, 
  3.847455121958023*^9, 3.847472851494228*^9},
 CellLabel->"Out[26]=",ExpressionUUID->"80b0cf67-6723-465f-8e79-d8bb06109129"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "5", "]"}], "/.", 
     RowBox[{"S", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"s", 
         RowBox[{"(", 
          RowBox[{"s", "-", "a"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "b"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"triang", "=", 
   RowBox[{
    RowBox[{"a", ">", "0"}], "&&", 
    RowBox[{"b", ">", "0"}], "&&", 
    RowBox[{"c", ">", "0"}], "&&", 
    RowBox[{
     RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
    RowBox[{
     RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
    RowBox[{
     RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Reduce", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"u", ">=", "0"}], "&&", 
          RowBox[{"v", ">=", "0"}], "&&", 
          RowBox[{"w", ">=", "0"}]}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"u", "<=", "0"}], "&&", 
          RowBox[{"v", "<=", "0"}], "&&", 
          RowBox[{"w", "<=", "0"}]}], ")"}]}], ")"}], "&&", "triang", "&&", 
      RowBox[{"a", ">", "b"}], "&&", 
      RowBox[{"a", ">", "c"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}], "//", 
   "PowerExpand"}], "//", "Factor"}]}], "Input",
 CellChangeTimes->{{3.847373128220627*^9, 3.84737316392423*^9}, {
  3.84737319992467*^9, 3.847373236611277*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"b138b86c-4bc2-4fed-9710-f76c290c993d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", ">", "0"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"0", "<", "b", "\[LessEqual]", 
       FractionBox["a", 
        SqrtBox["3"]]}], "&&", 
      RowBox[{
       FractionBox[
        SqrtBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"]}], ")"}], "2"]], 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["b", "2"]}]]], "\[LessEqual]", "c", "<", "a"}]}], 
     ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["a", 
        SqrtBox["3"]], "<", "b", "<", "a"}], "&&", 
      RowBox[{
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              SuperscriptBox["b", "2"]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
       "\[LessEqual]", "c", "<", "a"}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.8473731289546337`*^9, 3.847373165202767*^9}, {
   3.847373201009035*^9, 3.8473732375191593`*^9}, 3.8474296084129143`*^9, 
   3.847455122048918*^9, 3.847472851541709*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"2d264aee-3038-458f-ae1b-3481c29a5263"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "13", "]"}], "/.", 
     RowBox[{"S", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"s", 
         RowBox[{"(", 
          RowBox[{"s", "-", "a"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "b"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"triang", "=", 
   RowBox[{
    RowBox[{"a", ">", "0"}], "&&", 
    RowBox[{"b", ">", "0"}], "&&", 
    RowBox[{"c", ">", "0"}], "&&", 
    RowBox[{
     RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
    RowBox[{
     RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
    RowBox[{
     RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"u", ">=", "0"}], "&&", 
        RowBox[{"v", ">=", "0"}], "&&", 
        RowBox[{"w", ">=", "0"}]}], ")"}], "||", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"u", "<=", "0"}], "&&", 
        RowBox[{"v", "<=", "0"}], "&&", 
        RowBox[{"w", "<=", "0"}]}], ")"}]}], ")"}], "&&", "triang", "&&", 
    RowBox[{"a", ">", "b"}], "&&", 
    RowBox[{"a", ">", "c"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.847373283908373*^9, 3.847373303244184*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"cfaccd4b-a69c-4635-b330-623f574121fd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", ">", "0"}], "&&", 
  RowBox[{"0", "<", "b", "<", "a"}], "&&", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["b", "2"]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox["a", "2"]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["b", "2"]}]}]]}]}], "\[LessEqual]", "c", "<", 
   "a"}]}]], "Output",
 CellChangeTimes->{3.847373304645832*^9, 3.847429608480466*^9, 
  3.8474551221494427`*^9, 3.8474728516126966`*^9},
 CellLabel->"Out[32]=",ExpressionUUID->"f37896d2-cc6a-478d-908d-d632fe60d985"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "14", "]"}], "/.", 
     RowBox[{"S", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"s", 
         RowBox[{"(", 
          RowBox[{"s", "-", "a"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "b"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"triang", "=", 
   RowBox[{
    RowBox[{"a", ">", "0"}], "&&", 
    RowBox[{"b", ">", "0"}], "&&", 
    RowBox[{"c", ">", "0"}], "&&", 
    RowBox[{
     RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
    RowBox[{
     RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
    RowBox[{
     RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Reduce", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", ">=", "0"}], "&&", 
         RowBox[{"v", ">=", "0"}], "&&", 
         RowBox[{"w", ">=", "0"}]}], ")"}], "||", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", "<=", "0"}], "&&", 
         RowBox[{"v", "<=", "0"}], "&&", 
         RowBox[{"w", "<=", "0"}]}], ")"}]}], ")"}], "&&", "triang", "&&", 
     RowBox[{"a", ">", "b"}], "&&", 
     RowBox[{"a", ">", "c"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.847373341596416*^9, 3.847373354307529*^9}, {
  3.847373439989584*^9, 3.847373441115858*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"598c4e9a-257b-4c80-b541-c3a16059e478"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", ">", "0"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "\[Equal]", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           RowBox[{"a", " ", "b"}], "+", 
           SuperscriptBox["b", "2"]}]], "\[Equal]", "c"}], "||", 
        RowBox[{
         RowBox[{
          SqrtBox[
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox["a", "2"]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["b", "2"]}]}]], "+", 
          RowBox[{"2", " ", "c"}]}], "\[Equal]", "a"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         RowBox[{"a", " ", "b"}], "+", 
         SuperscriptBox["b", "2"]}]], "\[Equal]", "c"}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", ">", "b"}], "&&", 
          RowBox[{
           RowBox[{
            SqrtBox["3"], " ", "a"}], "<", 
           RowBox[{"2", " ", "b"}]}]}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SqrtBox["3"], " ", "a"}], ">", 
           RowBox[{"2", " ", "b"}]}], "&&", 
          RowBox[{"b", ">", "0"}]}], ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", ">", "b"}], "&&", 
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "<", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "+", 
          SqrtBox[
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox["a", "2"]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["b", "2"]}]}]]}], "\[Equal]", 
         RowBox[{"2", " ", "c"}]}], "||", 
        RowBox[{
         RowBox[{
          SqrtBox[
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox["a", "2"]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["b", "2"]}]}]], "+", 
          RowBox[{"2", " ", "c"}]}], "\[Equal]", "a"}]}], ")"}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.847373343105687*^9, 3.847373355516148*^9}, 
   3.8473734427826233`*^9, 3.847429608968561*^9, 3.8474551226714067`*^9, 
   3.847472852096278*^9},
 CellLabel->"Out[35]=",ExpressionUUID->"f72de78e-265c-4953-8db6-895c98ad5868"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "15", "]"}], "/.", 
     RowBox[{"S", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"s", 
         RowBox[{"(", 
          RowBox[{"s", "-", "a"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "b"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"triang", "=", 
   RowBox[{
    RowBox[{"a", ">", "0"}], "&&", 
    RowBox[{"b", ">", "0"}], "&&", 
    RowBox[{"c", ">", "0"}], "&&", 
    RowBox[{
     RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
    RowBox[{
     RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
    RowBox[{
     RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Reduce", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", ">=", "0"}], "&&", 
         RowBox[{"v", ">=", "0"}], "&&", 
         RowBox[{"w", ">=", "0"}]}], ")"}], "||", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", "<=", "0"}], "&&", 
         RowBox[{"v", "<=", "0"}], "&&", 
         RowBox[{"w", "<=", "0"}]}], ")"}]}], ")"}], "&&", "triang", "&&", 
     RowBox[{"a", ">", "b"}], "&&", 
     RowBox[{"a", ">", "c"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{3.847373384644788*^9},
 CellLabel->"In[36]:=",ExpressionUUID->"f95975d6-3ac8-4c4e-9c78-851a834482ad"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", ">", "0"}], "&&", 
  RowBox[{"0", "<", "b", "<", "a"}], "&&", 
  RowBox[{
   SqrtBox[
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["a", "2"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["b", "2"]}]}]], "\[LessEqual]", 
   RowBox[{"b", "+", 
    RowBox[{"2", " ", "c"}]}]}], "&&", 
  RowBox[{"a", ">", "c"}]}]], "Output",
 CellChangeTimes->{3.84737338520004*^9, 3.8474296090295773`*^9, 
  3.847455122761875*^9, 3.8474728521593933`*^9},
 CellLabel->"Out[38]=",ExpressionUUID->"c9528949-71ae-4b23-b66d-a8c9126ea74b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "16", "]"}], "/.", 
     RowBox[{"S", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"s", 
         RowBox[{"(", 
          RowBox[{"s", "-", "a"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "b"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"triang", "=", 
   RowBox[{
    RowBox[{"a", ">", "0"}], "&&", 
    RowBox[{"b", ">", "0"}], "&&", 
    RowBox[{"c", ">", "0"}], "&&", 
    RowBox[{
     RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
    RowBox[{
     RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
    RowBox[{
     RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Reduce", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", ">=", "0"}], "&&", 
         RowBox[{"v", ">=", "0"}], "&&", 
         RowBox[{"w", ">=", "0"}]}], ")"}], "||", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", "<=", "0"}], "&&", 
         RowBox[{"v", "<=", "0"}], "&&", 
         RowBox[{"w", "<=", "0"}]}], ")"}]}], ")"}], "&&", "triang", "&&", 
     RowBox[{"a", ">", "b"}], "&&", 
     RowBox[{"a", ">", "c"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{3.8473734062609663`*^9},
 CellLabel->"In[39]:=",ExpressionUUID->"98714d28-7377-40f7-9611-fc7ccfcd09c4"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{3.8473734070739737`*^9, 3.847429609079047*^9, 
  3.8474551229196043`*^9, 3.847472852238183*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"5373adef-942d-4a53-ba3c-0372ef414f0f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "17", "]"}], "/.", 
     RowBox[{"S", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"s", 
         RowBox[{"(", 
          RowBox[{"s", "-", "a"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "b"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"triang", "=", 
   RowBox[{
    RowBox[{"a", ">", "0"}], "&&", 
    RowBox[{"b", ">", "0"}], "&&", 
    RowBox[{"c", ">", "0"}], "&&", 
    RowBox[{
     RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
    RowBox[{
     RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
    RowBox[{
     RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Reduce", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", ">=", "0"}], "&&", 
         RowBox[{"v", ">=", "0"}], "&&", 
         RowBox[{"w", ">=", "0"}]}], ")"}], "||", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", "<=", "0"}], "&&", 
         RowBox[{"v", "<=", "0"}], "&&", 
         RowBox[{"w", "<=", "0"}]}], ")"}]}], ")"}], "&&", "triang", "&&", 
     RowBox[{"a", ">", "b"}], "&&", 
     RowBox[{"a", ">", "c"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{3.847373490717084*^9},
 CellLabel->"In[42]:=",ExpressionUUID->"1764d3ac-2521-4e6b-9b83-a25f25526020"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", ">", "0"}], "&&", 
  RowBox[{"0", "<", "b", "<", "a"}], "&&", 
  RowBox[{
   RowBox[{"Root", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "4"], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"]}], "+", 
       SuperscriptBox["b", "4"], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["a", "2"]}], "-", 
          SuperscriptBox["b", "2"]}], ")"}], " ", 
        SuperscriptBox["#1", "2"]}], "+", 
       SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], "\[LessEqual]", 
   "c", "<", "a"}]}]], "Output",
 CellChangeTimes->{3.847373492055793*^9, 3.84742960921943*^9, 
  3.847455123063176*^9, 3.847472852551221*^9},
 CellLabel->"Out[44]=",ExpressionUUID->"af7eab27-9867-4a21-9bcc-f595b9ebc35b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "18", "]"}], "/.", 
     RowBox[{"S", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"s", 
         RowBox[{"(", 
          RowBox[{"s", "-", "a"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "b"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"triang", "=", 
   RowBox[{
    RowBox[{"a", ">", "0"}], "&&", 
    RowBox[{"b", ">", "0"}], "&&", 
    RowBox[{"c", ">", "0"}], "&&", 
    RowBox[{
     RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
    RowBox[{
     RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
    RowBox[{
     RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Reduce", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", ">=", "0"}], "&&", 
         RowBox[{"v", ">=", "0"}], "&&", 
         RowBox[{"w", ">=", "0"}]}], ")"}], "||", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", "<=", "0"}], "&&", 
         RowBox[{"v", "<=", "0"}], "&&", 
         RowBox[{"w", "<=", "0"}]}], ")"}]}], ")"}], "&&", "triang", "&&", 
     RowBox[{"a", ">", "b"}], "&&", 
     RowBox[{"a", ">", "c"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.8473735029810457`*^9, 3.847373514476075*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"5dae103b-4ddc-4261-a5b0-8ddb5bad92c1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", ">", "0"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", "\[Equal]", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "\[Equal]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
        RowBox[{"c", "\[Equal]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
       ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "<", "a"}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
           "\[LessEqual]", "c"}], "&&", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"b", "\[Equal]", 
             FractionBox["a", 
              SqrtBox["3"]]}], "||", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FractionBox["a", 
                SqrtBox["3"]], "<", "b"}], "&&", 
              RowBox[{"b", "<", "a"}]}], ")"}]}], ")"}]}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", "<", 
           FractionBox["a", 
            SqrtBox["3"]]}], "&&", 
          RowBox[{
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], "<", 
           "b"}], "&&", 
          RowBox[{
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
           "\[LessEqual]", "c"}]}], ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "\[Equal]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}], "&&", 
          
          RowBox[{
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
           "\[LessEqual]", "c"}]}], ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", "<", 
           RowBox[{"2", " ", "b"}]}], "&&", 
          RowBox[{"b", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", "<", 
           FractionBox["a", 
            SqrtBox["3"]]}], "&&", 
          RowBox[{
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], "<", 
           "b"}]}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", ">", 
           RowBox[{"2", " ", "b"}]}], "&&", 
          RowBox[{"b", ">", "0"}]}], ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{
       FractionBox["a", 
        SqrtBox["3"]], "<", "b"}], "&&", 
      RowBox[{"b", "<", "a"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", "<", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{"b", "<", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"c", "\[LessEqual]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}], "&&", 
      RowBox[{
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
       "\[LessEqual]", "c"}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.847373504305173*^9, 3.84737351684702*^9}, 
   3.847429610422433*^9, 3.84745512422572*^9, 3.8474728536592083`*^9},
 CellLabel->"Out[47]=",ExpressionUUID->"a57c38b8-13d8-4456-bbd2-b87c79422cc8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "19", "]"}], "/.", 
     RowBox[{"S", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"s", 
         RowBox[{"(", 
          RowBox[{"s", "-", "a"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "b"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"triang", "=", 
   RowBox[{
    RowBox[{"a", ">", "0"}], "&&", 
    RowBox[{"b", ">", "0"}], "&&", 
    RowBox[{"c", ">", "0"}], "&&", 
    RowBox[{
     RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
    RowBox[{
     RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
    RowBox[{
     RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Reduce", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", ">=", "0"}], "&&", 
         RowBox[{"v", ">=", "0"}], "&&", 
         RowBox[{"w", ">=", "0"}]}], ")"}], "||", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", "<=", "0"}], "&&", 
         RowBox[{"v", "<=", "0"}], "&&", 
         RowBox[{"w", "<=", "0"}]}], ")"}]}], ")"}], "&&", "triang", "&&", 
     RowBox[{"a", ">", "b"}], "&&", 
     RowBox[{"a", ">", "c"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{3.847373530053197*^9},
 CellLabel->"In[48]:=",ExpressionUUID->"717ae2a3-4a3d-4243-a6bb-2d0ddef61f3e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", ">", "0"}], "&&", 
  RowBox[{"0", "<", "b", "<", "a"}], "&&", 
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox["a", "2"], "-", 
     SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c", "<", "a"}]}]], "Output",\

 CellChangeTimes->{3.847373531121069*^9, 3.84742961051383*^9, 
  3.847455124379846*^9, 3.847472853793247*^9},
 CellLabel->"Out[50]=",ExpressionUUID->"6d0e6bf7-655f-4464-a90f-730d9fb74c1b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "20", "]"}], "/.", 
     RowBox[{"S", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"s", 
         RowBox[{"(", 
          RowBox[{"s", "-", "a"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "b"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"triang", "=", 
   RowBox[{
    RowBox[{"a", ">", "0"}], "&&", 
    RowBox[{"b", ">", "0"}], "&&", 
    RowBox[{"c", ">", "0"}], "&&", 
    RowBox[{
     RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
    RowBox[{
     RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
    RowBox[{
     RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Reduce", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", ">=", "0"}], "&&", 
         RowBox[{"v", ">=", "0"}], "&&", 
         RowBox[{"w", ">=", "0"}]}], ")"}], "||", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", "<=", "0"}], "&&", 
         RowBox[{"v", "<=", "0"}], "&&", 
         RowBox[{"w", "<=", "0"}]}], ")"}]}], ")"}], "&&", "triang", "&&", 
     RowBox[{"a", ">", "b"}], "&&", 
     RowBox[{"a", ">", "c"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{{3.8473735410133457`*^9, 3.847373541372463*^9}},
 CellLabel->"In[51]:=",ExpressionUUID->"3cd0760c-916a-45e4-90bd-ad83c466494c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", ">", "0"}], "&&", 
  RowBox[{"0", "<", "b", "<", "a"}], "&&", 
  RowBox[{
   RowBox[{"Root", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", 
        SuperscriptBox["a", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"]}], "+", 
       SuperscriptBox["b", "4"], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"]}]}], ")"}], " ", 
        SuperscriptBox["#1", "2"]}], "+", 
       SuperscriptBox["#1", "4"]}], "&"}], ",", "2"}], "]"}], "\[LessEqual]", 
   "c", "<", "a"}]}]], "Output",
 CellChangeTimes->{3.847373542590707*^9, 3.847429610556952*^9, 
  3.847455124436866*^9, 3.84747285386377*^9},
 CellLabel->"Out[53]=",ExpressionUUID->"eac09268-ab51-42a6-a577-50a037875183"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "21", "]"}], "/.", 
     RowBox[{"S", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"s", 
         RowBox[{"(", 
          RowBox[{"s", "-", "a"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "b"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"triang", "=", 
   RowBox[{
    RowBox[{"a", ">", "0"}], "&&", 
    RowBox[{"b", ">", "0"}], "&&", 
    RowBox[{"c", ">", "0"}], "&&", 
    RowBox[{
     RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
    RowBox[{
     RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
    RowBox[{
     RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"red", "=", 
   RowBox[{"Reduce", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"u", ">=", "0"}], "&&", 
          RowBox[{"v", ">=", "0"}], "&&", 
          RowBox[{"w", ">=", "0"}]}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"u", "<=", "0"}], "&&", 
          RowBox[{"v", "<=", "0"}], "&&", 
          RowBox[{"w", "<=", "0"}]}], ")"}]}], ")"}], "&&", "triang", "&&", 
      RowBox[{"a", ">", "b"}], "&&", 
      RowBox[{"a", ">", "c"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"red", ",", 
   RowBox[{"triang", "&&", 
    RowBox[{"a", ">", "b"}], "&&", 
    RowBox[{"a", ">", "c"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.847373575789329*^9, 3.847373576132609*^9}, {
  3.847373613582428*^9, 3.847373654884585*^9}},
 CellLabel->"In[54]:=",ExpressionUUID->"ed19ea19-474b-46c2-b3bd-864cec0ef999"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.847373576721451*^9, {3.847373625601364*^9, 3.847373656004177*^9}, 
   3.847429610599337*^9, 3.8474551245120983`*^9, 3.847472853934999*^9},
 CellLabel->"Out[57]=",ExpressionUUID->"716684d4-8641-44c1-99d3-9e6e4e7aa001"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "condition", " ", "for", " ", "point", " ", "to", " ", "lie", 
    " ", "inside", " ", "or", " ", "on", " ", "the", " ", "triangle"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "100"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "[", "i", "]"}], "/.", 
         RowBox[{"S", "\[Rule]", 
          RowBox[{"2", 
           RowBox[{"Sqrt", "[", 
            RowBox[{"s", 
             RowBox[{"(", 
              RowBox[{"s", "-", "a"}], ")"}], 
             RowBox[{"(", 
              RowBox[{"s", "-", "b"}], ")"}], 
             RowBox[{"(", 
              RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
        RowBox[{"s", "\[Rule]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"triang", "=", 
       RowBox[{
        RowBox[{"a", ">", "0"}], "&&", 
        RowBox[{"b", ">", "0"}], "&&", 
        RowBox[{"c", ">", "0"}], "&&", 
        RowBox[{
         RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
        RowBox[{
         RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
        RowBox[{
         RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"red", "=", 
       RowBox[{"Reduce", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"u", ">=", "0"}], "&&", 
              RowBox[{"v", ">=", "0"}], "&&", 
              RowBox[{"w", ">=", "0"}]}], ")"}], "||", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"u", "<=", "0"}], "&&", 
              RowBox[{"v", "<=", "0"}], "&&", 
              RowBox[{"w", "<=", "0"}]}], ")"}]}], ")"}], "&&", "triang", "&&", 
          RowBox[{"a", ">", "b"}], "&&", 
          RowBox[{"a", ">", "c"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"simp", "=", 
       RowBox[{"Simplify", "[", 
        RowBox[{"red", ",", 
         RowBox[{"triang", "&&", 
          RowBox[{"a", ">", "b"}], "&&", 
          RowBox[{"a", ">", "c"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<[\>\"", ",", "i", ",", "\"\<]  \>\"", ",", "simp"}], 
       "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.847373665143682*^9, 3.847373781365604*^9}, {
  3.84737381459297*^9, 3.847373826805685*^9}, {3.847374063183951*^9, 
  3.847374064393943*^9}},
 CellLabel->"In[58]:=",ExpressionUUID->"9d133a8a-d190-48d1-a81c-7f53ad4ec37d"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 1, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.8474728540281677`*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"95dc199c-b6ab-4de6-a346-dd2ae4fc45d7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 2, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472854030863*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"fbaec50d-0de9-4ac9-8f89-ffa2cb919a23"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}],
  SequenceForm[
  "[", 3, "]  ", ($CellContext`a^2 - $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472854035318*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"32aad0cf-256d-4c05-871c-d8f1b3b075e2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}],
  SequenceForm[
  "[", 4, "]  ", ($CellContext`a^2 - $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472854101225*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"d924a532-b68c-486e-b0ae-f29c12bd5a97"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", "\[LessEqual]", 
       FractionBox["a", 
        SqrtBox["3"]]}], "&&", 
      RowBox[{
       SuperscriptBox["a", "2"], "\[LessEqual]", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"]}]], " ", "c"}]}]}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["a", 
        SqrtBox["3"]], "<", "b"}], "&&", 
      RowBox[{
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              SuperscriptBox["b", "2"]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
       "\[LessEqual]", "c"}]}], ")"}]}]}],
  SequenceForm["[", 5, "]  ", 
   Or[
    And[$CellContext`b <= 
     3^Rational[-1, 
         2] $CellContext`a, $CellContext`a^2 <= $CellContext`b^2 + \
($CellContext`a^2 + $CellContext`b^2)^Rational[1, 2] $CellContext`c], 
    And[3^Rational[-1, 2] $CellContext`a < $CellContext`b, 
     Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3] <= $CellContext`c]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472854541086*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"53825a70-a123-4cc6-9c82-3e83ebaf15d8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "6", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 6, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472854546184*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"922dc36f-e565-4790-85e8-f62622771bf3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "7", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 7, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472854609865*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"ba8af413-f130-4084-a3e5-7f3d3c35d724"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "8", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 8, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.84747285461108*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"76a743b7-ea7a-4e3d-9133-5dc95e842456"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "9", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 9, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472854611917*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"a0706db5-47a7-4e87-8b18-0bd1130cfe50"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "10", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 10, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.8474728546127443`*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"9bea2a99-2355-498b-86bc-b6ecab092b05"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "11", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 11, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472854613576*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"945da048-195c-4c4d-b0d1-be03d61dcd49"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 12, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.8474728546143923`*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"40b29e9e-8b23-420a-9c31-c988ff4d3490"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "13", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"]}]}]], "\[LessEqual]", 
    RowBox[{"b", "+", 
     RowBox[{"2", " ", "c"}]}]}]}],
  SequenceForm[
  "[", 13, "]  ", (4 $CellContext`a^2 - 3 $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`b + 2 $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472854747961*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"0974c789-acd3-422d-863c-769adbd11a87"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "14", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["b", "2"]}]}]], "+", 
        RowBox[{"2", " ", "c"}]}], "\[Equal]", "a"}], "&&", 
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "\[LessEqual]", 
       RowBox[{"2", " ", "b"}]}]}], ")"}], "||", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       RowBox[{"a", " ", "b"}], "+", 
       SuperscriptBox["b", "2"]}]], "\[Equal]", "c"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"a", "+", 
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["b", "2"]}]}]]}], "\[Equal]", 
       RowBox[{"2", " ", "c"}]}], "&&", 
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "<", 
       RowBox[{"2", " ", "b"}]}]}], ")"}]}]}],
  SequenceForm["[", 14, "]  ", 
   Or[
    And[((-3) $CellContext`a^2 + 4 $CellContext`b^2)^Rational[1, 2] + 
      2 $CellContext`c == $CellContext`a, 3^Rational[1, 2] $CellContext`a <= 
     2 $CellContext`b], ($CellContext`a^2 - $CellContext`a $CellContext`b + \
$CellContext`b^2)^Rational[1, 2] == $CellContext`c, 
    And[$CellContext`a + ((-3) $CellContext`a^2 + 4 $CellContext`b^2)^
       Rational[1, 2] == 2 $CellContext`c, 3^Rational[1, 2] $CellContext`a < 
     2 $CellContext`b]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472855627138*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"2765b605-940f-49c6-b047-4c28937aa056"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "15", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"]}]}]], "\[LessEqual]", 
    RowBox[{"b", "+", 
     RowBox[{"2", " ", "c"}]}]}]}],
  SequenceForm[
  "[", 15, "]  ", (4 $CellContext`a^2 - 3 $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`b + 2 $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.84747285569036*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"d3c76024-9a85-4f1f-8302-85a109a1fa78"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "16", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "False"}],
  SequenceForm["[", 16, "]  ", False],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472855761735*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"32256f34-8ddc-412c-a6dd-cfa310a07ec1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "17", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"Root", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["a", "2"]}], "-", 
           SuperscriptBox["b", "2"]}], ")"}], " ", 
         SuperscriptBox["#1", "2"]}], "+", 
        SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], "\[LessEqual]",
     "c"}]}],
  SequenceForm[
  "[", 17, "]  ", 
   Root[$CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472855868722*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"4d5567e3-cfce-4985-9c6a-691a5b4dedd5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "18", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", "\[Equal]", 
         RowBox[{"2", " ", "b"}]}], "||", 
        RowBox[{
         RowBox[{
          SqrtBox["3"], " ", "a"}], "<", 
         RowBox[{"3", " ", "b"}]}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[GreaterEqual]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", "\[Equal]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          
          RowBox[{"c", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", "<", 
           RowBox[{"2", " ", "b"}]}], "&&", 
          RowBox[{"b", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SqrtBox["3"], " ", "a"}], ">", 
           RowBox[{"3", " ", "b"}]}], "&&", 
          RowBox[{"b", ">", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
         ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", "\[GreaterEqual]", 
         RowBox[{"2", " ", "b"}]}], "||", 
        RowBox[{
         RowBox[{
          SqrtBox["3"], " ", "a"}], ">", 
         RowBox[{"3", " ", "b"}]}], "||", 
        RowBox[{"b", "\[LessEqual]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
       ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[GreaterEqual]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "\[LessEqual]", 
       RowBox[{"3", " ", "b"}]}]}], ")"}]}]}],
  SequenceForm["[", 18, "]  ", 
   Or[
    And[$CellContext`c == 
     Root[$CellContext`a^4 - 
       2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + \
(-$CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 3], 
     Or[$CellContext`a == 2 $CellContext`b, 3^Rational[1, 2] $CellContext`a < 
      3 $CellContext`b]], 
    And[$CellContext`c >= 
     Root[$CellContext`a^4 - 
       2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + \
(-$CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 3], 
     Or[
      And[$CellContext`b == 
       Root[$CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
         3], $CellContext`c < 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + \
(-$CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 4]], 
      And[$CellContext`a < 2 $CellContext`b, $CellContext`b < 
       Root[$CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
         3], $CellContext`c <= 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + \
(-$CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 4]], 
      And[
      3^Rational[1, 2] $CellContext`a > 3 $CellContext`b, $CellContext`b > 
       Root[$CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3]]]], 
    And[$CellContext`c == 
     Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + \
$CellContext`b^4 + ((-2) $CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 
       3], 
     Or[$CellContext`a >= 2 $CellContext`b, 3^Rational[1, 2] $CellContext`a > 
      3 $CellContext`b, $CellContext`b <= 
      Root[$CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3]]], 
    And[$CellContext`c >= 
     Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + \
$CellContext`b^4 + ((-2) $CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 
       3], 3^Rational[1, 2] $CellContext`a <= 3 $CellContext`b]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472856955873*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"1ea07a1c-95a0-4d75-a4ab-adbca719a62d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "19", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}],
  SequenceForm[
  "[", 19, "]  ", ($CellContext`a^2 - $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472857023923*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"6a5b3305-c2ea-4a23-b183-03cccab55d17"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "20", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"Root", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["b", "2"]}]}], ")"}], " ", 
         SuperscriptBox["#1", "2"]}], "+", 
        SuperscriptBox["#1", "4"]}], "&"}], ",", "2"}], "]"}], "\[LessEqual]",
     "c"}]}],
  SequenceForm[
  "[", 20, "]  ", 
   Root[(-3) $CellContext`a^4 + 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + (
       2 $CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 
     2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472857025268*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"80d17494-8812-418a-b7c2-0048b18ceb30"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "21", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 21, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472857032762*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"8f45238f-9539-4eb1-a8af-07964447f67a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "22", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"Root", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        SuperscriptBox["#1", "4"]}], "&"}], ",", "2"}], "]"}], "\[LessEqual]",
     "c"}]}],
  SequenceForm[
  "[", 22, "]  ", 
   Root[-$CellContext`a^4 + $CellContext`b^4 + #^4& , 2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472857102281*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"1feaa9ed-7dbf-48a4-90bc-fae5f58a4ac4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "23", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "False"}],
  SequenceForm["[", 23, "]  ", False],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.8474728571033907`*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"c7f28b05-e239-42bc-ae29-7a10c4e25a62"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "24", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
       "\[LessEqual]", "c"}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", "\[Equal]", 
           FractionBox["a", 
            SqrtBox["2"]]}], "&&", 
          RowBox[{"c", "\[LessEqual]", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             SuperscriptBox["b", "2"]}]]}]}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["b", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          
          RowBox[{"(", 
           RowBox[{
            RowBox[{"b", "\[GreaterEqual]", 
             RowBox[{"Root", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["a", "4"]}], "-", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["a", "2"], " ", 
                  SuperscriptBox["#1", "2"]}], "+", 
                 SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
            RowBox[{
             RowBox[{
              SqrtBox["2"], " ", "a"}], "<", 
             RowBox[{"2", " ", "b"}]}]}], ")"}]}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", "<", 
           FractionBox["a", 
            SqrtBox["2"]]}], "&&", 
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "+", 
               SuperscriptBox["b", "4"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
         ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["a", "4"]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           SuperscriptBox["b", "2"]}]], "\[Equal]", "c"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["b", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}], "&&", 
          
          RowBox[{
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "+", 
               SuperscriptBox["b", "4"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
           "\[LessEqual]", "c"}]}], ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"]}]], "\[Equal]", "c"}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b", "<", 
         FractionBox["a", 
          SqrtBox["2"]]}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["a", 
            SqrtBox["2"]], "<", "b"}], "&&", 
          RowBox[{"b", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["a", "4"]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["a", "4"]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], "<", 
         "b"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "+", 
           SuperscriptBox["b", "4"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
       "\[LessEqual]", "c"}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["a", 
            SqrtBox["2"]], "<", "b"}], "&&", 
          RowBox[{"b", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["a", "4"]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["b", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["a", "4"]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], "<", 
         "b"}]}], ")"}]}], ")"}]}]}],
  SequenceForm["[", 24, "]  ", 
   Or[
    And[Root[$CellContext`a^4 - 
       2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
       2 $CellContext`a^2 #^2 + #^4& , 3] <= $CellContext`c, 
     Or[
      And[$CellContext`b == 
       2^Rational[-1, 
           2] $CellContext`a, $CellContext`c <= ($CellContext`a^2 - \
$CellContext`b^2)^Rational[1, 2]], 
      And[$CellContext`c <= 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
         2 $CellContext`b^2 #^2 + #^4& , 3], 
       Or[$CellContext`b >= 
        Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3], 
        2^Rational[1, 2] $CellContext`a < 2 $CellContext`b]], 
      And[$CellContext`b < 2^Rational[-1, 2] $CellContext`a, $CellContext`c <= 
       Root[$CellContext`a^4 + $CellContext`b^4 + ((-2) $CellContext`a^2 - 
           2 $CellContext`b^2) #^2 + #^4& , 3]]]], 
    And[$CellContext`b == 
     Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3], 
     Or[($CellContext`a^2 - $CellContext`b^2)^
       Rational[1, 2] == $CellContext`c, 
      And[$CellContext`c < 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
         2 $CellContext`b^2 #^2 + #^4& , 4], 
       Root[$CellContext`a^4 + $CellContext`b^4 + ((-2) $CellContext`a^2 - 
           2 $CellContext`b^2) #^2 + #^4& , 3] <= $CellContext`c]]], 
    And[($CellContext`a^2 - $CellContext`b^2)^
      Rational[1, 2] == $CellContext`c, 
     Or[$CellContext`b < 2^Rational[-1, 2] $CellContext`a, 
      And[
      2^Rational[-1, 2] $CellContext`a < $CellContext`b, $CellContext`b < 
       Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3]], 
      Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
        3] < $CellContext`b]], 
    And[Root[$CellContext`a^4 + $CellContext`b^4 + ((-2) $CellContext`a^2 - 
         2 $CellContext`b^2) #^2 + #^4& , 3] <= $CellContext`c, 
     Or[
      And[
      2^Rational[-1, 2] $CellContext`a < $CellContext`b, $CellContext`b < 
       Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
         3], $CellContext`c <= 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
         2 $CellContext`b^2 #^2 + #^4& , 4]], 
      Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
        3] < $CellContext`b]]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472860236548*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"9e4404ec-30e7-4a1e-9514-a5fba8d34bc9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "25", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}],
  SequenceForm[
  "[", 25, "]  ", ($CellContext`a^2 - $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.8474728602827253`*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"0ae83d76-f572-4758-ace5-1fceeef91877"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "26", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[GreaterEqual]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "8"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "6"], " ", 
            SuperscriptBox["b", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "6"]}], "+", 
           SuperscriptBox["b", "8"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["a", "6"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "6"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["b", "4"], " ", 
            SuperscriptBox["#1", "4"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "6"]}], "+", 
           SuperscriptBox["#1", "8"]}], "&"}], ",", "4"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["#1", "4"]}]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["a", "8"]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "6"], " ", 
                SuperscriptBox["b", "2"]}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "4"], " ", 
                SuperscriptBox["b", "4"]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "6"]}], "-", 
               SuperscriptBox["b", "8"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["a", "6"]}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "6"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "6"]}], "+", 
               SuperscriptBox["#1", "8"]}], "&"}], ",", "4"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "8"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "6"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "6"]}], "-", 
               SuperscriptBox["b", "8"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["a", "6"]}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "6"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "4"], " ", 
                SuperscriptBox["#1", "4"]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "6"]}], "+", 
               SuperscriptBox["#1", "8"]}], "&"}], ",", "5"}], "]"}]}], "&&", 
          
          RowBox[{"b", "\[GreaterEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"-", "32"}], " ", 
                SuperscriptBox["a", "12"]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "10"], " ", 
                SuperscriptBox["#1", "2"]}], "-", 
               RowBox[{"36", " ", 
                SuperscriptBox["a", "8"], " ", 
                SuperscriptBox["#1", "4"]}], "-", 
               RowBox[{"207", " ", 
                SuperscriptBox["a", "6"], " ", 
                SuperscriptBox["#1", "6"]}], "-", 
               RowBox[{"270", " ", 
                SuperscriptBox["a", "4"], " ", 
                SuperscriptBox["#1", "8"]}], "+", 
               RowBox[{"189", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "10"]}], "+", 
               RowBox[{"432", " ", 
                SuperscriptBox["#1", "12"]}]}], "&"}], ",", "2"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"b", "<", 
             RowBox[{"Root", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "32"}], " ", 
                  SuperscriptBox["a", "12"]}], "-", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["a", "10"], " ", 
                  SuperscriptBox["#1", "2"]}], "-", 
                 RowBox[{"36", " ", 
                  SuperscriptBox["a", "8"], " ", 
                  SuperscriptBox["#1", "4"]}], "-", 
                 RowBox[{"207", " ", 
                  SuperscriptBox["a", "6"], " ", 
                  SuperscriptBox["#1", "6"]}], "-", 
                 RowBox[{"270", " ", 
                  SuperscriptBox["a", "4"], " ", 
                  SuperscriptBox["#1", "8"]}], "+", 
                 RowBox[{"189", " ", 
                  SuperscriptBox["a", "2"], " ", 
                  SuperscriptBox["#1", "10"]}], "+", 
                 RowBox[{"432", " ", 
                  SuperscriptBox["#1", "12"]}]}], "&"}], ",", "2"}], "]"}]}], 
            "||", 
            RowBox[{"b", "\[LessEqual]", 
             RowBox[{"Root", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["a", "4"]}], "-", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["a", "2"], " ", 
                  SuperscriptBox["#1", "2"]}], "+", 
                 SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
           ")"}], "&&", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"b", ">", 
             RowBox[{"Root", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["a", "4"]}], "-", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["a", "2"], " ", 
                  SuperscriptBox["#1", "2"]}], "+", 
                 SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
            RowBox[{"b", ">", 
             RowBox[{"Root", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["a", "4"], "-", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["a", "2"], " ", 
                  SuperscriptBox["#1", "2"]}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["#1", "4"]}]}], "&"}], ",", "3"}], "]"}]}]}],
            ")"}], "&&", 
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "8"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "6"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "6"]}], "-", 
               SuperscriptBox["b", "8"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["a", "6"]}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "6"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "4"], " ", 
                SuperscriptBox["#1", "4"]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "6"]}], "+", 
               SuperscriptBox["#1", "8"]}], "&"}], ",", "3"}], "]"}]}]}], 
         ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[GreaterEqual]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "8"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "6"], " ", 
            SuperscriptBox["b", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "6"]}], "+", 
           SuperscriptBox["b", "8"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["a", "6"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "6"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["b", "4"], " ", 
            SuperscriptBox["#1", "4"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "6"]}], "+", 
           SuperscriptBox["#1", "8"]}], "&"}], ",", "5"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b", ">", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["a", "4"]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
        RowBox[{"b", "\[GreaterEqual]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"-", "32"}], " ", 
              SuperscriptBox["a", "12"]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["a", "10"], " ", 
              SuperscriptBox["#1", "2"]}], "-", 
             RowBox[{"36", " ", 
              SuperscriptBox["a", "8"], " ", 
              SuperscriptBox["#1", "4"]}], "-", 
             RowBox[{"207", " ", 
              SuperscriptBox["a", "6"], " ", 
              SuperscriptBox["#1", "6"]}], "-", 
             RowBox[{"270", " ", 
              SuperscriptBox["a", "4"], " ", 
              SuperscriptBox["#1", "8"]}], "+", 
             RowBox[{"189", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["#1", "10"]}], "+", 
             RowBox[{"432", " ", 
              SuperscriptBox["#1", "12"]}]}], "&"}], ",", "2"}], "]"}]}]}], 
       ")"}]}], ")"}]}]}],
  SequenceForm["[", 26, "]  ", 
   Or[
    And[$CellContext`c >= 
     Root[-$CellContext`a^8 + 2 $CellContext`a^6 $CellContext`b^2 - 
       2 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 + (
         2 $CellContext`a^6 - 2 $CellContext`b^6) #^2 + 
       2 $CellContext`b^4 #^4 + ((-2) $CellContext`a^2 - 
         2 $CellContext`b^2) #^6 + #^8& , 4], 
     Or[
      And[$CellContext`b <= 
       Root[$CellContext`a^4 - 4 $CellContext`a^2 #^2 + 2 #^4& , 
         3], $CellContext`c <= 
       Root[-$CellContext`a^8 + 2 $CellContext`a^6 $CellContext`b^2 - 
         2 $CellContext`a^4 $CellContext`b^4 + 
         2 $CellContext`a^2 $CellContext`b^6 - $CellContext`b^8 + (
           2 $CellContext`a^6 + 
           2 $CellContext`b^6) #^2 + ((-2) $CellContext`a^2 - 
           2 $CellContext`b^2) #^6 + #^8& , 4]], 
      And[$CellContext`c <= 
       Root[$CellContext`a^8 - 2 $CellContext`a^6 $CellContext`b^2 + 
         2 $CellContext`a^2 $CellContext`b^6 - $CellContext`b^8 + ((-2) \
$CellContext`a^6 + 2 $CellContext`b^6) #^2 + 
         2 $CellContext`a^4 #^4 + ((-2) $CellContext`a^2 - 
           2 $CellContext`b^2) #^6 + #^8& , 5], $CellContext`b >= 
       Root[(-32) $CellContext`a^12 - 4 $CellContext`a^10 #^2 - 
         36 $CellContext`a^8 #^4 - 207 $CellContext`a^6 #^6 - 
         270 $CellContext`a^4 #^8 + 189 $CellContext`a^2 #^10 + 432 #^12& , 
         2]], 
      And[
       Or[$CellContext`b < 
        Root[(-32) $CellContext`a^12 - 4 $CellContext`a^10 #^2 - 
          36 $CellContext`a^8 #^4 - 207 $CellContext`a^6 #^6 - 
          270 $CellContext`a^4 #^8 + 189 $CellContext`a^2 #^10 + 432 #^12& , 
          2], $CellContext`b <= 
        Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3]], 
       Or[$CellContext`b > 
        Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
          3], $CellContext`b > 
        Root[$CellContext`a^4 - 4 $CellContext`a^2 #^2 + 2 #^4& , 
          3]], $CellContext`c <= 
       Root[$CellContext`a^8 - 2 $CellContext`a^6 $CellContext`b^2 + 
         2 $CellContext`a^2 $CellContext`b^6 - $CellContext`b^8 + ((-2) \
$CellContext`a^6 + 2 $CellContext`b^6) #^2 + 
         2 $CellContext`a^4 #^4 + ((-2) $CellContext`a^2 - 
           2 $CellContext`b^2) #^6 + #^8& , 3]]]], 
    And[$CellContext`c >= 
     Root[-$CellContext`a^8 + 2 $CellContext`a^6 $CellContext`b^2 - 
       2 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 + (
         2 $CellContext`a^6 - 2 $CellContext`b^6) #^2 + 
       2 $CellContext`b^4 #^4 + ((-2) $CellContext`a^2 - 
         2 $CellContext`b^2) #^6 + #^8& , 5], 
     Or[$CellContext`b > 
      Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
        3], $CellContext`b >= 
      Root[(-32) $CellContext`a^12 - 4 $CellContext`a^10 #^2 - 
        36 $CellContext`a^8 #^4 - 207 $CellContext`a^6 #^6 - 
        270 $CellContext`a^4 #^8 + 189 $CellContext`a^2 #^10 + 432 #^12& , 
        2]]]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472860593988*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"872b4f66-cc83-4bae-95b8-396fa1a632bf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "27", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}],
  SequenceForm[
  "[", 27, "]  ", ($CellContext`a^2 - $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472860642991*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"32bce194-db25-466f-b891-d6e0e6d825fd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "28", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}],
  SequenceForm[
  "[", 28, "]  ", ($CellContext`a^2 - $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472860696542*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"d2c1afaf-0342-4c1b-b0ee-f217d9a8cd41"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "29", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}],
  SequenceForm[
  "[", 29, "]  ", ($CellContext`a^2 - $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472860742696*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"5795bb82-7053-40b1-996d-f2c24ad56305"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "30", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "False"}],
  SequenceForm["[", 30, "]  ", False],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472860789906*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"863a3a34-9981-4c59-a28e-8fef425e0ca0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "31", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 31, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472860790944*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"78eccc98-a3d7-41e7-ae50-28de5af8960e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "32", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 32, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472860791791*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"5d51f034-e669-4770-acd7-5d678aa6db13"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "33", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}],
  SequenceForm[
  "[", 33, "]  ", ($CellContext`a^2 - $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472860837681*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"57593b4e-a5a4-422f-8bd9-e13ab244b55d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "34", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}],
  SequenceForm[
  "[", 34, "]  ", ($CellContext`a^2 - $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.8474728608807898`*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"6b53b647-0e7e-40c1-a396-7a478913aa15"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "35", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"]}]}]], "\[LessEqual]", 
    RowBox[{"b", "+", 
     RowBox[{"2", " ", "c"}]}]}]}],
  SequenceForm[
  "[", 35, "]  ", (4 $CellContext`a^2 - 3 $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`b + 2 $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472860928809*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"5baf1c92-d316-4b59-b3e3-4765df10905e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "36", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "False"}],
  SequenceForm["[", 36, "]  ", False],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472860929937*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"f81abaa4-a5c3-4c14-a6c7-c6ba22ba3a55"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "37", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 37, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.8474728609308367`*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"c975cc1b-4b17-4848-92d4-c2f79362d11d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "38", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 38, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472860931683*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"c1546f40-73c2-44bc-8604-42fd30606d4c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "39", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 39, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472860932529*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"8d72e4bb-8017-48d5-9e76-55a4ee434a1c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "40", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"Root", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "2"]}], "+", 
           RowBox[{"2", " ", "a", " ", "b"}], "-", 
           SuperscriptBox["b", "2"]}], ")"}], " ", "#1"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "-", "b"}], ")"}], " ", 
         SuperscriptBox["#1", "2"]}], "+", 
        SuperscriptBox["#1", "3"]}], "&"}], ",", "1"}], "]"}], "\[LessEqual]",
     "c"}]}],
  SequenceForm[
  "[", 40, "]  ", 
   Root[-$CellContext`a^3 - $CellContext`a^2 $CellContext`b + $CellContext`a \
$CellContext`b^2 + $CellContext`b^3 + (-$CellContext`a^2 + 
       2 $CellContext`a $CellContext`b - $CellContext`b^2) # + \
($CellContext`a - $CellContext`b) #^2 + #^3& , 1] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472860978725*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"6d1cd5b4-dbb2-4256-80fd-9bbab419b24b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "41", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 41, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472860979949*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"3a0fcb14-d82a-484d-a100-aa122712e89f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "42", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 42, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472860980785*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"49f1a18b-05b4-40db-a300-54de0879a4b3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "43", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SqrtBox["5"], " ", "a"}], "+", 
        RowBox[{"2", " ", "b"}]}], ">", 
       RowBox[{"3", " ", "a"}]}], "&&", 
      RowBox[{"a", ">", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{
       RowBox[{"b", " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", "c"}], ")"}]}], "\[GreaterEqual]", 
       RowBox[{"a", " ", "c"}]}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", "\[Equal]", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{
       RowBox[{"b", " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", "c"}], ")"}]}], ">", 
       RowBox[{"a", " ", "c"}]}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", "<", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{
       RowBox[{
        SqrtBox["5"], " ", "a"}], "\[GreaterEqual]", 
       RowBox[{"a", "+", 
        RowBox[{"2", " ", "b"}]}]}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox["5"], " ", "a"}], "<", 
       RowBox[{"a", "+", 
        RowBox[{"2", " ", "b"}]}]}], "&&", 
      RowBox[{
       FractionBox[
        RowBox[{"a", " ", "b"}], 
        RowBox[{"a", "+", "b"}]], "\[LessEqual]", "c"}]}], ")"}]}]}],
  SequenceForm["[", 43, "]  ", 
   Or[
    And[5^Rational[1, 2] $CellContext`a + 2 $CellContext`b > 
     3 $CellContext`a, $CellContext`a > 
     2 $CellContext`b, $CellContext`b ($CellContext`a + $CellContext`c) >= \
$CellContext`a $CellContext`c], 
    And[$CellContext`a == 
     2 $CellContext`b, $CellContext`b ($CellContext`a + $CellContext`c) > \
$CellContext`a $CellContext`c], 
    And[$CellContext`a < 2 $CellContext`b, 
     5^Rational[1, 2] $CellContext`a >= $CellContext`a + 2 $CellContext`b], 
    And[5^Rational[1, 2] $CellContext`a < $CellContext`a + 
      2 $CellContext`b, $CellContext`a $CellContext`b/($CellContext`a + \
$CellContext`b) <= $CellContext`c]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472861492351*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"2367a51d-51c2-40f6-9eaf-be75da0bf89e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "44", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "False"}],
  SequenceForm["[", 44, "]  ", False],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472861537725*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"5c2c51c3-492e-42dc-9224-1e7c61e75dbd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "45", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 45, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.84747286153906*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"5e8f9b6b-2ec9-4995-b8c7-d4b96d4f8f34"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "46", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "3"]}], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "b"}], "+", 
           RowBox[{"a", " ", 
            SuperscriptBox["b", "2"]}], "-", 
           SuperscriptBox["b", "3"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "-", 
              SuperscriptBox["b", "2"]}], ")"}], " ", "#1"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b"}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "3"]}], "&"}], ",", "3"}], "]"}], 
       "\[LessEqual]", "c"}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SqrtBox["3"], " ", "a"}], "\[Equal]", 
           RowBox[{"a", "+", "b"}]}], "&&", 
          RowBox[{"c", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "3"], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "b"}], "-", 
               RowBox[{"a", " ", 
                SuperscriptBox["b", "2"]}], "-", 
               SuperscriptBox["b", "3"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["a", "2"]}], "-", 
                  SuperscriptBox["b", "2"]}], ")"}], " ", "#1"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "a"}], "+", "b"}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "3"]}], "&"}], ",", "3"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["a", 
            SqrtBox["2"]], "<", "b"}], "&&", 
          RowBox[{
           RowBox[{"a", "+", "b"}], "<", 
           RowBox[{
            SqrtBox["3"], " ", "a"}]}], "&&", 
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "3"], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "b"}], "-", 
               RowBox[{"a", " ", 
                SuperscriptBox["b", "2"]}], "-", 
               SuperscriptBox["b", "3"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["a", "2"]}], "-", 
                  SuperscriptBox["b", "2"]}], ")"}], " ", "#1"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "a"}], "+", "b"}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "3"]}], "&"}], ",", "3"}], "]"}]}]}], 
         ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"16", " ", 
            SuperscriptBox["a", "4"]}], "-", 
           RowBox[{"5", " ", 
            SuperscriptBox["a", "3"], " ", "#1"}], "-", 
           RowBox[{"30", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "-", 
           RowBox[{"5", " ", "a", " ", 
            SuperscriptBox["#1", "3"]}], "+", 
           RowBox[{"16", " ", 
            SuperscriptBox["#1", "4"]}]}], "&"}], ",", "1"}], "]"}]}], "&&", 
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "3"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "b"}], "-", 
           RowBox[{"a", " ", 
            SuperscriptBox["b", "2"]}], "-", 
           SuperscriptBox["b", "3"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "-", 
              SuperscriptBox["b", "2"]}], ")"}], " ", "#1"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b"}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "3"]}], "&"}], ",", "2"}], "]"}]}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "<", 
       RowBox[{"a", "+", "b"}]}], "&&", 
      RowBox[{"c", "\[GreaterEqual]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "3"]}], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "b"}], "+", 
           RowBox[{"a", " ", 
            SuperscriptBox["b", "2"]}], "-", 
           SuperscriptBox["b", "3"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "-", 
              SuperscriptBox["b", "2"]}], ")"}], " ", "#1"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b"}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "3"]}], "&"}], ",", "3"}], "]"}]}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"16", " ", 
            SuperscriptBox["a", "4"]}], "-", 
           RowBox[{"5", " ", 
            SuperscriptBox["a", "3"], " ", "#1"}], "-", 
           RowBox[{"30", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "-", 
           RowBox[{"5", " ", "a", " ", 
            SuperscriptBox["#1", "3"]}], "+", 
           RowBox[{"16", " ", 
            SuperscriptBox["#1", "4"]}]}], "&"}], ",", "1"}], "]"}], "<", 
       "b"}], "&&", 
      RowBox[{"b", "\[LessEqual]", 
       FractionBox["a", 
        SqrtBox["2"]]}], "&&", 
      RowBox[{"c", "\[LessEqual]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "3"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "b"}], "-", 
           RowBox[{"a", " ", 
            SuperscriptBox["b", "2"]}], "-", 
           SuperscriptBox["b", "3"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "-", 
              SuperscriptBox["b", "2"]}], ")"}], " ", "#1"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b"}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "3"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "3"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "b"}], "-", 
           RowBox[{"a", " ", 
            SuperscriptBox["b", "2"]}], "-", 
           SuperscriptBox["b", "3"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "-", 
              SuperscriptBox["b", "2"]}], ")"}], " ", "#1"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b"}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "3"]}], "&"}], ",", "2"}], "]"}], 
       "\[LessEqual]", "c"}]}], ")"}]}]}],
  SequenceForm["[", 46, "]  ", 
   Or[
    And[Root[-$CellContext`a^3 + $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + (-$CellContext`a^2 - \
$CellContext`b^2) # + ($CellContext`a + $CellContext`b) #^2 + #^3& , 
       3] <= $CellContext`c, 
     Or[
      And[
      3^Rational[
          1, 2] $CellContext`a == $CellContext`a + $CellContext`b, \
$CellContext`c < 
       Root[$CellContext`a^3 + $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + (-$CellContext`a^2 - \
$CellContext`b^2) # + (-$CellContext`a + $CellContext`b) #^2 + #^3& , 3]], 
      And[
      2^Rational[-1, 
           2] $CellContext`a < $CellContext`b, $CellContext`a + \
$CellContext`b < 3^Rational[1, 2] $CellContext`a, $CellContext`c <= 
       Root[$CellContext`a^3 + $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + (-$CellContext`a^2 - \
$CellContext`b^2) # + (-$CellContext`a + $CellContext`b) #^2 + #^3& , 3]]]], 
    And[$CellContext`b == 
     Root[16 $CellContext`a^4 - 5 $CellContext`a^3 # - 
       30 $CellContext`a^2 #^2 - 5 $CellContext`a #^3 + 16 #^4& , 
       1], $CellContext`c == 
     Root[$CellContext`a^3 + $CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 - $CellContext`b^3 + (-$CellContext`a^2 - $CellContext`b^2) \
# + (-$CellContext`a + $CellContext`b) #^2 + #^3& , 2]], 
    And[3^
       Rational[
        1, 2] $CellContext`a < $CellContext`a + $CellContext`b, \
$CellContext`c >= 
     Root[-$CellContext`a^3 + $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + (-$CellContext`a^2 - \
$CellContext`b^2) # + ($CellContext`a + $CellContext`b) #^2 + #^3& , 3]], 
    And[Root[
      16 $CellContext`a^4 - 5 $CellContext`a^3 # - 30 $CellContext`a^2 #^2 - 
       5 $CellContext`a #^3 + 16 #^4& , 1] < $CellContext`b, $CellContext`b <= 
     2^Rational[-1, 2] $CellContext`a, $CellContext`c <= 
     Root[$CellContext`a^3 + $CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 - $CellContext`b^3 + (-$CellContext`a^2 - $CellContext`b^2) \
# + (-$CellContext`a + $CellContext`b) #^2 + #^3& , 3], 
     Root[$CellContext`a^3 + $CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 - $CellContext`b^3 + (-$CellContext`a^2 - $CellContext`b^2) \
# + (-$CellContext`a + $CellContext`b) #^2 + #^3& , 2] <= $CellContext`c]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472862313259*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"73e07da2-4c57-4cc7-9a4a-be07a117f391"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "47", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox["2"], " ", "a"}], "\[Equal]", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["b", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[GreaterEqual]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "+", 
           SuperscriptBox["b", "4"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SqrtBox["2"], " ", "a"}], "<", 
           RowBox[{"2", " ", "b"}]}], "&&", 
          RowBox[{"b", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["a", "4"]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["b", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", "\[GreaterEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["a", "4"]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          
          RowBox[{"c", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["b", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{"b", ">", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["a", "4"]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
       ")"}]}], ")"}], "||", 
    RowBox[{"c", "\[LessEqual]", 
     RowBox[{"Root", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"]}], "+", 
         SuperscriptBox["b", "4"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["#1", "2"]}], "+", 
         SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}]}],
  SequenceForm["[", 47, "]  ", 
   Or[
    And[2^Rational[1, 2] $CellContext`a == 2 $CellContext`b, $CellContext`c == 
     Root[$CellContext`a^4 - 
       2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
       2 $CellContext`b^2 #^2 + #^4& , 3]], 
    And[$CellContext`c >= 
     Root[$CellContext`a^4 + $CellContext`b^4 + ((-2) $CellContext`a^2 - 
         2 $CellContext`b^2) #^2 + #^4& , 3], 
     Or[
      And[
      2^Rational[1, 2] $CellContext`a < 2 $CellContext`b, $CellContext`b < 
       Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
         3], $CellContext`c <= 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
         2 $CellContext`b^2 #^2 + #^4& , 4]], 
      And[$CellContext`b >= 
       Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
         3], $CellContext`c < 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
         2 $CellContext`b^2 #^2 + #^4& , 4]], $CellContext`b > 
      Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
        3]]], $CellContext`c <= 
    Root[$CellContext`a^4 - 
      2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
      2 $CellContext`a^2 #^2 + #^4& , 3]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472863207625*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"afa679bd-efb5-4626-a609-fdda81ef8111"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "48", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}],
  SequenceForm[
  "[", 48, "]  ", ($CellContext`a^2 - $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472863251361*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"a8c37479-715a-4de7-bc35-a83b8618ee2e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "49", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", "\[Equal]", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"]}]], "\[Equal]", "c"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", "\[Equal]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          
          RowBox[{"c", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", "<", 
           RowBox[{"2", " ", "b"}]}], "&&", 
          RowBox[{"b", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SqrtBox["3"], " ", "a"}], "<", 
           RowBox[{"3", " ", "b"}]}], "&&", 
          RowBox[{
           RowBox[{
            SqrtBox["3"], " ", "a"}], "\[GreaterEqual]", 
           RowBox[{"2", " ", "b"}]}]}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SqrtBox["3"], " ", "a"}], "\[GreaterEqual]", 
           RowBox[{"3", " ", "b"}]}], "&&", 
          RowBox[{"b", ">", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
         ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[GreaterEqual]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              SuperscriptBox["b", "2"]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", "\[GreaterEqual]", 
             RowBox[{"2", " ", "b"}]}], "||", 
            RowBox[{
             RowBox[{
              SqrtBox["3"], " ", "a"}], "\[GreaterEqual]", 
             RowBox[{"3", " ", "b"}]}], "||", 
            RowBox[{"b", "\[LessEqual]", 
             RowBox[{"Root", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["a", "4"], "-", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["a", "2"], " ", 
                  SuperscriptBox["#1", "2"]}], "+", 
                 SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
           ")"}]}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SqrtBox["3"], " ", "a"}], "<", 
             RowBox[{"2", " ", "b"}]}], "||", 
            RowBox[{
             RowBox[{
              SqrtBox["3"], " ", "a"}], "<", 
             RowBox[{"3", " ", "b"}]}]}], ")"}]}], ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "<", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{"c", "\[GreaterEqual]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
     ")"}]}]}],
  SequenceForm["[", 49, "]  ", 
   Or[
    And[$CellContext`a == 
     2 $CellContext`b, ($CellContext`a^2 - $CellContext`b^2)^
      Rational[1, 2] == $CellContext`c], 
    And[($CellContext`a^2 - $CellContext`b^2)^
      Rational[1, 2] <= $CellContext`c, 
     Or[
      And[$CellContext`b == 
       Root[$CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
         3], $CellContext`c < 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + \
(-$CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 4]], 
      And[$CellContext`a < 2 $CellContext`b, $CellContext`b < 
       Root[$CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
         3], $CellContext`c <= 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + \
(-$CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 4]], 
      And[
      3^Rational[1, 2] $CellContext`a < 3 $CellContext`b, 
       3^Rational[1, 2] $CellContext`a >= 2 $CellContext`b], 
      And[
      3^Rational[1, 2] $CellContext`a >= 3 $CellContext`b, $CellContext`b > 
       Root[$CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3]]]], 
    And[$CellContext`c >= 
     Root[$CellContext`a^4 - 
       2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3], 
     Or[
      And[$CellContext`c <= 
       Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + \
$CellContext`b^4 + ((-2) $CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 
         3], 
       Or[$CellContext`a >= 2 $CellContext`b, 3^Rational[1, 2] $CellContext`a >= 
        3 $CellContext`b, $CellContext`b <= 
        Root[$CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3]]], 
      And[$CellContext`c <= 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + \
(-$CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 3], 
       Or[
       3^Rational[1, 2] $CellContext`a < 2 $CellContext`b, 
        3^Rational[1, 2] $CellContext`a < 3 $CellContext`b]]]], 
    And[3^Rational[1, 2] $CellContext`a < 2 $CellContext`b, $CellContext`c >= 
     Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + \
$CellContext`b^4 + ((-2) $CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 
       3]]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472866482523*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"ca68b6c9-22d5-48f3-92b6-fd48fbeaed80"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "50", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"]}]}]], "\[GreaterEqual]", 
    RowBox[{"b", "+", 
     RowBox[{"2", " ", "c"}]}]}]}],
  SequenceForm[
  "[", 50, "]  ", (4 $CellContext`a^2 - 3 $CellContext`b^2)^
    Rational[1, 2] >= $CellContext`b + 2 $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472866616049*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"d832884a-a632-4be5-acfa-cf558ae1ad41"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "51", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", "\[LessEqual]", 
       FractionBox["a", 
        SqrtBox["3"]]}], "&&", 
      RowBox[{
       SuperscriptBox["a", "2"], "\[LessEqual]", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"]}]], " ", "c"}]}]}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["a", 
        SqrtBox["3"]], "<", "b"}], "&&", 
      RowBox[{
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              SuperscriptBox["b", "2"]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
       "\[LessEqual]", "c"}]}], ")"}]}]}],
  SequenceForm["[", 51, "]  ", 
   Or[
    And[$CellContext`b <= 
     3^Rational[-1, 
         2] $CellContext`a, $CellContext`a^2 <= $CellContext`b^2 + \
($CellContext`a^2 + $CellContext`b^2)^Rational[1, 2] $CellContext`c], 
    And[3^Rational[-1, 2] $CellContext`a < $CellContext`b, 
     Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3] <= $CellContext`c]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.8474728666704693`*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"fdf66f9b-fe39-48aa-a7d9-58d60cf36b83"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "52", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", "\[Equal]", 
       FractionBox["a", 
        SqrtBox["2"]]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "\[Equal]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["b", "2"], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            RowBox[{
             SqrtBox[
              RowBox[{
               SuperscriptBox["a", "2"], "+", 
               SuperscriptBox["b", "2"]}]], " ", "c"}]}], "\[LessEqual]", 
           SuperscriptBox["a", "2"]}], "&&", 
          RowBox[{
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
           "\[LessEqual]", "c"}]}], ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["a", "4"]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["b", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}], "&&", 
          
          RowBox[{
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "+", 
               SuperscriptBox["b", "4"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
           "\[LessEqual]", "c"}]}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            RowBox[{
             SqrtBox[
              RowBox[{
               SuperscriptBox["a", "2"], "+", 
               SuperscriptBox["b", "2"]}]], " ", "c"}]}], "\[LessEqual]", 
           SuperscriptBox["a", "2"]}], "&&", 
          RowBox[{
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
           "\[LessEqual]", "c"}]}], ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
       "\[LessEqual]", "c"}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", "\[LessEqual]", 
           FractionBox["a", 
            SqrtBox["3"]]}], "&&", 
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["a", "2"]}], "-", 
                  SuperscriptBox["b", "2"]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            RowBox[{
             SqrtBox[
              RowBox[{
               SuperscriptBox["a", "2"], "+", 
               SuperscriptBox["b", "2"]}]], " ", "c"}]}], "\[LessEqual]", 
           SuperscriptBox["a", "2"]}], "&&", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FractionBox["a", 
                SqrtBox["2"]], "<", "b"}], "&&", 
              RowBox[{"b", "<", 
               RowBox[{"Root", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["a", "4"]}], "-", 
                   RowBox[{"4", " ", 
                    SuperscriptBox["a", "2"], " ", 
                    SuperscriptBox["#1", "2"]}], "+", 
                   SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
             ")"}], "||", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FractionBox["a", 
                SqrtBox["3"]], "<", "b"}], "&&", 
              RowBox[{"b", "<", 
               FractionBox["a", 
                SqrtBox["2"]]}]}], ")"}], "||", 
            RowBox[{
             RowBox[{"Root", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["a", "4"]}], "-", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["a", "2"], " ", 
                  SuperscriptBox["#1", "2"]}], "+", 
                 SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], "<", 
             "b"}]}], ")"}]}], ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "+", 
           SuperscriptBox["b", "4"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
       "\[LessEqual]", "c"}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["a", 
            SqrtBox["2"]], "<", "b"}], "&&", 
          RowBox[{"b", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["a", "4"]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["b", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["a", "4"]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], "<", 
         "b"}]}], ")"}]}], ")"}]}]}],
  SequenceForm["[", 52, "]  ", 
   Or[
    And[$CellContext`b == 2^Rational[-1, 2] $CellContext`a, 
     Or[$CellContext`c == 
      Root[$CellContext`a^4 - 
        2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
        2 $CellContext`b^2 #^2 + #^4& , 3], 
      And[$CellContext`b^2 + ($CellContext`a^2 + $CellContext`b^2)^
          Rational[1, 2] $CellContext`c <= $CellContext`a^2, 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
         2 $CellContext`a^2 #^2 + #^4& , 3] <= $CellContext`c]]], 
    And[$CellContext`b == 
     Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3], 
     Or[
      And[$CellContext`c < 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
         2 $CellContext`b^2 #^2 + #^4& , 4], 
       Root[$CellContext`a^4 + $CellContext`b^4 + ((-2) $CellContext`a^2 - 
           2 $CellContext`b^2) #^2 + #^4& , 3] <= $CellContext`c], 
      And[$CellContext`b^2 + ($CellContext`a^2 + $CellContext`b^2)^
          Rational[1, 2] $CellContext`c <= $CellContext`a^2, 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
         2 $CellContext`a^2 #^2 + #^4& , 3] <= $CellContext`c]]], 
    And[Root[$CellContext`a^4 - 
       2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
       2 $CellContext`a^2 #^2 + #^4& , 3] <= $CellContext`c, 
     Or[
      And[$CellContext`b <= 3^Rational[-1, 2] $CellContext`a, $CellContext`c <= 
       Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3]], 
      And[$CellContext`b^2 + ($CellContext`a^2 + $CellContext`b^2)^
          Rational[1, 2] $CellContext`c <= $CellContext`a^2, 
       Or[
        And[
        2^Rational[-1, 2] $CellContext`a < $CellContext`b, $CellContext`b < 
         Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3]], 
        And[
        3^Rational[-1, 2] $CellContext`a < $CellContext`b, $CellContext`b < 
         2^Rational[-1, 2] $CellContext`a], 
        Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
          3] < $CellContext`b]]]], 
    And[Root[$CellContext`a^4 + $CellContext`b^4 + ((-2) $CellContext`a^2 - 
         2 $CellContext`b^2) #^2 + #^4& , 3] <= $CellContext`c, 
     Or[
      And[
      2^Rational[-1, 2] $CellContext`a < $CellContext`b, $CellContext`b < 
       Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
         3], $CellContext`c <= 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
         2 $CellContext`b^2 #^2 + #^4& , 4]], 
      Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
        3] < $CellContext`b]]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.8474728687027903`*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"1bc49ffc-2d60-4481-95c7-cac0d06e49a6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "53", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "\[GreaterEqual]", 
       RowBox[{"3", " ", "b"}]}], "&&", 
      RowBox[{"c", "\[LessEqual]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              SuperscriptBox["b", "2"]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "<", 
       RowBox[{"3", " ", "b"}]}], "&&", 
      RowBox[{
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"]}]], " ", "c"}]}], "\[LessEqual]", 
       SuperscriptBox["a", "2"]}]}], ")"}]}]}],
  SequenceForm["[", 53, "]  ", 
   Or[($CellContext`a^2 - $CellContext`b^2)^Rational[1, 2] <= $CellContext`c, 
    
    And[3^Rational[1, 2] $CellContext`a >= 3 $CellContext`b, $CellContext`c <= 
     Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3]], 
    And[3^Rational[1, 2] $CellContext`a < 
     3 $CellContext`b, $CellContext`b^2 + ($CellContext`a^2 + \
$CellContext`b^2)^Rational[1, 2] $CellContext`c <= $CellContext`a^2]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472869248372*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"a58a8b55-3e47-4391-a13d-c196241fafda"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "54", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], "\[LessEqual]", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"]}]], " ", "c"}]}]}], "&&", 
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "\[GreaterEqual]", 
       RowBox[{"3", " ", "b"}]}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["a", 
        SqrtBox["3"]], "<", "b"}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], "\[Equal]", 
         RowBox[{
          SuperscriptBox["b", "2"], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"]}]], " ", "c"}]}]}], "||", 
        RowBox[{
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                SuperscriptBox["b", "2"]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
         "\[LessEqual]", "c"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              SuperscriptBox["b", "2"]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"b", "<", 
       FractionBox["a", 
        SqrtBox["3"]]}]}], ")"}]}]}],
  SequenceForm["[", 54, "]  ", 
   Or[
    And[$CellContext`a^2 <= $CellContext`b^2 + ($CellContext`a^2 + \
$CellContext`b^2)^Rational[1, 2] $CellContext`c, 
     3^Rational[1, 2] $CellContext`a >= 3 $CellContext`b], 
    And[3^Rational[-1, 2] $CellContext`a < $CellContext`b, 
     Or[$CellContext`a^2 == $CellContext`b^2 + ($CellContext`a^2 + \
$CellContext`b^2)^Rational[1, 2] $CellContext`c, 
      Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3] <= $CellContext`c]], 
    And[$CellContext`c == 
     Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3], $CellContext`b < 
     3^Rational[-1, 2] $CellContext`a]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472870666916*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"ff5d1716-f883-4b55-a465-cfbe69ffb06c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "55", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 55, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472870672117*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"3ab0b2cd-81c7-48fe-b439-f54953c11abb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "56", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 56, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472870749295*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"9fbd59aa-4d03-480d-8754-39626b32637c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "57", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 57, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.8474728707505083`*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"a36d8a82-cb8c-4f67-b42c-957fe91c38ec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "58", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 58, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472870751546*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"8fbf5758-ed61-4bd6-b0dc-4d4af9ed9a2e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "59", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 59, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472870752984*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"d868e764-2f54-45df-a7d6-37855950fca7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "60", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 60, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472870754115*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"8ca2fd98-9263-4298-8417-03444359585d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "61", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"c", "\[LessEqual]", 
     RowBox[{"Root", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"]}], "+", 
         SuperscriptBox["b", "4"], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"]}], ")"}], " ", 
          SuperscriptBox["#1", "2"]}], "+", 
         SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
    RowBox[{
     SqrtBox[
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox["a", "2"]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["b", "2"]}]}]], "\[LessEqual]", 
     RowBox[{"b", "+", 
      RowBox[{"2", " ", "c"}]}]}]}]}],
  SequenceForm["[", 61, "]  ", 
   Or[$CellContext`c <= 
    Root[$CellContext`a^4 - 
      2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3], (4 $CellContext`a^2 - 
      3 $CellContext`b^2)^Rational[1, 2] <= $CellContext`b + 
     2 $CellContext`c]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472870986003*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"440bc8d8-c6e9-4508-90e9-f3ee2a621851"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "62", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "\[Equal]", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", "<", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "\[GreaterEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}], "&&", 
          
          RowBox[{"a", "<", 
           RowBox[{"2", " ", "b"}]}]}], ")"}], "||", 
        RowBox[{"c", "\[LessEqual]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
       ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", "\[GreaterEqual]", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           RowBox[{"a", " ", "b"}], "+", 
           SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}], "||", 
        RowBox[{"c", "\[LessEqual]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
       ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[LessEqual]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", 
               SuperscriptBox["a", "2"]}], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["b", "2"]}]}]], "+", 
            RowBox[{"2", " ", "c"}]}], "\[GreaterEqual]", "a"}], "&&", 
          RowBox[{
           RowBox[{
            SqrtBox["3"], " ", "a"}], "<", 
           RowBox[{"2", " ", "b"}]}]}], ")"}], "||", 
        RowBox[{
         RowBox[{
          SqrtBox["3"], " ", "a"}], "\[GreaterEqual]", 
         RowBox[{"3", " ", "b"}]}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[LessEqual]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SqrtBox["3"], " ", "a"}], "<", 
         RowBox[{"3", " ", "b"}]}], "||", 
        RowBox[{
         RowBox[{
          SqrtBox["3"], " ", "a"}], "\[LessEqual]", 
         RowBox[{"2", " ", "b"}]}]}], ")"}]}], ")"}]}]}],
  SequenceForm["[", 62, "]  ", 
   Or[
    And[3^Rational[1, 2] $CellContext`a == 2 $CellContext`b, $CellContext`c == 
     Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + \
$CellContext`b^4 + ((-2) $CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 
       3]], 
    And[$CellContext`b < 
     Root[$CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3], 
     Or[
      And[$CellContext`c >= 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + \
(-$CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 4], $CellContext`a < 
       2 $CellContext`b], $CellContext`c <= 
      Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + \
$CellContext`b^4 + ((-2) $CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 
        3]]], 
    And[$CellContext`a >= 2 $CellContext`b, 
     Or[($CellContext`a^2 - $CellContext`a $CellContext`b + $CellContext`b^2)^
       Rational[1, 2] <= $CellContext`c, $CellContext`c <= 
      Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + \
$CellContext`b^4 + ((-2) $CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 
        3]]], 
    And[$CellContext`c <= 
     Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + \
$CellContext`b^4 + ((-2) $CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 
       3], 
     Or[
      And[((-3) $CellContext`a^2 + 4 $CellContext`b^2)^Rational[1, 2] + 
        2 $CellContext`c >= $CellContext`a, 3^Rational[1, 2] $CellContext`a < 
       2 $CellContext`b], 3^Rational[1, 2] $CellContext`a >= 
      3 $CellContext`b]], 
    And[$CellContext`c <= 
     Root[$CellContext`a^4 - 
       2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + \
(-$CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 3], 
     Or[3^Rational[1, 2] $CellContext`a < 3 $CellContext`b, 
      3^Rational[1, 2] $CellContext`a <= 2 $CellContext`b]]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.8474728725157757`*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"6addf379-bf82-4f86-b26a-c9f6ba1665bc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "63", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}],
  SequenceForm[
  "[", 63, "]  ", ($CellContext`a^2 - $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472872594728*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"d66474ac-c324-4d3e-b693-0215def55a22"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "64", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"Root", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["b", "2"]}]}], ")"}], " ", 
         SuperscriptBox["#1", "2"]}], "+", 
        SuperscriptBox["#1", "4"]}], "&"}], ",", "2"}], "]"}], "\[LessEqual]",
     "c"}]}],
  SequenceForm[
  "[", 64, "]  ", 
   Root[(-3) $CellContext`a^4 + 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + (
       2 $CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 
     2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472872596086*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"12623f3d-5324-4e61-95f0-d1229be5fbb8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "65", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 65, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472872597134*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"e0c7077d-93a7-40d6-b529-75585bb5b982"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "66", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"Root", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        SuperscriptBox["#1", "4"]}], "&"}], ",", "2"}], "]"}], "\[LessEqual]",
     "c"}]}],
  SequenceForm[
  "[", 66, "]  ", 
   Root[-$CellContext`a^4 + $CellContext`b^4 + #^4& , 2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472872684876*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"e6d694a0-7564-4f81-b1e7-59bdf62432fa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "67", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           SuperscriptBox["b", "4"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"b", "\[GreaterEqual]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", "3"}], " ", 
            SuperscriptBox["a", "4"]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["#1", "4"]}]}], "&"}], ",", "2"}], "]"}]}]}], 
     ")"}], "||", 
    RowBox[{"c", "\[Equal]", 
     RowBox[{"Root", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"]}], "-", 
         SuperscriptBox["b", "4"], "+", 
         SuperscriptBox["#1", "4"]}], "&"}], ",", "2"}], "]"}]}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           SuperscriptBox["b", "4"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}], "&&", 
      RowBox[{
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", "3"}], " ", 
            SuperscriptBox["a", "4"]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["#1", "4"]}]}], "&"}], ",", "2"}], "]"}], "<", 
       "b"}]}], ")"}]}]}],
  SequenceForm["[", 67, "]  ", 
   Or[
    And[$CellContext`c == 
     Root[$CellContext`a^4 - $CellContext`b^4 - $CellContext`a^2 #^2 + #^4& , 
       3], $CellContext`b >= 
     Root[(-3) $CellContext`a^4 + 4 #^4& , 2]], $CellContext`c == 
    Root[-$CellContext`a^4 + $CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^4 + #^4& , 2], 
    And[$CellContext`c == 
     Root[$CellContext`a^4 - $CellContext`b^4 - $CellContext`a^2 #^2 + #^4& , 
       4], Root[(-3) $CellContext`a^4 + 4 #^4& , 2] < $CellContext`b]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472872766103*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"fc0bfbfc-b41c-4f0b-8652-ab6953b008da"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "68", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["a", "4"]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["b", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}], "&&", 
          
          RowBox[{
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "+", 
               SuperscriptBox["b", "4"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
           "\[LessEqual]", "c"}]}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["b", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          
          RowBox[{
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
           "\[LessEqual]", "c"}]}], ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
       "\[LessEqual]", "c"}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", "\[LessEqual]", 
           FractionBox["a", 
            SqrtBox["2"]]}], "&&", 
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "+", 
               SuperscriptBox["b", "4"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["b", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FractionBox["a", 
                SqrtBox["2"]], "<", "b"}], "&&", 
              RowBox[{"b", "<", 
               RowBox[{"Root", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["a", "4"]}], "-", 
                   RowBox[{"4", " ", 
                    SuperscriptBox["a", "2"], " ", 
                    SuperscriptBox["#1", "2"]}], "+", 
                   SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
             ")"}], "||", 
            RowBox[{
             RowBox[{"Root", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["a", "4"]}], "-", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["a", "2"], " ", 
                  SuperscriptBox["#1", "2"]}], "+", 
                 SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], "<", 
             "b"}]}], ")"}]}], ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "+", 
           SuperscriptBox["b", "4"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
       "\[LessEqual]", "c"}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["a", 
            SqrtBox["2"]], "<", "b"}], "&&", 
          RowBox[{"b", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["a", "4"]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["b", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["a", "4"]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], "<", 
         "b"}]}], ")"}]}], ")"}]}]}],
  SequenceForm["[", 68, "]  ", 
   Or[
    And[$CellContext`b == 
     Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3], 
     Or[
      And[$CellContext`c < 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
         2 $CellContext`b^2 #^2 + #^4& , 4], 
       Root[$CellContext`a^4 + $CellContext`b^4 + ((-2) $CellContext`a^2 - 
           2 $CellContext`b^2) #^2 + #^4& , 3] <= $CellContext`c], 
      And[$CellContext`c <= 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
         2 $CellContext`b^2 #^2 + #^4& , 3], 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
         2 $CellContext`a^2 #^2 + #^4& , 3] <= $CellContext`c]]], 
    And[Root[$CellContext`a^4 - 
       2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
       2 $CellContext`a^2 #^2 + #^4& , 3] <= $CellContext`c, 
     Or[
      And[$CellContext`b <= 2^Rational[-1, 2] $CellContext`a, $CellContext`c <= R\
oot[$CellContext`a^4 + $CellContext`b^4 + ((-2) $CellContext`a^2 - 
           2 $CellContext`b^2) #^2 + #^4& , 3]], 
      And[$CellContext`c <= 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
         2 $CellContext`b^2 #^2 + #^4& , 3], 
       Or[
        And[
        2^Rational[-1, 2] $CellContext`a < $CellContext`b, $CellContext`b < 
         Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3]], 
        Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
          3] < $CellContext`b]]]], 
    And[Root[$CellContext`a^4 + $CellContext`b^4 + ((-2) $CellContext`a^2 - 
         2 $CellContext`b^2) #^2 + #^4& , 3] <= $CellContext`c, 
     Or[
      And[
      2^Rational[-1, 2] $CellContext`a < $CellContext`b, $CellContext`b < 
       Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
         3], $CellContext`c <= 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
         2 $CellContext`b^2 #^2 + #^4& , 4]], 
      Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
        3] < $CellContext`b]]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.84747287319309*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"cd569dd6-3e14-4344-99dd-9940def32d9b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "69", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}],
  SequenceForm[
  "[", 69, "]  ", ($CellContext`a^2 - $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472873275099*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"f0e492bd-e61b-4f54-bedd-844241010833"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "70", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[GreaterEqual]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "8"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "6"], " ", 
            SuperscriptBox["b", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "6"]}], "+", 
           SuperscriptBox["b", "8"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["a", "6"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "6"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["b", "4"], " ", 
            SuperscriptBox["#1", "4"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "6"]}], "+", 
           SuperscriptBox["#1", "8"]}], "&"}], ",", "4"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "8"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "6"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "6"]}], "-", 
               SuperscriptBox["b", "8"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["a", "6"]}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "6"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "4"], " ", 
                SuperscriptBox["#1", "4"]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "6"]}], "+", 
               SuperscriptBox["#1", "8"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          
          RowBox[{"(", 
           RowBox[{
            RowBox[{"b", "\[Equal]", 
             RowBox[{"Root", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["a", "4"]}], "-", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["a", "2"], " ", 
                  SuperscriptBox["#1", "2"]}], "+", 
                 SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"b", "\[GreaterEqual]", 
               RowBox[{"Root", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["a", "4"]}], "-", 
                   RowBox[{"4", " ", 
                    SuperscriptBox["a", "2"], " ", 
                    SuperscriptBox["#1", "2"]}], "+", 
                   SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
              RowBox[{"b", "<", 
               RowBox[{"Root", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "32"}], " ", 
                    SuperscriptBox["a", "12"]}], "-", 
                   RowBox[{"4", " ", 
                    SuperscriptBox["a", "10"], " ", 
                    SuperscriptBox["#1", "2"]}], "-", 
                   RowBox[{"36", " ", 
                    SuperscriptBox["a", "8"], " ", 
                    SuperscriptBox["#1", "4"]}], "-", 
                   RowBox[{"207", " ", 
                    SuperscriptBox["a", "6"], " ", 
                    SuperscriptBox["#1", "6"]}], "-", 
                   RowBox[{"270", " ", 
                    SuperscriptBox["a", "4"], " ", 
                    SuperscriptBox["#1", "8"]}], "+", 
                   RowBox[{"189", " ", 
                    SuperscriptBox["a", "2"], " ", 
                    SuperscriptBox["#1", "10"]}], "+", 
                   RowBox[{"432", " ", 
                    SuperscriptBox["#1", "12"]}]}], "&"}], ",", "2"}], 
                "]"}]}]}], ")"}], "||", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"b", ">", 
               RowBox[{"Root", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["a", "4"], "-", 
                   RowBox[{"4", " ", 
                    SuperscriptBox["a", "2"], " ", 
                    SuperscriptBox["#1", "2"]}], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox["#1", "4"]}]}], "&"}], ",", "3"}], "]"}]}],
               "&&", 
              RowBox[{"b", "\[LessEqual]", 
               RowBox[{"Root", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["a", "4"]}], "-", 
                   RowBox[{"4", " ", 
                    SuperscriptBox["a", "2"], " ", 
                    SuperscriptBox["#1", "2"]}], "+", 
                   SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
             ")"}]}], ")"}]}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", "\[GreaterEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"-", "32"}], " ", 
                SuperscriptBox["a", "12"]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "10"], " ", 
                SuperscriptBox["#1", "2"]}], "-", 
               RowBox[{"36", " ", 
                SuperscriptBox["a", "8"], " ", 
                SuperscriptBox["#1", "4"]}], "-", 
               RowBox[{"207", " ", 
                SuperscriptBox["a", "6"], " ", 
                SuperscriptBox["#1", "6"]}], "-", 
               RowBox[{"270", " ", 
                SuperscriptBox["a", "4"], " ", 
                SuperscriptBox["#1", "8"]}], "+", 
               RowBox[{"189", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "10"]}], "+", 
               RowBox[{"432", " ", 
                SuperscriptBox["#1", "12"]}]}], "&"}], ",", "2"}], "]"}]}], "&&", 
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "8"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "6"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "6"]}], "-", 
               SuperscriptBox["b", "8"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["a", "6"]}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "6"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "4"], " ", 
                SuperscriptBox["#1", "4"]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "6"]}], "+", 
               SuperscriptBox["#1", "8"]}], "&"}], ",", "5"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["#1", "4"]}]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["a", "8"]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "6"], " ", 
                SuperscriptBox["b", "2"]}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "4"], " ", 
                SuperscriptBox["b", "4"]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "6"]}], "-", 
               SuperscriptBox["b", "8"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["a", "6"]}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "6"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "6"]}], "+", 
               SuperscriptBox["#1", "8"]}], "&"}], ",", "4"}], "]"}]}]}], 
         ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "8"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "6"], " ", 
            SuperscriptBox["b", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "4"], " ", 
            SuperscriptBox["b", "4"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "6"]}], "-", 
           SuperscriptBox["b", "8"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["a", "6"]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "6"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "6"]}], "+", 
           SuperscriptBox["#1", "8"]}], "&"}], ",", "4"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b", "\[GreaterEqual]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["a", "4"]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
        RowBox[{"b", "\[GreaterEqual]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"-", "32"}], " ", 
              SuperscriptBox["a", "12"]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["a", "10"], " ", 
              SuperscriptBox["#1", "2"]}], "-", 
             RowBox[{"36", " ", 
              SuperscriptBox["a", "8"], " ", 
              SuperscriptBox["#1", "4"]}], "-", 
             RowBox[{"207", " ", 
              SuperscriptBox["a", "6"], " ", 
              SuperscriptBox["#1", "6"]}], "-", 
             RowBox[{"270", " ", 
              SuperscriptBox["a", "4"], " ", 
              SuperscriptBox["#1", "8"]}], "+", 
             RowBox[{"189", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["#1", "10"]}], "+", 
             RowBox[{"432", " ", 
              SuperscriptBox["#1", "12"]}]}], "&"}], ",", "2"}], "]"}]}], "||", 
        RowBox[{"b", ">", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["#1", "4"]}]}], "&"}], ",", "3"}], "]"}]}]}], 
       ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "8"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "6"], " ", 
            SuperscriptBox["b", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "4"], " ", 
            SuperscriptBox["b", "4"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "6"]}], "-", 
           SuperscriptBox["b", "8"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["a", "6"]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "6"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "6"]}], "+", 
           SuperscriptBox["#1", "8"]}], "&"}], ",", "5"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b", "<", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["a", "4"]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
        RowBox[{"b", "\[LessEqual]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["#1", "4"]}]}], "&"}], ",", "3"}], "]"}]}]}], 
       ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "8"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "6"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "6"]}], "-", 
           SuperscriptBox["b", "8"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "6"]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "6"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "4"], " ", 
            SuperscriptBox["#1", "4"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "6"]}], "+", 
           SuperscriptBox["#1", "8"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"b", "<", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["#1", "4"]}]}], "&"}], ",", "3"}], "]"}]}]}], 
     ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", "\[GreaterEqual]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", "32"}], " ", 
            SuperscriptBox["a", "12"]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["a", "10"], " ", 
            SuperscriptBox["#1", "2"]}], "-", 
           RowBox[{"36", " ", 
            SuperscriptBox["a", "8"], " ", 
            SuperscriptBox["#1", "4"]}], "-", 
           RowBox[{"207", " ", 
            SuperscriptBox["a", "6"], " ", 
            SuperscriptBox["#1", "6"]}], "-", 
           RowBox[{"270", " ", 
            SuperscriptBox["a", "4"], " ", 
            SuperscriptBox["#1", "8"]}], "+", 
           RowBox[{"189", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "10"]}], "+", 
           RowBox[{"432", " ", 
            SuperscriptBox["#1", "12"]}]}], "&"}], ",", "2"}], "]"}]}], "&&", 
      
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "\[Equal]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "8"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "6"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "6"]}], "-", 
             SuperscriptBox["b", "8"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "6"]}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "6"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "4"], " ", 
              SuperscriptBox["#1", "4"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "6"]}], "+", 
             SuperscriptBox["#1", "8"]}], "&"}], ",", "6"}], "]"}]}], "||", 
        RowBox[{"c", "\[GreaterEqual]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "8"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "6"], " ", 
              SuperscriptBox["b", "2"]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "6"]}], "+", 
             SuperscriptBox["b", "8"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SuperscriptBox["a", "6"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "6"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["b", "4"], " ", 
              SuperscriptBox["#1", "4"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "6"]}], "+", 
             SuperscriptBox["#1", "8"]}], "&"}], ",", "5"}], "]"}]}]}], 
       ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "8"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "6"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "6"]}], "-", 
           SuperscriptBox["b", "8"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "6"]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "6"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "4"], " ", 
            SuperscriptBox["#1", "4"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "6"]}], "+", 
           SuperscriptBox["#1", "8"]}], "&"}], ",", "7"}], "]"}]}], "&&", 
      RowBox[{"b", ">", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", "32"}], " ", 
            SuperscriptBox["a", "12"]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["a", "10"], " ", 
            SuperscriptBox["#1", "2"]}], "-", 
           RowBox[{"36", " ", 
            SuperscriptBox["a", "8"], " ", 
            SuperscriptBox["#1", "4"]}], "-", 
           RowBox[{"207", " ", 
            SuperscriptBox["a", "6"], " ", 
            SuperscriptBox["#1", "6"]}], "-", 
           RowBox[{"270", " ", 
            SuperscriptBox["a", "4"], " ", 
            SuperscriptBox["#1", "8"]}], "+", 
           RowBox[{"189", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "10"]}], "+", 
           RowBox[{"432", " ", 
            SuperscriptBox["#1", "12"]}]}], "&"}], ",", "2"}], "]"}]}]}], 
     ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[GreaterEqual]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "8"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "6"], " ", 
            SuperscriptBox["b", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "6"]}], "+", 
           SuperscriptBox["b", "8"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["a", "6"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "6"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["b", "4"], " ", 
            SuperscriptBox["#1", "4"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "6"]}], "+", 
           SuperscriptBox["#1", "8"]}], "&"}], ",", "5"}], "]"}]}], "&&", 
      RowBox[{"b", ">", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["a", "4"]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
     ")"}]}]}],
  SequenceForm["[", 70, "]  ", 
   Or[
    And[$CellContext`c >= 
     Root[-$CellContext`a^8 + 2 $CellContext`a^6 $CellContext`b^2 - 
       2 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 + (
         2 $CellContext`a^6 - 2 $CellContext`b^6) #^2 + 
       2 $CellContext`b^4 #^4 + ((-2) $CellContext`a^2 - 
         2 $CellContext`b^2) #^6 + #^8& , 4], 
     Or[
      And[$CellContext`c <= 
       Root[$CellContext`a^8 - 2 $CellContext`a^6 $CellContext`b^2 + 
         2 $CellContext`a^2 $CellContext`b^6 - $CellContext`b^8 + ((-2) \
$CellContext`a^6 + 2 $CellContext`b^6) #^2 + 
         2 $CellContext`a^4 #^4 + ((-2) $CellContext`a^2 - 
           2 $CellContext`b^2) #^6 + #^8& , 3], 
       Or[$CellContext`b == 
        Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3], 
        And[$CellContext`b >= 
         Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
           3], $CellContext`b < 
         Root[(-32) $CellContext`a^12 - 4 $CellContext`a^10 #^2 - 
           36 $CellContext`a^8 #^4 - 207 $CellContext`a^6 #^6 - 
           270 $CellContext`a^4 #^8 + 189 $CellContext`a^2 #^10 + 432 #^12& , 
           2]], 
        And[$CellContext`b > 
         Root[$CellContext`a^4 - 4 $CellContext`a^2 #^2 + 2 #^4& , 
           3], $CellContext`b <= 
         Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3]]]], 
      And[$CellContext`b >= 
       Root[(-32) $CellContext`a^12 - 4 $CellContext`a^10 #^2 - 
         36 $CellContext`a^8 #^4 - 207 $CellContext`a^6 #^6 - 
         270 $CellContext`a^4 #^8 + 189 $CellContext`a^2 #^10 + 432 #^12& , 
         2], $CellContext`c <= 
       Root[$CellContext`a^8 - 2 $CellContext`a^6 $CellContext`b^2 + 
         2 $CellContext`a^2 $CellContext`b^6 - $CellContext`b^8 + ((-2) \
$CellContext`a^6 + 2 $CellContext`b^6) #^2 + 
         2 $CellContext`a^4 #^4 + ((-2) $CellContext`a^2 - 
           2 $CellContext`b^2) #^6 + #^8& , 5]], 
      And[$CellContext`b <= 
       Root[$CellContext`a^4 - 4 $CellContext`a^2 #^2 + 2 #^4& , 
         3], $CellContext`c <= 
       Root[-$CellContext`a^8 + 2 $CellContext`a^6 $CellContext`b^2 - 
         2 $CellContext`a^4 $CellContext`b^4 + 
         2 $CellContext`a^2 $CellContext`b^6 - $CellContext`b^8 + (
           2 $CellContext`a^6 + 
           2 $CellContext`b^6) #^2 + ((-2) $CellContext`a^2 - 
           2 $CellContext`b^2) #^6 + #^8& , 4]]]], 
    And[$CellContext`c == 
     Root[-$CellContext`a^8 + 2 $CellContext`a^6 $CellContext`b^2 - 
       2 $CellContext`a^4 $CellContext`b^4 + 
       2 $CellContext`a^2 $CellContext`b^6 - $CellContext`b^8 + (
         2 $CellContext`a^6 + 
         2 $CellContext`b^6) #^2 + ((-2) $CellContext`a^2 - 
         2 $CellContext`b^2) #^6 + #^8& , 4], 
     Or[$CellContext`b >= 
      Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
        3], $CellContext`b >= 
      Root[(-32) $CellContext`a^12 - 4 $CellContext`a^10 #^2 - 
        36 $CellContext`a^8 #^4 - 207 $CellContext`a^6 #^6 - 
        270 $CellContext`a^4 #^8 + 189 $CellContext`a^2 #^10 + 432 #^12& , 
        2], $CellContext`b > 
      Root[$CellContext`a^4 - 4 $CellContext`a^2 #^2 + 2 #^4& , 3]]], 
    And[$CellContext`c == 
     Root[-$CellContext`a^8 + 2 $CellContext`a^6 $CellContext`b^2 - 
       2 $CellContext`a^4 $CellContext`b^4 + 
       2 $CellContext`a^2 $CellContext`b^6 - $CellContext`b^8 + (
         2 $CellContext`a^6 + 
         2 $CellContext`b^6) #^2 + ((-2) $CellContext`a^2 - 
         2 $CellContext`b^2) #^6 + #^8& , 5], 
     Or[$CellContext`b < 
      Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
        3], $CellContext`b <= 
      Root[$CellContext`a^4 - 4 $CellContext`a^2 #^2 + 2 #^4& , 3]]], 
    And[$CellContext`c == 
     Root[$CellContext`a^8 - 2 $CellContext`a^6 $CellContext`b^2 + 
       2 $CellContext`a^2 $CellContext`b^6 - $CellContext`b^8 + ((-2) \
$CellContext`a^6 + 2 $CellContext`b^6) #^2 + 
       2 $CellContext`a^4 #^4 + ((-2) $CellContext`a^2 - 
         2 $CellContext`b^2) #^6 + #^8& , 3], $CellContext`b < 
     Root[$CellContext`a^4 - 4 $CellContext`a^2 #^2 + 2 #^4& , 3]], 
    And[$CellContext`b >= 
     Root[(-32) $CellContext`a^12 - 4 $CellContext`a^10 #^2 - 
       36 $CellContext`a^8 #^4 - 207 $CellContext`a^6 #^6 - 
       270 $CellContext`a^4 #^8 + 189 $CellContext`a^2 #^10 + 432 #^12& , 2], 
     
     Or[$CellContext`c == 
      Root[$CellContext`a^8 - 2 $CellContext`a^6 $CellContext`b^2 + 
        2 $CellContext`a^2 $CellContext`b^6 - $CellContext`b^8 + ((-2) \
$CellContext`a^6 + 2 $CellContext`b^6) #^2 + 
        2 $CellContext`a^4 #^4 + ((-2) $CellContext`a^2 - 
          2 $CellContext`b^2) #^6 + #^8& , 6], $CellContext`c >= 
      Root[-$CellContext`a^8 + 2 $CellContext`a^6 $CellContext`b^2 - 
        2 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 + (
          2 $CellContext`a^6 - 2 $CellContext`b^6) #^2 + 
        2 $CellContext`b^4 #^4 + ((-2) $CellContext`a^2 - 
          2 $CellContext`b^2) #^6 + #^8& , 5]]], 
    And[$CellContext`c == 
     Root[$CellContext`a^8 - 2 $CellContext`a^6 $CellContext`b^2 + 
       2 $CellContext`a^2 $CellContext`b^6 - $CellContext`b^8 + ((-2) \
$CellContext`a^6 + 2 $CellContext`b^6) #^2 + 
       2 $CellContext`a^4 #^4 + ((-2) $CellContext`a^2 - 
         2 $CellContext`b^2) #^6 + #^8& , 7], $CellContext`b > 
     Root[(-32) $CellContext`a^12 - 4 $CellContext`a^10 #^2 - 
       36 $CellContext`a^8 #^4 - 207 $CellContext`a^6 #^6 - 
       270 $CellContext`a^4 #^8 + 189 $CellContext`a^2 #^10 + 432 #^12& , 2]], 
    And[$CellContext`c >= 
     Root[-$CellContext`a^8 + 2 $CellContext`a^6 $CellContext`b^2 - 
       2 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 + (
         2 $CellContext`a^6 - 2 $CellContext`b^6) #^2 + 
       2 $CellContext`b^4 #^4 + ((-2) $CellContext`a^2 - 
         2 $CellContext`b^2) #^6 + #^8& , 5], $CellContext`b > 
     Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3]]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.84747287431532*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"77a1297b-e117-49c4-9aeb-768efd83c32a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "71", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}],
  SequenceForm[
  "[", 71, "]  ", ($CellContext`a^2 - $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472874395961*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"87365d43-e8e1-44bb-a49a-be1f491d7d24"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "72", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}],
  SequenceForm[
  "[", 72, "]  ", ($CellContext`a^2 - $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472874397294*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"390c9cc2-910c-4bbb-9141-be531d94c5a1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "73", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}],
  SequenceForm[
  "[", 73, "]  ", ($CellContext`a^2 - $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.84747287448384*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"436dda17-a588-4238-b6c8-5067ef0b0eb9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "74", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", 
        SqrtBox["2"], " ", "a"}], "\[LessEqual]", 
       RowBox[{"3", " ", "b"}]}], "&&", 
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["b", "4"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "+", 
              SuperscriptBox["b", "2"]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], ")"}], "||", 
    RowBox[{"c", "\[Equal]", 
     RowBox[{"Root", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"]}], "-", 
         SuperscriptBox["b", "4"], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"]}], ")"}], " ", 
          SuperscriptBox["#1", "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["#1", "4"]}]}], "&"}], ",", "2"}], "]"}]}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", 
        SqrtBox["2"], " ", "a"}], "<", 
       RowBox[{"3", " ", "b"}]}], "&&", 
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["b", "4"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "+", 
              SuperscriptBox["b", "2"]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}]}], 
     ")"}]}]}],
  SequenceForm["[", 74, "]  ", 
   Or[
    And[2 2^Rational[1, 2] $CellContext`a <= 3 $CellContext`b, $CellContext`c == 
     Root[$CellContext`a^4 + $CellContext`a^2 $CellContext`b^2 - 
       2 $CellContext`b^4 + ((-2) $CellContext`a^2 + $CellContext`b^2) #^2 + \
#^4& , 3]], $CellContext`c == 
    Root[-$CellContext`a^4 + 
      2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + \
(-$CellContext`a^2 - $CellContext`b^2) #^2 + 2 #^4& , 2], 
    And[2 2^Rational[1, 2] $CellContext`a < 3 $CellContext`b, $CellContext`c == 
     Root[$CellContext`a^4 + $CellContext`a^2 $CellContext`b^2 - 
       2 $CellContext`b^4 + ((-2) $CellContext`a^2 + $CellContext`b^2) #^2 + \
#^4& , 4]]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472874718121*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"e946966f-18db-4a4f-b3ab-c044c8e15388"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "75", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 75, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472874723078*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"6d5d730b-ad52-42dc-b1c0-e35da0ebe5d9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "76", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 76, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.8474728747995863`*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"07f92dda-89c6-48f8-ba7f-ce60743a986c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "77", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}],
  SequenceForm[
  "[", 77, "]  ", ($CellContext`a^2 - $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.8474728748008947`*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"44d918ae-7bbe-4a2d-8ff2-8816a724a359"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "78", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}],
  SequenceForm[
  "[", 78, "]  ", ($CellContext`a^2 - $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472874801999*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"4a516b36-5b31-474d-9167-02d73cf83c2c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "79", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"]}]}]], "\[LessEqual]", 
    RowBox[{"b", "+", 
     RowBox[{"2", " ", "c"}]}]}]}],
  SequenceForm[
  "[", 79, "]  ", (4 $CellContext`a^2 - 3 $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`b + 2 $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.8474728748831244`*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"9113327b-41c6-478b-bfd6-1427c3e2d45e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "80", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["b", "2"]}]}]], "+", 
        RowBox[{"2", " ", "c"}]}], "\[Equal]", "a"}], "&&", 
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "\[LessEqual]", 
       RowBox[{"2", " ", "b"}]}]}], ")"}], "||", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       RowBox[{"a", " ", "b"}], "+", 
       SuperscriptBox["b", "2"]}]], "\[Equal]", "c"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"a", "+", 
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["b", "2"]}]}]]}], "\[Equal]", 
       RowBox[{"2", " ", "c"}]}], "&&", 
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "<", 
       RowBox[{"2", " ", "b"}]}]}], ")"}]}]}],
  SequenceForm["[", 80, "]  ", 
   Or[
    And[((-3) $CellContext`a^2 + 4 $CellContext`b^2)^Rational[1, 2] + 
      2 $CellContext`c == $CellContext`a, 3^Rational[1, 2] $CellContext`a <= 
     2 $CellContext`b], ($CellContext`a^2 - $CellContext`a $CellContext`b + \
$CellContext`b^2)^Rational[1, 2] == $CellContext`c, 
    And[$CellContext`a + ((-3) $CellContext`a^2 + 4 $CellContext`b^2)^
       Rational[1, 2] == 2 $CellContext`c, 3^Rational[1, 2] $CellContext`a < 
     2 $CellContext`b]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472875457685*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"152ff3c2-8cd2-4dad-9791-64721babaab0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "81", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 81, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472875536858*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"76abc5db-2a45-4311-8707-635651d27900"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "82", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 82, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472875538368*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"6129e7dc-9f40-470f-81ab-b09373965ea8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "83", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 83, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472875539344*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"118c1c1d-e592-4fb2-aec5-b93d2b46effa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "84", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"Root", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "2"]}], "+", 
           RowBox[{"2", " ", "a", " ", "b"}], "-", 
           SuperscriptBox["b", "2"]}], ")"}], " ", "#1"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "-", "b"}], ")"}], " ", 
         SuperscriptBox["#1", "2"]}], "+", 
        SuperscriptBox["#1", "3"]}], "&"}], ",", "1"}], "]"}], "\[LessEqual]",
     "c"}]}],
  SequenceForm[
  "[", 84, "]  ", 
   Root[-$CellContext`a^3 - $CellContext`a^2 $CellContext`b + $CellContext`a \
$CellContext`b^2 + $CellContext`b^3 + (-$CellContext`a^2 + 
       2 $CellContext`a $CellContext`b - $CellContext`b^2) # + \
($CellContext`a - $CellContext`b) #^2 + #^3& , 1] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472875540558*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"a42aeca7-d706-449f-bddb-9575339e14f6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "85", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 85, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.8474728755416107`*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"664079a6-1506-48e9-9365-45fe333e0f8e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "86", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 86, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.8474728755425386`*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"a77cc4ae-a293-47b6-a789-92b569c51d76"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "87", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SqrtBox["5"], " ", "a"}], "+", 
        RowBox[{"2", " ", "b"}]}], ">", 
       RowBox[{"3", " ", "a"}]}], "&&", 
      RowBox[{"a", ">", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{
       RowBox[{"b", " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", "c"}], ")"}]}], "\[GreaterEqual]", 
       RowBox[{"a", " ", "c"}]}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", "\[Equal]", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{
       RowBox[{"b", " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", "c"}], ")"}]}], ">", 
       RowBox[{"a", " ", "c"}]}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", "<", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{
       RowBox[{
        SqrtBox["5"], " ", "a"}], "\[GreaterEqual]", 
       RowBox[{"a", "+", 
        RowBox[{"2", " ", "b"}]}]}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox["5"], " ", "a"}], "<", 
       RowBox[{"a", "+", 
        RowBox[{"2", " ", "b"}]}]}], "&&", 
      RowBox[{
       FractionBox[
        RowBox[{"a", " ", "b"}], 
        RowBox[{"a", "+", "b"}]], "\[LessEqual]", "c"}]}], ")"}]}]}],
  SequenceForm["[", 87, "]  ", 
   Or[
    And[5^Rational[1, 2] $CellContext`a + 2 $CellContext`b > 
     3 $CellContext`a, $CellContext`a > 
     2 $CellContext`b, $CellContext`b ($CellContext`a + $CellContext`c) >= \
$CellContext`a $CellContext`c], 
    And[$CellContext`a == 
     2 $CellContext`b, $CellContext`b ($CellContext`a + $CellContext`c) > \
$CellContext`a $CellContext`c], 
    And[$CellContext`a < 2 $CellContext`b, 
     5^Rational[1, 2] $CellContext`a >= $CellContext`a + 2 $CellContext`b], 
    And[5^Rational[1, 2] $CellContext`a < $CellContext`a + 
      2 $CellContext`b, $CellContext`a $CellContext`b/($CellContext`a + \
$CellContext`b) <= $CellContext`c]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472875622706*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"3e4eaf6e-550d-4355-a4c7-6a4a9ab6372e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "88", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"a", "+", "b"}], "\[Equal]", 
       RowBox[{"2", " ", "c"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", "<", 
         RowBox[{"3", " ", "b"}]}], "||", 
        RowBox[{
         RowBox[{"2", " ", "a"}], "<", 
         RowBox[{"3", " ", "b"}]}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"a", "+", "c"}], "\[Equal]", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{
       RowBox[{"2", " ", "a"}], "<", 
       RowBox[{"3", " ", "b"}]}]}], ")"}]}]}],
  SequenceForm["[", 88, "]  ", 
   Or[
    And[$CellContext`a + $CellContext`b == 2 $CellContext`c, 
     Or[$CellContext`a < 3 $CellContext`b, 2 $CellContext`a < 
      3 $CellContext`b]], 
    And[$CellContext`a + $CellContext`c == 2 $CellContext`b, 2 $CellContext`a < 
     3 $CellContext`b]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472875709742*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"a554723e-d1e8-4f38-8dde-cc20d70fc8d7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "89", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["[", 89, "]  ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472875788906*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"6e5e2df8-5ec6-45cf-abe3-8e81df6f3247"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "90", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "\[Equal]", 
       RowBox[{"a", "+", "b"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "\[Equal]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "3"], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "b"}], "-", 
             RowBox[{"a", " ", 
              SuperscriptBox["b", "2"]}], "-", 
             SuperscriptBox["b", "3"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["a", "2"]}], "-", 
                SuperscriptBox["b", "2"]}], ")"}], " ", "#1"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "a"}], "+", "b"}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "3"]}], "&"}], ",", "2"}], "]"}]}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "3"], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "b"}], "-", 
               RowBox[{"a", " ", 
                SuperscriptBox["b", "2"]}], "-", 
               SuperscriptBox["b", "3"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["a", "2"]}], "-", 
                  SuperscriptBox["b", "2"]}], ")"}], " ", "#1"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "a"}], "+", "b"}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "3"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          
          RowBox[{
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["a", "3"]}], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "b"}], "+", 
               RowBox[{"a", " ", 
                SuperscriptBox["b", "2"]}], "-", 
               SuperscriptBox["b", "3"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["a", "2"]}], "-", 
                  SuperscriptBox["b", "2"]}], ")"}], " ", "#1"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"a", "+", "b"}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "3"]}], "&"}], ",", "3"}], "]"}], 
           "\[LessEqual]", "c"}]}], ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[LessEqual]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "3"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "b"}], "-", 
           RowBox[{"a", " ", 
            SuperscriptBox["b", "2"]}], "-", 
           SuperscriptBox["b", "3"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "-", 
              SuperscriptBox["b", "2"]}], ")"}], " ", "#1"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b"}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "3"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "3"], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "b"}], "-", 
               RowBox[{"a", " ", 
                SuperscriptBox["b", "2"]}], "-", 
               SuperscriptBox["b", "3"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["a", "2"]}], "-", 
                  SuperscriptBox["b", "2"]}], ")"}], " ", "#1"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "a"}], "+", "b"}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "3"]}], "&"}], ",", "2"}], "]"}], 
           "\[LessEqual]", "c"}], "&&", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"b", "\[Equal]", 
             FractionBox["a", 
              SqrtBox["2"]]}], "||", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"b", "<", 
               FractionBox["a", 
                SqrtBox["2"]]}], "&&", 
              RowBox[{
               RowBox[{"Root", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"16", " ", 
                    SuperscriptBox["a", "4"]}], "-", 
                   RowBox[{"5", " ", 
                    SuperscriptBox["a", "3"], " ", "#1"}], "-", 
                   RowBox[{"30", " ", 
                    SuperscriptBox["a", "2"], " ", 
                    SuperscriptBox["#1", "2"]}], "-", 
                   RowBox[{"5", " ", "a", " ", 
                    SuperscriptBox["#1", "3"]}], "+", 
                   RowBox[{"16", " ", 
                    SuperscriptBox["#1", "4"]}]}], "&"}], ",", "1"}], "]"}], 
               "<", "b"}]}], ")"}]}], ")"}]}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["a", 
            SqrtBox["2"]], "<", "b"}], "&&", 
          RowBox[{
           RowBox[{"a", "+", "b"}], "<", 
           RowBox[{
            SqrtBox["3"], " ", "a"}]}], "&&", 
          RowBox[{
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["a", "3"]}], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "b"}], "+", 
               RowBox[{"a", " ", 
                SuperscriptBox["b", "2"]}], "-", 
               SuperscriptBox["b", "3"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["a", "2"]}], "-", 
                  SuperscriptBox["b", "2"]}], ")"}], " ", "#1"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"a", "+", "b"}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "3"]}], "&"}], ",", "3"}], "]"}], 
           "\[LessEqual]", "c"}]}], ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"16", " ", 
            SuperscriptBox["a", "4"]}], "-", 
           RowBox[{"5", " ", 
            SuperscriptBox["a", "3"], " ", "#1"}], "-", 
           RowBox[{"30", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "-", 
           RowBox[{"5", " ", "a", " ", 
            SuperscriptBox["#1", "3"]}], "+", 
           RowBox[{"16", " ", 
            SuperscriptBox["#1", "4"]}]}], "&"}], ",", "1"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "\[Equal]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "3"], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "b"}], "-", 
             RowBox[{"a", " ", 
              SuperscriptBox["b", "2"]}], "-", 
             SuperscriptBox["b", "3"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["a", "2"]}], "-", 
                SuperscriptBox["b", "2"]}], ")"}], " ", "#1"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "a"}], "+", "b"}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "3"]}], "&"}], ",", "2"}], "]"}]}], "||", 
        RowBox[{"c", "\[Equal]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "3"]}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "b"}], "+", 
             RowBox[{"a", " ", 
              SuperscriptBox["b", "2"]}], "-", 
             SuperscriptBox["b", "3"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["a", "2"]}], "-", 
                SuperscriptBox["b", "2"]}], ")"}], " ", "#1"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"a", "+", "b"}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "3"]}], "&"}], ",", "3"}], "]"}]}]}], 
       ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "3"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "b"}], "-", 
           RowBox[{"a", " ", 
            SuperscriptBox["b", "2"]}], "-", 
           SuperscriptBox["b", "3"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "-", 
              SuperscriptBox["b", "2"]}], ")"}], " ", "#1"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b"}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "3"]}], "&"}], ",", "2"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["a", 
            SqrtBox["2"]], "<", "b"}], "&&", 
          RowBox[{
           RowBox[{"a", "+", "b"}], "<", 
           RowBox[{
            SqrtBox["3"], " ", "a"}]}]}], ")"}], "||", 
        RowBox[{
         RowBox[{
          SqrtBox["3"], " ", "a"}], "<", 
         RowBox[{"a", "+", "b"}]}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "3"]}], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "b"}], "+", 
           RowBox[{"a", " ", 
            SuperscriptBox["b", "2"]}], "-", 
           SuperscriptBox["b", "3"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "-", 
              SuperscriptBox["b", "2"]}], ")"}], " ", "#1"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b"}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "3"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b", "<", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"16", " ", 
              SuperscriptBox["a", "4"]}], "-", 
             RowBox[{"5", " ", 
              SuperscriptBox["a", "3"], " ", "#1"}], "-", 
             RowBox[{"30", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["#1", "2"]}], "-", 
             RowBox[{"5", " ", "a", " ", 
              SuperscriptBox["#1", "3"]}], "+", 
             RowBox[{"16", " ", 
              SuperscriptBox["#1", "4"]}]}], "&"}], ",", "1"}], "]"}]}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", "<", 
           FractionBox["a", 
            SqrtBox["2"]]}], "&&", 
          RowBox[{
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"16", " ", 
                SuperscriptBox["a", "4"]}], "-", 
               RowBox[{"5", " ", 
                SuperscriptBox["a", "3"], " ", "#1"}], "-", 
               RowBox[{"30", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "-", 
               RowBox[{"5", " ", "a", " ", 
                SuperscriptBox["#1", "3"]}], "+", 
               RowBox[{"16", " ", 
                SuperscriptBox["#1", "4"]}]}], "&"}], ",", "1"}], "]"}], "<", 
           "b"}]}], ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "<", 
       RowBox[{"a", "+", "b"}]}], "&&", 
      RowBox[{
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "3"]}], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "b"}], "+", 
           RowBox[{"a", " ", 
            SuperscriptBox["b", "2"]}], "-", 
           SuperscriptBox["b", "3"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "-", 
              SuperscriptBox["b", "2"]}], ")"}], " ", "#1"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b"}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "3"]}], "&"}], ",", "3"}], "]"}], 
       "\[LessEqual]", "c"}]}], ")"}]}]}],
  SequenceForm["[", 90, "]  ", 
   Or[
    And[3^Rational[1, 2] $CellContext`a == $CellContext`a + $CellContext`b, 
     Or[$CellContext`c == 
      Root[$CellContext`a^3 + $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + (-$CellContext`a^2 - \
$CellContext`b^2) # + (-$CellContext`a + $CellContext`b) #^2 + #^3& , 2], 
      And[$CellContext`c < 
       Root[$CellContext`a^3 + $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + (-$CellContext`a^2 - \
$CellContext`b^2) # + (-$CellContext`a + $CellContext`b) #^2 + #^3& , 3], 
       Root[-$CellContext`a^3 + $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + (-$CellContext`a^2 - \
$CellContext`b^2) # + ($CellContext`a + $CellContext`b) #^2 + #^3& , 
         3] <= $CellContext`c]]], 
    And[$CellContext`c <= 
     Root[$CellContext`a^3 + $CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 - $CellContext`b^3 + (-$CellContext`a^2 - $CellContext`b^2) \
# + (-$CellContext`a + $CellContext`b) #^2 + #^3& , 3], 
     Or[
      And[
      Root[$CellContext`a^3 + $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + (-$CellContext`a^2 - \
$CellContext`b^2) # + (-$CellContext`a + $CellContext`b) #^2 + #^3& , 
         2] <= $CellContext`c, 
       Or[$CellContext`b == 2^Rational[-1, 2] $CellContext`a, 
        And[$CellContext`b < 2^Rational[-1, 2] $CellContext`a, 
         Root[16 $CellContext`a^4 - 5 $CellContext`a^3 # - 
           30 $CellContext`a^2 #^2 - 5 $CellContext`a #^3 + 16 #^4& , 
           1] < $CellContext`b]]], 
      And[
      2^Rational[-1, 
           2] $CellContext`a < $CellContext`b, $CellContext`a + \
$CellContext`b < 3^Rational[1, 2] $CellContext`a, 
       Root[-$CellContext`a^3 + $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + (-$CellContext`a^2 - \
$CellContext`b^2) # + ($CellContext`a + $CellContext`b) #^2 + #^3& , 
         3] <= $CellContext`c]]], 
    And[$CellContext`b == 
     Root[16 $CellContext`a^4 - 5 $CellContext`a^3 # - 
       30 $CellContext`a^2 #^2 - 5 $CellContext`a #^3 + 16 #^4& , 1], 
     Or[$CellContext`c == 
      Root[$CellContext`a^3 + $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + (-$CellContext`a^2 - \
$CellContext`b^2) # + (-$CellContext`a + $CellContext`b) #^2 + #^3& , 
        2], $CellContext`c == 
      Root[-$CellContext`a^3 + $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + (-$CellContext`a^2 - \
$CellContext`b^2) # + ($CellContext`a + $CellContext`b) #^2 + #^3& , 3]]], 
    And[$CellContext`c == 
     Root[$CellContext`a^3 + $CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 - $CellContext`b^3 + (-$CellContext`a^2 - $CellContext`b^2) \
# + (-$CellContext`a + $CellContext`b) #^2 + #^3& , 2], 
     Or[
      And[
      2^Rational[-1, 
           2] $CellContext`a < $CellContext`b, $CellContext`a + \
$CellContext`b < 3^Rational[1, 2] $CellContext`a], 
      3^Rational[1, 2] $CellContext`a < $CellContext`a + $CellContext`b]], 
    And[$CellContext`c == 
     Root[-$CellContext`a^3 + $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + (-$CellContext`a^2 - \
$CellContext`b^2) # + ($CellContext`a + $CellContext`b) #^2 + #^3& , 3], 
     Or[$CellContext`b < 
      Root[16 $CellContext`a^4 - 5 $CellContext`a^3 # - 
        30 $CellContext`a^2 #^2 - 5 $CellContext`a #^3 + 16 #^4& , 1], 
      And[$CellContext`b < 2^Rational[-1, 2] $CellContext`a, 
       Root[16 $CellContext`a^4 - 5 $CellContext`a^3 # - 
         30 $CellContext`a^2 #^2 - 5 $CellContext`a #^3 + 16 #^4& , 
         1] < $CellContext`b]]], 
    And[3^Rational[1, 2] $CellContext`a < $CellContext`a + $CellContext`b, 
     Root[-$CellContext`a^3 + $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + (-$CellContext`a^2 - \
$CellContext`b^2) # + ($CellContext`a + $CellContext`b) #^2 + #^3& , 
       3] <= $CellContext`c]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472877471126*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"a41a95b8-6480-4e7d-b9fa-54359a0f4575"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "91", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["b", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SqrtBox["2"], " ", "a"}], "<", 
         RowBox[{"2", " ", "b"}]}], "||", 
        RowBox[{"b", "\[GreaterEqual]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["a", "4"]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
       ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "+", 
           SuperscriptBox["b", "4"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{
       RowBox[{
        SqrtBox["2"], " ", "a"}], "\[GreaterEqual]", 
       RowBox[{"2", " ", "b"}]}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[GreaterEqual]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "+", 
           SuperscriptBox["b", "4"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SqrtBox["2"], " ", "a"}], "<", 
           RowBox[{"2", " ", "b"}]}], "&&", 
          RowBox[{"b", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["a", "4"]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["b", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", "\[GreaterEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["a", "4"]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          
          RowBox[{"c", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["b", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{"b", ">", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["a", "4"]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
       ")"}]}], ")"}], "||", 
    RowBox[{"c", "\[LessEqual]", 
     RowBox[{"Root", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"]}], "+", 
         SuperscriptBox["b", "4"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["#1", "2"]}], "+", 
         SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}]}],
  SequenceForm["[", 91, "]  ", 
   Or[
    And[$CellContext`c == 
     Root[$CellContext`a^4 - 
       2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
       2 $CellContext`b^2 #^2 + #^4& , 3], 
     Or[2^Rational[1, 2] $CellContext`a < 2 $CellContext`b, $CellContext`b >= 
      Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3]]], 
    And[$CellContext`c == 
     Root[$CellContext`a^4 + $CellContext`b^4 + ((-2) $CellContext`a^2 - 
         2 $CellContext`b^2) #^2 + #^4& , 3], 2^Rational[1, 2] $CellContext`a >= 
     2 $CellContext`b], 
    And[$CellContext`c >= 
     Root[$CellContext`a^4 + $CellContext`b^4 + ((-2) $CellContext`a^2 - 
         2 $CellContext`b^2) #^2 + #^4& , 3], 
     Or[
      And[
      2^Rational[1, 2] $CellContext`a < 2 $CellContext`b, $CellContext`b < 
       Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
         3], $CellContext`c <= 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
         2 $CellContext`b^2 #^2 + #^4& , 4]], 
      And[$CellContext`b >= 
       Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
         3], $CellContext`c < 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
         2 $CellContext`b^2 #^2 + #^4& , 4]], $CellContext`b > 
      Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
        3]]], $CellContext`c <= 
    Root[$CellContext`a^4 - 
      2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
      2 $CellContext`a^2 #^2 + #^4& , 3]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472877902122*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"bd8dfe33-ab5b-4a1c-8b2d-6797365a6e43"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "92", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}],
  SequenceForm[
  "[", 92, "]  ", ($CellContext`a^2 - $CellContext`b^2)^
    Rational[1, 2] <= $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472877983533*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"4c130c9a-1d6e-4082-ab4a-9047f089671c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "93", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", "\[GreaterEqual]", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                SuperscriptBox["b", "2"]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
         "\[LessEqual]", "c", "\[LessEqual]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           SuperscriptBox["b", "2"]}]], "\[Equal]", "c"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", "<", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{"b", "<", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                SuperscriptBox["b", "2"]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
         "\[LessEqual]", "c", "\[LessEqual]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
        RowBox[{"c", "\[Equal]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c", "\[LessEqual]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}]}], 
       ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                SuperscriptBox["b", "2"]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
         "\[LessEqual]", "c", "\[LessEqual]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
        RowBox[{"c", "\[Equal]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c", "<", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}]}], 
       ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], "<", "b", 
       "<", 
       FractionBox["a", 
        SqrtBox["3"]]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                SuperscriptBox["b", "2"]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
         "\[LessEqual]", "c", "\[LessEqual]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
        RowBox[{"c", "\[Equal]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}], ")"}]}], 
     ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", "\[Equal]", 
       FractionBox["a", 
        SqrtBox["3"]]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                SuperscriptBox["b", "2"]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
         "\[LessEqual]", "c", "\[LessEqual]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}], ")"}]}], 
     ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["a", 
        SqrtBox["3"]], "<", "b", "<", 
       FractionBox[
        RowBox[{
         SqrtBox["3"], " ", "a"}], "2"]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                SuperscriptBox["b", "2"]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
         "\[LessEqual]", "c", "\[LessEqual]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
        RowBox[{"c", "\[Equal]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}], ")"}]}], 
     ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "\[Equal]", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                SuperscriptBox["b", "2"]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
         "\[LessEqual]", "c", "\[LessEqual]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}], ")"}]}], 
     ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "<", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                SuperscriptBox["b", "2"]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
         "\[LessEqual]", "c", "\[LessEqual]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           SuperscriptBox["b", "2"]}]], "\[Equal]", "c"}], "||", 
        RowBox[{
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
         "\[LessEqual]", "c"}]}], ")"}]}], ")"}]}]}],
  SequenceForm["[", 93, "]  ", 
   Or[
    And[$CellContext`a >= 2 $CellContext`b, 
     Or[
      Inequality[
       Root[$CellContext`a^4 - 
        2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3], 
       LessEqual, $CellContext`c, LessEqual, 
       Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + \
$CellContext`b^4 + ((-2) $CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 
        3]], ($CellContext`a^2 - $CellContext`b^2)^
       Rational[1, 2] == $CellContext`c]], 
    And[$CellContext`a < 2 $CellContext`b, $CellContext`b < 
     Root[$CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3], 
     Or[
      Inequality[
       Root[$CellContext`a^4 - 
        2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3], 
       LessEqual, $CellContext`c, LessEqual, 
       Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + \
$CellContext`b^4 + ((-2) $CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 
        3]], $CellContext`c == 
      Root[$CellContext`a^4 - 
        2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + \
(-$CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 3], 
      Inequality[($CellContext`a^2 - $CellContext`b^2)^Rational[1, 2], 
       LessEqual, $CellContext`c, LessEqual, 
       Root[$CellContext`a^4 - 
        2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + \
(-$CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 4]]]], 
    And[$CellContext`b == 
     Root[$CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3], 
     Or[
      Inequality[
       Root[$CellContext`a^4 - 
        2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3], 
       LessEqual, $CellContext`c, LessEqual, 
       Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + \
$CellContext`b^4 + ((-2) $CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 
        3]], $CellContext`c == 
      Root[$CellContext`a^4 - 
        2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + \
(-$CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 3], 
      Inequality[($CellContext`a^2 - $CellContext`b^2)^Rational[1, 2], 
       LessEqual, $CellContext`c, Less, 
       Root[$CellContext`a^4 - 
        2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + \
(-$CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 4]]]], 
    And[
     Inequality[
      Root[$CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3], 
      Less, $CellContext`b, Less, 3^Rational[-1, 2] $CellContext`a], 
     Or[
      Inequality[
       Root[$CellContext`a^4 - 
        2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3], 
       LessEqual, $CellContext`c, LessEqual, 
       Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + \
$CellContext`b^4 + ((-2) $CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 
        3]], $CellContext`c == 
      Root[$CellContext`a^4 - 
        2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + \
(-$CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 
        3], ($CellContext`a^2 - $CellContext`b^2)^
       Rational[1, 2] <= $CellContext`c]], 
    And[$CellContext`b == 3^Rational[-1, 2] $CellContext`a, 
     Or[
      Inequality[
       Root[$CellContext`a^4 - 
        2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3], 
       LessEqual, $CellContext`c, LessEqual, 
       Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + \
$CellContext`b^4 + ((-2) $CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 
        3]], ($CellContext`a^2 - $CellContext`b^2)^
       Rational[1, 2] <= $CellContext`c]], 
    And[
     Inequality[
     3^Rational[-1, 2] $CellContext`a, Less, $CellContext`b, Less, 
      Rational[1, 2] 3^Rational[1, 2] $CellContext`a], 
     Or[
      Inequality[
       Root[$CellContext`a^4 - 
        2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3], 
       LessEqual, $CellContext`c, LessEqual, 
       Root[$CellContext`a^4 - 
        2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + \
(-$CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 3]], $CellContext`c == 
      Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + \
$CellContext`b^4 + ((-2) $CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 
        3], ($CellContext`a^2 - $CellContext`b^2)^
       Rational[1, 2] <= $CellContext`c]], 
    And[3^Rational[1, 2] $CellContext`a == 2 $CellContext`b, 
     Or[
      Inequality[
       Root[$CellContext`a^4 - 
        2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3], 
       LessEqual, $CellContext`c, LessEqual, 
       Root[$CellContext`a^4 - 
        2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + \
(-$CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 
        3]], ($CellContext`a^2 - $CellContext`b^2)^
       Rational[1, 2] <= $CellContext`c]], 
    And[3^Rational[1, 2] $CellContext`a < 2 $CellContext`b, 
     Or[
      Inequality[
       Root[$CellContext`a^4 - 
        2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3], 
       LessEqual, $CellContext`c, LessEqual, 
       Root[$CellContext`a^4 - 
        2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + \
(-$CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 
        3]], ($CellContext`a^2 - $CellContext`b^2)^
       Rational[1, 2] == $CellContext`c, 
      Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + \
$CellContext`b^4 + ((-2) $CellContext`a^2 - 2 $CellContext`b^2) #^2 + #^4& , 
        3] <= $CellContext`c]]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472879545233*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"7d79df75-d217-490b-ad67-db59297cc874"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "94", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       RowBox[{"a", " ", "b"}], "+", 
       SuperscriptBox["b", "2"]}]], "\[Equal]", "c"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "\[LessEqual]", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{
       RowBox[{
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["b", "2"]}]}]], "+", 
        RowBox[{"2", " ", "c"}]}], "\[Equal]", "a"}]}], ")"}], "||", 
    RowBox[{
     SqrtBox[
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox["a", "2"]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["b", "2"]}]}]], "\[GreaterEqual]", 
     RowBox[{"b", "+", 
      RowBox[{"2", " ", "c"}]}]}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "<", 
       RowBox[{"2", " ", "b"}]}], "&&", 
      RowBox[{
       RowBox[{"a", "+", 
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["b", "2"]}]}]]}], "\[Equal]", 
       RowBox[{"2", " ", "c"}]}]}], ")"}]}]}],
  SequenceForm["[", 94, "]  ", 
   Or[($CellContext`a^2 - $CellContext`a $CellContext`b + $CellContext`b^2)^
     Rational[1, 2] == $CellContext`c, 
    And[3^Rational[1, 2] $CellContext`a <= 
     2 $CellContext`b, ((-3) $CellContext`a^2 + 4 $CellContext`b^2)^
       Rational[1, 2] + 2 $CellContext`c == $CellContext`a], (
      4 $CellContext`a^2 - 3 $CellContext`b^2)^
     Rational[1, 2] >= $CellContext`b + 2 $CellContext`c, 
    And[3^Rational[1, 2] $CellContext`a < 
     2 $CellContext`b, $CellContext`a + ((-3) $CellContext`a^2 + 
        4 $CellContext`b^2)^Rational[1, 2] == 2 $CellContext`c]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.8474728803692427`*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"5ed444a5-69fd-4490-ba06-1376311a8b4a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "95", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], "\[LessEqual]", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"]}]], " ", "c"}]}]}], "&&", 
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "\[GreaterEqual]", 
       RowBox[{"3", " ", "b"}]}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["a", 
        SqrtBox["3"]], "<", "b"}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], "\[Equal]", 
         RowBox[{
          SuperscriptBox["b", "2"], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"]}]], " ", "c"}]}]}], "||", 
        RowBox[{
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                SuperscriptBox["b", "2"]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
         "\[LessEqual]", "c"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              SuperscriptBox["b", "2"]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"b", "<", 
       FractionBox["a", 
        SqrtBox["3"]]}]}], ")"}]}]}],
  SequenceForm["[", 95, "]  ", 
   Or[
    And[$CellContext`a^2 <= $CellContext`b^2 + ($CellContext`a^2 + \
$CellContext`b^2)^Rational[1, 2] $CellContext`c, 
     3^Rational[1, 2] $CellContext`a >= 3 $CellContext`b], 
    And[3^Rational[-1, 2] $CellContext`a < $CellContext`b, 
     Or[$CellContext`a^2 == $CellContext`b^2 + ($CellContext`a^2 + \
$CellContext`b^2)^Rational[1, 2] $CellContext`c, 
      Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3] <= $CellContext`c]], 
    And[$CellContext`c == 
     Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3], $CellContext`b < 
     3^Rational[-1, 2] $CellContext`a]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472880590579*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"f2c86484-3c0f-49a4-90f3-d047d49ad326"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "96", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox["2"], " ", "a"}], "\[Equal]", 
       RowBox[{"a", "+", "b"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], "\[Equal]", 
         RowBox[{
          SuperscriptBox["b", "2"], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"]}]], " ", "c"}]}]}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["a", "2"]}], "-", 
                  SuperscriptBox["b", "2"]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          
          RowBox[{
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
           "\[LessEqual]", "c"}]}], ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], "\[Equal]", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"]}]], " ", "c"}]}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "+", "b"}], "<", 
         RowBox[{
          SqrtBox["2"], " ", "a"}]}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SqrtBox["2"], " ", "a"}], "<", 
           RowBox[{"a", "+", "b"}]}], "&&", 
          RowBox[{"b", "<", 
           FractionBox["a", 
            SqrtBox["3"]]}]}], ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", "\[Equal]", 
       FractionBox["a", 
        SqrtBox["3"]]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "\[Equal]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "+", 
             SuperscriptBox["b", "4"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["b", "2"]}]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            RowBox[{
             SqrtBox[
              RowBox[{
               SuperscriptBox["a", "2"], "+", 
               SuperscriptBox["b", "2"]}]], " ", "c"}]}], "\[LessEqual]", 
           SuperscriptBox["a", "2"]}], "&&", 
          RowBox[{
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
           "\[LessEqual]", "c"}]}], ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["a", "4"]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "\[Equal]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             SuperscriptBox["b", "4"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["b", "2"], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["b", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}], "&&", 
          
          RowBox[{
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "+", 
               SuperscriptBox["b", "4"], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["a", "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["b", "2"]}]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
           "\[LessEqual]", "c"}]}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            RowBox[{
             SqrtBox[
              RowBox[{
               SuperscriptBox["a", "2"], "+", 
               SuperscriptBox["b", "2"]}]], " ", "c"}]}], "\[LessEqual]", 
           SuperscriptBox["a", "2"]}], "&&", 
          RowBox[{
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
           "\[LessEqual]", "c"}]}], ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["b", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["a", 
            SqrtBox["2"]], "<", "b"}], "&&", 
          RowBox[{"b", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["a", "4"]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["a", "4"]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], "<", 
         "b"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "+", 
           SuperscriptBox["b", "4"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "+", "b"}], "<", 
         RowBox[{
          SqrtBox["2"], " ", "a"}]}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["a", 
            SqrtBox["3"]], "<", "b"}], "&&", 
          RowBox[{"b", "\[LessEqual]", 
           FractionBox["a", 
            SqrtBox["2"]]}]}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SqrtBox["2"], " ", "a"}], "<", 
           RowBox[{"a", "+", "b"}]}], "&&", 
          RowBox[{"b", "<", 
           FractionBox["a", 
            SqrtBox["3"]]}]}], ")"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              SuperscriptBox["b", "2"]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["a", 
            SqrtBox["2"]], "<", "b"}], "&&", 
          RowBox[{"b", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["a", "4"]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["a", 
            SqrtBox["3"]], "<", "b"}], "&&", 
          RowBox[{"b", "\[LessEqual]", 
           FractionBox["a", 
            SqrtBox["2"]]}]}], ")"}], "||", 
        RowBox[{
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["a", "4"]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], "<", 
         "b"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
       "\[LessEqual]", "c"}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            RowBox[{
             SqrtBox[
              RowBox[{
               SuperscriptBox["a", "2"], "+", 
               SuperscriptBox["b", "2"]}]], " ", "c"}]}], "\[LessEqual]", 
           SuperscriptBox["a", "2"]}], "&&", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FractionBox["a", 
                SqrtBox["2"]], "<", "b"}], "&&", 
              RowBox[{"b", "<", 
               RowBox[{"Root", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"2", " ", 
                    SuperscriptBox["a", "4"]}], "-", 
                   RowBox[{"4", " ", 
                    SuperscriptBox["a", "2"], " ", 
                    SuperscriptBox["#1", "2"]}], "+", 
                   SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
             ")"}], "||", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FractionBox["a", 
                SqrtBox["3"]], "<", "b"}], "&&", 
              RowBox[{"b", "\[LessEqual]", 
               FractionBox["a", 
                SqrtBox["2"]]}]}], ")"}], "||", 
            RowBox[{
             RowBox[{"Root", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["a", "4"]}], "-", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["a", "2"], " ", 
                  SuperscriptBox["#1", "2"]}], "+", 
                 SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], "<", 
             "b"}]}], ")"}]}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["a", "2"]}], "-", 
                  SuperscriptBox["b", "2"]}], ")"}], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SqrtBox["2"], " ", "a"}], "<", 
               RowBox[{"a", "+", "b"}]}], "&&", 
              RowBox[{"b", "<", 
               FractionBox["a", 
                SqrtBox["3"]]}]}], ")"}], "||", 
            RowBox[{
             RowBox[{"a", "+", "b"}], "<", 
             RowBox[{
              SqrtBox["2"], " ", "a"}]}]}], ")"}]}], ")"}]}], ")"}]}], ")"}], 
    "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "+", 
           SuperscriptBox["b", "4"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["b", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], 
       "\[LessEqual]", "c"}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["a", 
            SqrtBox["2"]], "<", "b"}], "&&", 
          RowBox[{"b", "<", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["a", "4"]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
          
          RowBox[{"c", "\[LessEqual]", 
           RowBox[{"Root", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["b", "2"]}], "+", 
               SuperscriptBox["b", "4"], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["b", "2"], " ", 
                SuperscriptBox["#1", "2"]}], "+", 
               SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}]}], 
         ")"}], "||", 
        RowBox[{
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["a", "4"]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}], "<", 
         "b"}]}], ")"}]}], ")"}]}]}],
  SequenceForm["[", 96, "]  ", 
   Or[
    And[2^Rational[1, 2] $CellContext`a == $CellContext`a + $CellContext`b, 
     Or[$CellContext`a^2 == $CellContext`b^2 + ($CellContext`a^2 + \
$CellContext`b^2)^Rational[1, 2] $CellContext`c, 
      And[$CellContext`c <= 
       Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3], 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
         2 $CellContext`a^2 #^2 + #^4& , 3] <= $CellContext`c]]], 
    And[$CellContext`a^2 == $CellContext`b^2 + ($CellContext`a^2 + \
$CellContext`b^2)^Rational[1, 2] $CellContext`c, 
     Or[$CellContext`a + $CellContext`b < 2^Rational[1, 2] $CellContext`a, 
      And[
      2^Rational[
          1, 2] $CellContext`a < $CellContext`a + $CellContext`b, \
$CellContext`b < 3^Rational[-1, 2] $CellContext`a]]], 
    And[$CellContext`b == 3^Rational[-1, 2] $CellContext`a, 
     Or[$CellContext`c == 
      Root[$CellContext`a^4 + $CellContext`b^4 + ((-2) $CellContext`a^2 - 
          2 $CellContext`b^2) #^2 + #^4& , 3], 
      And[$CellContext`b^2 + ($CellContext`a^2 + $CellContext`b^2)^
          Rational[1, 2] $CellContext`c <= $CellContext`a^2, 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
         2 $CellContext`a^2 #^2 + #^4& , 3] <= $CellContext`c]]], 
    And[$CellContext`b == 
     Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3], 
     Or[$CellContext`c == 
      Root[$CellContext`a^4 - 
        2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
        2 $CellContext`b^2 #^2 + #^4& , 3], 
      And[$CellContext`c < 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
         2 $CellContext`b^2 #^2 + #^4& , 4], 
       Root[$CellContext`a^4 + $CellContext`b^4 + ((-2) $CellContext`a^2 - 
           2 $CellContext`b^2) #^2 + #^4& , 3] <= $CellContext`c], 
      And[$CellContext`b^2 + ($CellContext`a^2 + $CellContext`b^2)^
          Rational[1, 2] $CellContext`c <= $CellContext`a^2, 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
         2 $CellContext`a^2 #^2 + #^4& , 3] <= $CellContext`c]]], 
    And[$CellContext`c == 
     Root[$CellContext`a^4 - 
       2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
       2 $CellContext`b^2 #^2 + #^4& , 3], 
     Or[
      And[
      2^Rational[-1, 2] $CellContext`a < $CellContext`b, $CellContext`b < 
       Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3]], 
      Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
        3] < $CellContext`b]], 
    And[$CellContext`c == 
     Root[$CellContext`a^4 + $CellContext`b^4 + ((-2) $CellContext`a^2 - 
         2 $CellContext`b^2) #^2 + #^4& , 3], 
     Or[$CellContext`a + $CellContext`b < 2^Rational[1, 2] $CellContext`a, 
      And[
      3^Rational[-1, 2] $CellContext`a < $CellContext`b, $CellContext`b <= 
       2^Rational[-1, 2] $CellContext`a], 
      And[
      2^Rational[
          1, 2] $CellContext`a < $CellContext`a + $CellContext`b, \
$CellContext`b < 3^Rational[-1, 2] $CellContext`a]]], 
    And[$CellContext`c == 
     Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3], 
     Or[
      And[
      2^Rational[-1, 2] $CellContext`a < $CellContext`b, $CellContext`b < 
       Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3]], 
      And[
      3^Rational[-1, 2] $CellContext`a < $CellContext`b, $CellContext`b <= 
       2^Rational[-1, 2] $CellContext`a], 
      Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
        3] < $CellContext`b]], 
    And[Root[$CellContext`a^4 - 
       2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
       2 $CellContext`a^2 #^2 + #^4& , 3] <= $CellContext`c, 
     Or[
      And[$CellContext`b^2 + ($CellContext`a^2 + $CellContext`b^2)^
          Rational[1, 2] $CellContext`c <= $CellContext`a^2, 
       Or[
        And[
        2^Rational[-1, 2] $CellContext`a < $CellContext`b, $CellContext`b < 
         Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 3]], 
        And[
        3^Rational[-1, 2] $CellContext`a < $CellContext`b, $CellContext`b <= 
         2^Rational[-1, 2] $CellContext`a], 
        Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
          3] < $CellContext`b]], 
      And[$CellContext`c <= 
       Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3], 
       Or[
        And[
        2^Rational[
            1, 2] $CellContext`a < $CellContext`a + $CellContext`b, \
$CellContext`b < 
         3^Rational[-1, 2] $CellContext`a], $CellContext`a + $CellContext`b < 
        2^Rational[1, 2] $CellContext`a]]]], 
    And[Root[$CellContext`a^4 + $CellContext`b^4 + ((-2) $CellContext`a^2 - 
         2 $CellContext`b^2) #^2 + #^4& , 3] <= $CellContext`c, 
     Or[
      And[
      2^Rational[-1, 2] $CellContext`a < $CellContext`b, $CellContext`b < 
       Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
         3], $CellContext`c <= 
       Root[$CellContext`a^4 - 
         2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
         2 $CellContext`b^2 #^2 + #^4& , 4]], 
      Root[2 $CellContext`a^4 - 4 $CellContext`a^2 #^2 + #^4& , 
        3] < $CellContext`b]]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472882641706*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"cd97ee47-65af-4b83-936a-b629c8de2fa7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "97", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["a", "2"]}], "-", 
              SuperscriptBox["b", "2"]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "<", 
       RowBox[{"3", " ", "b"}]}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], ">", 
       RowBox[{"3", " ", "b"}]}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], "\[Equal]", 
         RowBox[{
          SuperscriptBox["b", "2"], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"]}]], " ", "c"}]}]}], "||", 
        RowBox[{"c", "\[LessEqual]", 
         RowBox[{"Root", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "4"], "-", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox["a", "2"]}], "-", 
                SuperscriptBox["b", "2"]}], ")"}], " ", 
              SuperscriptBox["#1", "2"]}], "+", 
             SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}]}], 
       ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "a"}], "\[LessEqual]", 
       RowBox[{"3", " ", "b"}]}], "&&", 
      RowBox[{
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"]}]], " ", "c"}]}], "\[LessEqual]", 
       SuperscriptBox["a", "2"]}]}], ")"}], "||", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["b", "2"]}]], "\[LessEqual]", "c"}]}]}],
  SequenceForm["[", 97, "]  ", 
   Or[
    And[$CellContext`c == 
     Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3], 
     3^Rational[1, 2] $CellContext`a < 3 $CellContext`b], 
    And[3^Rational[1, 2] $CellContext`a > 3 $CellContext`b, 
     Or[$CellContext`a^2 == $CellContext`b^2 + ($CellContext`a^2 + \
$CellContext`b^2)^Rational[1, 2] $CellContext`c, $CellContext`c <= 
      Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + ((-2) \
$CellContext`a^2 - $CellContext`b^2) #^2 + #^4& , 3]]], 
    And[3^Rational[1, 2] $CellContext`a <= 
     3 $CellContext`b, $CellContext`b^2 + ($CellContext`a^2 + \
$CellContext`b^2)^
        Rational[
         1, 2] $CellContext`c <= $CellContext`a^2], ($CellContext`a^2 - \
$CellContext`b^2)^Rational[1, 2] <= $CellContext`c]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472884355715*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"f6109210-2356-488b-9c24-33293306c387"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "98", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "-", 
           RowBox[{
            SuperscriptBox["b", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "3"}], "]"}]}], "&&", 
      RowBox[{"b", "\[GreaterEqual]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            SuperscriptBox["a", "4"]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "2"}], "]"}]}]}], ")"}], "||", 
    RowBox[{
     SqrtBox[
      FractionBox[
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox["b", "4"]}], 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}]]], "\[Equal]", "c"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "\[Equal]", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "-", 
           RowBox[{
            SuperscriptBox["b", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}]}], "&&", 
      RowBox[{"b", ">", 
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            SuperscriptBox["a", "4"]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           SuperscriptBox["#1", "4"]}], "&"}], ",", "2"}], "]"}]}]}], 
     ")"}]}]}],
  SequenceForm["[", 98, "]  ", 
   Or[
    And[$CellContext`c == 
     Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^2 #^2 + #^4& , 3], $CellContext`b >= 
     Root[(-4) $CellContext`a^4 + 4 $CellContext`a^2 #^2 + #^4& , 
       2]], (($CellContext`a^2 + $CellContext`b^2)^(-1) ($CellContext`a^4 + \
$CellContext`b^4))^Rational[1, 2] == $CellContext`c, 
    And[$CellContext`c == 
     Root[$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^2 #^2 + #^4& , 4], $CellContext`b > 
     Root[(-4) $CellContext`a^4 + 4 $CellContext`a^2 #^2 + #^4& , 2]]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472885381398*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"597cf909-f32b-4b95-91ba-552a5c17841c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "99", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"a", "<", 
     RowBox[{"2", " ", "b"}]}], "&&", 
    RowBox[{"b", "\[Equal]", "c"}]}]}],
  SequenceForm["[", 99, "]  ", 
   And[$CellContext`a < 2 $CellContext`b, $CellContext`b == $CellContext`c]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.84747288545929*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"40bfe940-af9e-4f4b-9522-45965b561d2e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\"]  \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"a", "<", 
     RowBox[{"2", " ", "b"}]}], "&&", 
    RowBox[{"b", "\[Equal]", "c"}]}]}],
  SequenceForm["[", 100, "]  ", 
   And[$CellContext`a < 2 $CellContext`b, $CellContext`b == $CellContext`c]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.847373753715374*^9, 3.847373783214162*^9}, 
   3.847373828724798*^9, 3.847374066902912*^9, 3.847429610722371*^9, 
   3.847455124598806*^9, 3.847472885460453*^9},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"d48bf212-58fd-4e3c-a05f-c6a4020dddc8"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
   RowBox[{"x", "[", "87", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"triang", "=", 
   RowBox[{
    RowBox[{"a", ">", "0"}], "&&", 
    RowBox[{"b", ">", "0"}], "&&", 
    RowBox[{"c", ">", "0"}], "&&", 
    RowBox[{
     RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
    RowBox[{
     RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
    RowBox[{
     RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"red", "=", 
   RowBox[{"Reduce", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"u", ">=", "0"}], "&&", 
          RowBox[{"v", ">=", "0"}], "&&", 
          RowBox[{"w", ">=", "0"}]}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"u", "<=", "0"}], "&&", 
          RowBox[{"v", "<=", "0"}], "&&", 
          RowBox[{"w", "<=", "0"}]}], ")"}]}], ")"}], "&&", "triang"}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"simp", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"red", ",", "triang"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.847432653859881*^9, 3.847432693475046*^9}},
 CellLabel->"In[59]:=",ExpressionUUID->"faeb4f4c-b9bf-4e73-b248-f80d8d01448c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SqrtBox["5"], " ", "a"}], "+", 
      RowBox[{"2", " ", "b"}]}], ">", 
     RowBox[{"3", " ", "a"}]}], "&&", 
    RowBox[{
     RowBox[{
      SqrtBox["5"], " ", "a"}], ">", 
     RowBox[{"a", "+", 
      RowBox[{"2", " ", "b"}]}]}], "&&", 
    RowBox[{
     FractionBox[
      RowBox[{"a", " ", "b"}], 
      RowBox[{"a", "-", "b"}]], "\[GreaterEqual]", "c"}]}], ")"}], "||", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      SqrtBox["5"], " ", "a"}], "\[Equal]", 
     RowBox[{"a", "+", 
      RowBox[{"2", " ", "b"}]}]}], "&&", 
    RowBox[{
     FractionBox[
      RowBox[{"a", " ", "b"}], 
      RowBox[{"a", "-", "b"}]], ">", "c"}]}], ")"}], "||", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      SqrtBox["5"], " ", "a"}], "<", 
     RowBox[{"a", "+", 
      RowBox[{"2", " ", "b"}]}]}], "&&", 
    RowBox[{
     RowBox[{"a", "+", 
      RowBox[{
       SqrtBox["5"], " ", "a"}]}], ">", 
     RowBox[{"2", " ", "b"}]}], "&&", 
    RowBox[{
     FractionBox[
      RowBox[{"a", " ", "b"}], 
      RowBox[{"a", "+", "b"}]], "\[LessEqual]", "c"}]}], ")"}], "||", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "+", 
      RowBox[{
       SqrtBox["5"], " ", "a"}]}], "\[Equal]", 
     RowBox[{"2", " ", "b"}]}], "&&", 
    RowBox[{
     FractionBox[
      RowBox[{"a", " ", "b"}], 
      RowBox[{"a", "+", "b"}]], "<", "c"}]}], ")"}], "||", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "+", 
      RowBox[{
       SqrtBox["5"], " ", "a"}]}], "<", 
     RowBox[{"2", " ", "b"}]}], "&&", 
    RowBox[{
     RowBox[{"2", " ", "b"}], "<", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "+", 
        SqrtBox["5"]}], ")"}], " ", "a"}]}], "&&", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"a", " ", "b"}], 
       RowBox[{"a", "-", "b"}]], "+", "c"}], "\[LessEqual]", "0"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.8474326950738287`*^9, 3.847455158254168*^9, 
  3.8474728872499933`*^9},
 CellLabel->"Out[62]=",ExpressionUUID->"4de6b962-8e7f-44e6-9527-46df7d91c744"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
   RowBox[{"x", "[", "87", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"triang", "=", 
   RowBox[{
    RowBox[{"a", ">", "0"}], "&&", 
    RowBox[{"b", ">", "0"}], "&&", 
    RowBox[{"c", ">", "0"}], "&&", 
    RowBox[{
     RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
    RowBox[{
     RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
    RowBox[{
     RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"red", "=", 
   RowBox[{"Reduce", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"u", ">=", "0"}], "&&", 
          RowBox[{"v", ">=", "0"}], "&&", 
          RowBox[{"w", ">=", "0"}]}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"u", "<=", "0"}], "&&", 
          RowBox[{"v", "<=", "0"}], "&&", 
          RowBox[{"w", "<=", "0"}]}], ")"}]}], ")"}], "&&", "triang", "&&", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3", "-", 
          RowBox[{"Sqrt", "[", "5", "]"}]}], ")"}], "/", "2"}], "<", 
       RowBox[{"b", "/", "a"}], "<", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", "2"}]}]}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"simp", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"red", ",", 
    RowBox[{"triang", "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", "-", 
         RowBox[{"Sqrt", "[", "5", "]"}]}], ")"}], "/", "2"}], "<", 
      RowBox[{"b", "/", "a"}], "<", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Sqrt", "[", "5", "]"}], "-", "1"}], ")"}], "/", "2"}]}]}]}],
    "]"}]}]}], "Input",
 CellChangeTimes->{{3.84743330694917*^9, 3.847433347592145*^9}, {
  3.8474334765833073`*^9, 3.8474334980344553`*^9}},
 CellLabel->"In[63]:=",ExpressionUUID->"2e0cc489-f98a-40c9-8a4e-d4c12c6f382b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"b", " ", 
   RowBox[{"(", 
    RowBox[{"a", "+", "c"}], ")"}]}], "\[GreaterEqual]", 
  RowBox[{"a", " ", "c"}]}]], "Output",
 CellChangeTimes->{{3.8474333358788652`*^9, 3.847433349207869*^9}, {
   3.847433486430522*^9, 3.847433499117284*^9}, 3.8474551584845963`*^9, 
   3.847472887518731*^9},
 CellLabel->"Out[66]=",ExpressionUUID->"34b5d89c-580b-4e1d-9bef-c93c3ecc535a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
   RowBox[{"x", "[", "87", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"triang", "=", 
   RowBox[{
    RowBox[{"a", ">", "0"}], "&&", 
    RowBox[{"b", ">", "0"}], "&&", 
    RowBox[{"c", ">", "0"}], "&&", 
    RowBox[{
     RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
    RowBox[{
     RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
    RowBox[{
     RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"red", "=", 
   RowBox[{"Reduce", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"u", ">=", "0"}], "&&", 
          RowBox[{"v", ">=", "0"}], "&&", 
          RowBox[{"w", ">=", "0"}]}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"u", "<=", "0"}], "&&", 
          RowBox[{"v", "<=", "0"}], "&&", 
          RowBox[{"w", "<=", "0"}]}], ")"}]}], ")"}], "&&", "triang", "&&", 
      RowBox[{
       RowBox[{"1", "/", "a"}], "<=", 
       RowBox[{"1", "/", "b"}], "<=", 
       RowBox[{"1", "/", "c"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"simp", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"red", ",", 
    RowBox[{"triang", "&&", 
     RowBox[{
      RowBox[{"1", "/", "a"}], "<=", 
      RowBox[{"1", "/", "b"}], "<=", 
      RowBox[{"1", "/", "c"}]}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.847433644934697*^9, 3.8474336645696993`*^9}, {
  3.847433715199503*^9, 3.847433735110105*^9}, {3.847433856203143*^9, 
  3.8474338616895647`*^9}},
 CellLabel->"In[67]:=",ExpressionUUID->"c0762316-a112-49a8-9065-f9de213fdac6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"a", " ", "b"}], 
    RowBox[{"a", "+", "b"}]], "\[LessEqual]", "c"}], "||", 
  RowBox[{
   RowBox[{
    SqrtBox["5"], " ", "a"}], "\[GreaterEqual]", 
   RowBox[{"a", "+", 
    RowBox[{"2", " ", "b"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.84743366784914*^9, {3.8474337230105133`*^9, 3.84743373637818*^9}, 
   3.847433863874267*^9, 3.847455158843142*^9, 3.847472887866604*^9},
 CellLabel->"Out[70]=",ExpressionUUID->"b5b80419-2d9c-4958-ae2a-de3252b15b33"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"x", "[", "35", "]"}], "/.", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"4", 
          RowBox[{"a", "^", "2"}]}], "-", 
         RowBox[{"3", 
          RowBox[{"b", "^", "2"}]}]}], "]"}], "-", "b"}], ")"}], "/", 
     "2"}]}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.847456320412816*^9, 3.847456380888707*^9}},
 CellLabel->"In[71]:=",ExpressionUUID->"68cc9844-0c52-4c79-9c06-40bfc334faae"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    RowBox[{"(", 
     RowBox[{"a", "-", "b"}], ")"}], " ", 
    SuperscriptBox["b", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", "a"}], "+", 
      RowBox[{"3", " ", "b"}], "+", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"]}]}]]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "8"]}], " ", "b", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", 
       SqrtBox[
        RowBox[{
         RowBox[{"4", " ", 
          SuperscriptBox["a", "2"]}], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["b", "2"]}]}]]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "a"}], "+", 
      RowBox[{"3", " ", "b"}], "+", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"]}]}]]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.847456374504896*^9, 3.847456381899576*^9}, 
   3.847472887950933*^9},
 CellLabel->"Out[71]=",ExpressionUUID->"b3414028-b3a7-49d7-b4ff-f44919f99dde"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"x", "[", "50", "]"}], "/.", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"4", 
          RowBox[{"a", "^", "2"}]}], "-", 
         RowBox[{"3", 
          RowBox[{"b", "^", "2"}]}]}], "]"}], "-", "b"}], ")"}], "/", 
     "2"}]}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.847456390585434*^9, 3.847456390816977*^9}, {
  3.847457165509254*^9, 3.847457175181533*^9}},
 CellLabel->"In[72]:=",ExpressionUUID->"f66f7ce8-78d7-4364-9dfb-22b75b8fd6e5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    FractionBox["3", "2"], " ", 
    SuperscriptBox["b", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["b", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["a", "2"]}], "+", 
      RowBox[{"b", " ", 
       RowBox[{"(", 
        RowBox[{"b", "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SuperscriptBox["a", "2"]}], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["b", "2"]}]}]]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["3", "2"], " ", 
    SuperscriptBox["b", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["b", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", "b"}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SuperscriptBox["a", "2"]}], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["b", "2"]}]}]]}], ")"}]}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.847456391936554*^9, {3.847457168002767*^9, 3.847457176287486*^9}, 
   3.8474728880388813`*^9},
 CellLabel->"Out[72]=",ExpressionUUID->"4db20855-08b1-4699-8f8b-253e2f5b9b5d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"x", "[", "79", "]"}], "/.", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"4", 
          RowBox[{"a", "^", "2"}]}], "-", 
         RowBox[{"3", 
          RowBox[{"b", "^", "2"}]}]}], "]"}], "-", "b"}], ")"}], "/", 
     "2"}]}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.847456402381076*^9, 3.847456415761067*^9}},
 CellLabel->"In[73]:=",ExpressionUUID->"d22c2c4d-adec-4ea0-8139-3eed2bf0fb07"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["3", "2"], " ", "b", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "a"}], "+", "b", "+", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"]}]}]]}], ")"}]}], ",", "0", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.847456405462511*^9, 3.847456416595714*^9}, 
   3.84747288812357*^9},
 CellLabel->"Out[73]=",ExpressionUUID->"84dd8487-13f0-4a69-a3cf-ea503c78c6b2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"x", "[", "3", "]"}], "/.", 
   RowBox[{"a", "\[Rule]", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{"b", "^", "2"}], "+", 
      RowBox[{"c", "^", "2"}]}], "]"}]}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{3.847457701546645*^9},
 CellLabel->"In[74]:=",ExpressionUUID->"f23fa17f-b3e2-4fcf-b441-c7086d7cab6f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["c", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["c", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.847457702027494*^9, 3.847472888131939*^9},
 CellLabel->"Out[74]=",ExpressionUUID->"d4549bb3-5475-4c06-90b7-62b4f25a0d7e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"x", "[", "4", "]"}], "/.", 
   RowBox[{"a", "\[Rule]", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{"b", "^", "2"}], "+", 
      RowBox[{"c", "^", "2"}]}], "]"}]}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{3.847457710138686*^9},
 CellLabel->"In[75]:=",ExpressionUUID->"a17b9de9-068b-4fd8-b0c7-daf19b800c0a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["c", "2"]}], ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.8474577105843163`*^9, 3.847472888212117*^9},
 CellLabel->"Out[75]=",ExpressionUUID->"34a936b4-0ef6-4bc2-bd8f-00c33def21f4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"x", "[", "19", "]"}], "/.", 
   RowBox[{"a", "\[Rule]", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{"b", "^", "2"}], "+", 
      RowBox[{"c", "^", "2"}]}], "]"}]}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.847457573118072*^9, 3.847457573533462*^9}, {
  3.8474576104745617`*^9, 3.8474576720282087`*^9}},
 CellLabel->"In[76]:=",ExpressionUUID->"3fbdba00-9c1a-4b98-8c7e-076f65f5dc5f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["c", "2"], " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}]]}], ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.847457573979464*^9, {3.8474576139939528`*^9, 3.847457673414345*^9}, 
   3.847472888220788*^9},
 CellLabel->"Out[76]=",ExpressionUUID->"462c2c49-f200-4c39-b125-69cd08af9b9c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "[", "25", "]"}], "/.", 
  RowBox[{"a", "\[Rule]", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"b", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8474572760657578`*^9, 3.847457330661118*^9}},
 CellLabel->"In[77]:=",ExpressionUUID->"94a8be1f-44d3-425d-a7ba-4273091a4b9f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["c", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}], ",", "0", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.8474572790745296`*^9, 3.847457297691936*^9}, 
   3.847457331214473*^9, 3.847472888302101*^9},
 CellLabel->"Out[77]=",ExpressionUUID->"2bd1ada7-32a1-47a4-87d0-0d4e71ff80c7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "[", "27", "]"}], "/.", 
  RowBox[{"a", "\[Rule]", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"b", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{3.847457350373281*^9},
 CellLabel->"In[78]:=",ExpressionUUID->"c837c307-f74a-472f-91d6-1586079abb67"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["c", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"c", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}]}], ",", "0", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.847457350865075*^9, 3.847472888397184*^9},
 CellLabel->"Out[78]=",ExpressionUUID->"487056d5-0347-4b79-ad32-55fe018ece87"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "[", "28", "]"}], "/.", 
  RowBox[{"a", "\[Rule]", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"b", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{3.84745736004557*^9},
 CellLabel->"In[79]:=",ExpressionUUID->"2e2bda83-2d81-4cd6-a2fd-93b622a0fc91"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["c", "2"], " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}]], " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"c", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}]}], ",", "0", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.84745736058829*^9, 3.8474728884053307`*^9},
 CellLabel->"Out[79]=",ExpressionUUID->"9b6711ee-f846-403d-a803-26148dd2142c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "[", "29", "]"}], "/.", 
  RowBox[{"a", "\[Rule]", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"b", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{3.847457368013544*^9},
 CellLabel->"In[80]:=",ExpressionUUID->"85d44100-6ffc-4ec8-aa57-066a04be2989"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["c", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "b"}], "-", "c", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"c", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}]}], ",", "0", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.8474573684313383`*^9, 3.84747288848531*^9},
 CellLabel->"Out[80]=",ExpressionUUID->"4e8e6d65-4a8d-4e82-b206-5238af9d24d5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "[", "33", "]"}], "/.", 
  RowBox[{"a", "\[Rule]", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"b", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.84745737722934*^9, 3.84745737750062*^9}},
 CellLabel->"In[81]:=",ExpressionUUID->"86f25be3-bdb0-4783-a06f-612e6979c625"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["c", "2"], " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "b"}], "-", "c", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}]}], ",", "0", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.847457377974634*^9, 3.847472888493779*^9},
 CellLabel->"Out[81]=",ExpressionUUID->"e2668828-49c0-4508-ab97-f9551076e070"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "[", "34", "]"}], "/.", 
  RowBox[{"a", "\[Rule]", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"b", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.847457385533395*^9, 3.847457385852806*^9}},
 CellLabel->"In[82]:=",ExpressionUUID->"47ac2f1f-db2c-4b34-9a14-0f9fa295f784"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["c", "2"], " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}]], " ", 
    RowBox[{"(", 
     RowBox[{"b", "-", "c", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "b"}], "+", "c", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}]}], ",", "0", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.847457386283004*^9, 3.847472888575953*^9},
 CellLabel->"Out[82]=",ExpressionUUID->"0c91c1a2-640a-49aa-85d1-4d98bb9433ad"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "[", "48", "]"}], "/.", 
  RowBox[{"a", "\[Rule]", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"b", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.847457393733295*^9, 3.8474573943972282`*^9}},
 CellLabel->"In[83]:=",ExpressionUUID->"c9c57200-cf0f-4bb2-bd05-761ca215782c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["b", "3"], " ", 
    SuperscriptBox["c", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["c", "3"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.847457394951024*^9, 3.8474728885846252`*^9},
 CellLabel->"Out[83]=",ExpressionUUID->"06f50b11-5cf6-4fd4-8808-5afcfcb2590e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "[", "63", "]"}], "/.", 
  RowBox[{"a", "\[Rule]", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"b", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.847457402645444*^9, 3.847457403420813*^9}},
 CellLabel->"In[84]:=",ExpressionUUID->"6d8c0b4b-e40d-4a00-8205-aea2f69bbe49"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", "b", " ", 
    SuperscriptBox["c", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["b", "2"], " ", "c"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8474574046824293`*^9, 3.847472888665625*^9},
 CellLabel->"Out[84]=",ExpressionUUID->"d3156280-b9fa-4637-baa8-3d282de291f6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "[", "69", "]"}], "/.", 
  RowBox[{"a", "\[Rule]", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"b", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8474574123416243`*^9, 3.847457412844874*^9}},
 CellLabel->"In[85]:=",ExpressionUUID->"1142eb20-cb5c-445a-a249-e403001f15f4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["c", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["b", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.847457413309802*^9, 3.847472888673176*^9},
 CellLabel->"Out[85]=",ExpressionUUID->"df347c8d-a476-421d-a114-6b5254a86e61"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "[", "71", "]"}], "/.", 
  RowBox[{"a", "\[Rule]", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"b", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.847457420557482*^9, 3.847457420740881*^9}},
 CellLabel->"In[86]:=",ExpressionUUID->"3de4bb40-277d-48ff-af7e-a561cc9b6c24"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["c", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"c", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["c", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.847457421558406*^9, 3.847472888757578*^9},
 CellLabel->"Out[86]=",ExpressionUUID->"125ca11f-0a61-4839-b596-6b36f6f90b5b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "[", "72", "]"}], "/.", 
  RowBox[{"a", "\[Rule]", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"b", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.847457428749761*^9, 3.847457429196912*^9}},
 CellLabel->"In[87]:=",ExpressionUUID->"5fabedbc-7426-41b3-a52d-8bde9a8d12f8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", "b", " ", 
    SuperscriptBox["c", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"c", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["b", "2"], " ", "c", " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8474574299002857`*^9, 3.847472888766361*^9},
 CellLabel->"Out[87]=",ExpressionUUID->"259ed9d6-5b5d-4255-afcc-5399b4198b82"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "[", "73", "]"}], "/.", 
  RowBox[{"a", "\[Rule]", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"b", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8474574372298403`*^9, 3.8474574375171537`*^9}},
 CellLabel->"In[88]:=",ExpressionUUID->"b57dd5aa-11be-45db-8b73-2eef923b0b01"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["c", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", "c", "-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"b", "-", "c", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"c", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["c", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", "c", "-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "b"}], "+", "c", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8474574383873873`*^9, 3.847472888851776*^9},
 CellLabel->"Out[88]=",ExpressionUUID->"bf3892f2-e0fc-4d17-86e0-94130eb04dd1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "[", "77", "]"}], "/.", 
  RowBox[{"a", "\[Rule]", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"b", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.847457446981639*^9, 3.847457447236842*^9}},
 CellLabel->"In[89]:=",ExpressionUUID->"b21cf3c4-10b6-4483-9fbf-b17c44b175d5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", "b", " ", 
    SuperscriptBox["c", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", "c", "-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"b", "-", "c", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["b", "2"], " ", "c", " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", "c", "-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "b"}], "+", "c", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.847457447864959*^9, 3.847472888860156*^9},
 CellLabel->"Out[89]=",ExpressionUUID->"4e738943-fdd8-45af-b664-eb2150bf1aa3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "[", "78", "]"}], "/.", 
  RowBox[{"a", "\[Rule]", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"b", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.847457452997553*^9, 3.8474574533009977`*^9}},
 CellLabel->"In[90]:=",ExpressionUUID->"4ed2f4ea-1eb0-498c-b281-1bab4b153840"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", "b", " ", 
    SuperscriptBox["c", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"b", "-", "c", "-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["b", "2"], " ", "c", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "b"}], "+", "c", "-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.847457454385168*^9, 3.847472888949387*^9},
 CellLabel->"Out[90]=",ExpressionUUID->"3cab56b1-833d-4ac2-866a-f8f02cb1756d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "[", "92", "]"}], "/.", 
  RowBox[{"a", "\[Rule]", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"b", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.847457461253565*^9, 3.847457461637312*^9}},
 CellLabel->"In[91]:=",ExpressionUUID->"03178bd1-f0c6-414b-9c14-cdf073d9651c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["b", "3"], " ", 
    SuperscriptBox["c", "3"]}], ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.847457462352612*^9, 3.847472888957189*^9},
 CellLabel->"Out[91]=",ExpressionUUID->"0028a4e6-de59-451b-bdfe-d55a8406f3ac"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
   RowBox[{"x", "[", "88", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"triang", "=", 
   RowBox[{
    RowBox[{"a", ">", "0"}], "&&", 
    RowBox[{"b", ">", "0"}], "&&", 
    RowBox[{"c", ">", "0"}], "&&", 
    RowBox[{
     RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
    RowBox[{
     RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
    RowBox[{
     RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"red", "=", 
   RowBox[{"Reduce", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"u", ">=", "0"}], "&&", 
          RowBox[{"v", ">=", "0"}], "&&", 
          RowBox[{"w", ">=", "0"}]}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"u", "<=", "0"}], "&&", 
          RowBox[{"v", "<=", "0"}], "&&", 
          RowBox[{"w", "<=", "0"}]}], ")"}]}], ")"}], "&&", "triang", "&&", 
      RowBox[{"a", ">=", "b", ">=", "c"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{"red", ",", 
   RowBox[{"triang", "&&", 
    RowBox[{"a", ">=", "b", ">=", "c"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.847465373685048*^9, 3.84746538034729*^9}, {
  3.847465428557613*^9, 3.8474654300198603`*^9}},
 CellLabel->"In[92]:=",ExpressionUUID->"0af2787d-78e0-4da3-a08d-160ec2335b16"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", "+", "c"}], "\[Equal]", 
  RowBox[{"2", " ", "b"}]}]], "Output",
 CellChangeTimes->{3.847465381786351*^9, 3.847465431174006*^9, 
  3.847472889039629*^9},
 CellLabel->"Out[95]=",ExpressionUUID->"8b7a0f96-c463-441c-9981-dd9371a0e7e7"]
}, Open  ]]
}, Closed]]
},
WindowSize->{808, 911},
WindowMargins->{{485, Automatic}, {Automatic, 65}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 1117, 19, 219, "Text",ExpressionUUID->"efc13449-d829-40e5-a520-40b6e62a69ca",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1700, 43, 190, 3, 67, "Section",ExpressionUUID->"ef755c8a-0e25-48d6-ac78-b33a61727a24"],
Cell[1893, 48, 162803, 4553, 4630, "Input",ExpressionUUID->"fbc3a809-de22-4d8c-9ba8-10a1a9fbf15d"]
}, Closed]],
Cell[CellGroupData[{
Cell[164733, 4606, 152, 3, 53, "Section",ExpressionUUID->"9f10404a-060d-4023-b1ed-cb0e490194b3"],
Cell[164888, 4611, 2563, 68, 241, "Input",ExpressionUUID->"302b605f-5435-4cad-ab15-5f5d143d5473"]
}, Closed]],
Cell[CellGroupData[{
Cell[167488, 4684, 368, 6, 53, "Section",ExpressionUUID->"53670d4d-5e61-49f3-9240-35a20dac235d"],
Cell[CellGroupData[{
Cell[167881, 4694, 3187, 85, 220, "Input",ExpressionUUID->"4ff0d522-c877-4f89-9f20-38d2b2f09705"],
Cell[171071, 4781, 957, 19, 70, "Print",ExpressionUUID->"29d2bbd5-a07d-4124-bb47-dd133a7f120f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[172065, 4805, 3091, 82, 199, "Input",ExpressionUUID->"eb9c273e-ce75-4348-953f-f3faff2723f5"],
Cell[175159, 4889, 1133, 22, 70, "Print",ExpressionUUID->"3d9ba66a-73c3-49c2-84c2-7ec3efcd8d3a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[176329, 4916, 3233, 85, 220, "Input",ExpressionUUID->"45a2478b-55f7-4a40-a39c-59b95e08b00b"],
Cell[179565, 5003, 846, 18, 70, "Print",ExpressionUUID->"8c3c6426-9f59-4b1b-827b-3089deee49e7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[180448, 5026, 3757, 94, 220, "Input",ExpressionUUID->"1104a228-c2a2-4394-bb1b-fdd7cd05016f"],
Cell[184208, 5122, 859, 16, 70, "Print",ExpressionUUID->"f46968ab-9752-4957-9bed-dab74fa9adde"]
}, Open  ]],
Cell[CellGroupData[{
Cell[185104, 5143, 477, 11, 30, "Input",ExpressionUUID->"b38dea24-40ed-4f46-9016-2c99621e3321"],
Cell[185584, 5156, 520, 12, 70, "Output",ExpressionUUID->"9ced83f1-d4e5-49bd-93a4-904dd252311e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[186141, 5173, 2717, 72, 199, "Input",ExpressionUUID->"169434d7-af20-4ebf-ad60-7a53cc156552"],
Cell[188861, 5247, 459, 11, 70, "Print",ExpressionUUID->"c78b2416-67f8-4e47-9ad0-1b99f0c5c5b2"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[189369, 5264, 432, 6, 53, "Section",ExpressionUUID->"31951922-4886-4bc8-80b6-3f2ea321db67"],
Cell[CellGroupData[{
Cell[189826, 5274, 1865, 57, 94, "Input",ExpressionUUID->"f109f0ec-c583-430f-8fc7-45995182aa3f"],
Cell[191694, 5333, 500, 13, 42, "Output",ExpressionUUID->"5f3db211-213c-42e7-8c18-237fbd04026c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[192231, 5351, 1745, 55, 94, "Input",ExpressionUUID->"46610b6c-e87e-4ef3-b836-a878f084f2a4"],
Cell[193979, 5408, 448, 12, 42, "Output",ExpressionUUID->"80b0cf67-6723-465f-8e79-d8bb06109129"]
}, Open  ]],
Cell[CellGroupData[{
Cell[194464, 5425, 1918, 59, 94, "Input",ExpressionUUID->"b138b86c-4bc2-4fed-9710-f76c290c993d"],
Cell[196385, 5486, 1679, 50, 203, "Output",ExpressionUUID->"2d264aee-3038-458f-ae1b-3481c29a5263"]
}, Open  ]],
Cell[CellGroupData[{
Cell[198101, 5541, 1768, 55, 94, "Input",ExpressionUUID->"cfaccd4b-a69c-4635-b330-623f574121fd"],
Cell[199872, 5598, 635, 19, 51, "Output",ExpressionUUID->"f37896d2-cc6a-478d-908d-d632fe60d985"]
}, Open  ]],
Cell[CellGroupData[{
Cell[200544, 5622, 1873, 58, 94, "Input",ExpressionUUID->"598c4e9a-257b-4c80-b541-c3a16059e478"],
Cell[202420, 5682, 2686, 86, 123, "Output",ExpressionUUID->"f72de78e-265c-4953-8db6-895c98ad5868"]
}, Open  ]],
Cell[CellGroupData[{
Cell[205143, 5773, 1796, 57, 94, "Input",ExpressionUUID->"f95975d6-3ac8-4c4e-9c78-851a834482ad"],
Cell[206942, 5832, 574, 16, 42, "Output",ExpressionUUID->"c9528949-71ae-4b23-b66d-a8c9126ea74b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[207553, 5853, 1798, 57, 94, "Input",ExpressionUUID->"98714d28-7377-40f7-9611-fc7ccfcd09c4"],
Cell[209354, 5912, 226, 3, 34, "Output",ExpressionUUID->"5373adef-942d-4a53-ba3c-0372ef414f0f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[209617, 5920, 1796, 57, 94, "Input",ExpressionUUID->"1764d3ac-2521-4e6b-9b83-a25f25526020"],
Cell[211416, 5979, 917, 26, 37, "Output",ExpressionUUID->"af7eab27-9867-4a21-9bcc-f595b9ebc35b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[212370, 6010, 1826, 57, 94, "Input",ExpressionUUID->"5dae103b-4ddc-4261-a5b0-8ddb5bad92c1"],
Cell[214199, 6069, 12050, 342, 548, "Output",ExpressionUUID->"a57c38b8-13d8-4456-bbd2-b87c79422cc8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[226286, 6416, 1796, 57, 94, "Input",ExpressionUUID->"717ae2a3-4a3d-4243-a6bb-2d0ddef61f3e"],
Cell[228085, 6475, 445, 12, 42, "Output",ExpressionUUID->"6d0e6bf7-655f-4464-a90f-730d9fb74c1b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[228567, 6492, 1822, 57, 94, "Input",ExpressionUUID->"3cd0760c-916a-45e4-90bd-ad83c466494c"],
Cell[230392, 6551, 975, 28, 37, "Output",ExpressionUUID->"eac09268-ab51-42a6-a577-50a037875183"]
}, Open  ]],
Cell[CellGroupData[{
Cell[231404, 6584, 2078, 64, 115, "Input",ExpressionUUID->"ed19ea19-474b-46c2-b3bd-864cec0ef999"],
Cell[233485, 6650, 273, 4, 34, "Output",ExpressionUUID->"716684d4-8641-44c1-99d3-9e6e4e7aa001"]
}, Open  ]],
Cell[CellGroupData[{
Cell[233795, 6659, 2998, 80, 199, "Input",ExpressionUUID->"9d133a8a-d190-48d1-a81c-7f53ad4ec37d"],
Cell[CellGroupData[{
Cell[236818, 6743, 511, 11, 24, "Print",ExpressionUUID->"95dc199c-b6ab-4de6-a346-dd2ae4fc45d7"],
Cell[237332, 6756, 509, 11, 24, "Print",ExpressionUUID->"fbaec50d-0de9-4ac9-8f89-ffa2cb919a23"],
Cell[237844, 6769, 711, 18, 30, "Print",ExpressionUUID->"32aad0cf-256d-4c05-871c-d8f1b3b075e2"],
Cell[238558, 6789, 711, 18, 30, "Print",ExpressionUUID->"d924a532-b68c-486e-b0ae-f29c12bd5a97"],
Cell[239272, 6809, 2082, 58, 45, "Print",ExpressionUUID->"53825a70-a123-4cc6-9c82-3e83ebaf15d8"],
Cell[241357, 6869, 509, 11, 24, "Print",ExpressionUUID->"922dc36f-e565-4790-85e8-f62622771bf3"],
Cell[241869, 6882, 509, 11, 24, "Print",ExpressionUUID->"ba8af413-f130-4084-a3e5-7f3d3c35d724"],
Cell[242381, 6895, 508, 11, 24, "Print",ExpressionUUID->"76a743b7-ea7a-4e3d-9133-5dc95e842456"],
Cell[242892, 6908, 509, 11, 24, "Print",ExpressionUUID->"a0706db5-47a7-4e87-8b18-0bd1130cfe50"],
Cell[243404, 6921, 513, 11, 24, "Print",ExpressionUUID->"9bea2a99-2355-498b-86bc-b6ecab092b05"],
Cell[243920, 6934, 511, 11, 24, "Print",ExpressionUUID->"945da048-195c-4c4d-b0d1-be03d61dcd49"],
Cell[244434, 6947, 513, 11, 24, "Print",ExpressionUUID->"40b29e9e-8b23-420a-9c31-c988ff4d3490"],
Cell[244950, 6960, 843, 22, 30, "Print",ExpressionUUID->"0974c789-acd3-422d-863c-769adbd11a87"],
Cell[245796, 6984, 2074, 58, 38, "Print",ExpressionUUID->"2765b605-940f-49c6-b047-4c28937aa056"],
Cell[247873, 7044, 842, 22, 30, "Print",ExpressionUUID->"d3c76024-9a85-4f1f-8302-85a109a1fa78"],
Cell[248718, 7068, 513, 11, 24, "Print",ExpressionUUID->"32256f34-8ddc-412c-a6dd-cfa310a07ec1"],
Cell[249234, 7081, 1296, 35, 27, "Print",ExpressionUUID->"4d5567e3-cfce-4985-9c6a-691a5b4dedd5"],
Cell[250533, 7118, 9433, 254, 182, "Print",ExpressionUUID->"1ea07a1c-95a0-4d75-a4ab-adbca719a62d"],
Cell[259969, 7374, 713, 18, 30, "Print",ExpressionUUID->"6a5b3305-c2ea-4a23-b183-03cccab55d17"],
Cell[260685, 7394, 1372, 38, 27, "Print",ExpressionUUID->"80d17494-8812-418a-b7c2-0048b18ceb30"],
Cell[262060, 7434, 511, 11, 24, "Print",ExpressionUUID->"8f45238f-9539-4eb1-a8af-07964447f67a"],
Cell[262574, 7447, 857, 23, 27, "Print",ExpressionUUID->"1feaa9ed-7dbf-48a4-90bc-fae5f58a4ac4"],
Cell[263434, 7472, 515, 11, 24, "Print",ExpressionUUID->"c7f28b05-e239-42bc-ae29-7a10c4e25a62"],
Cell[263952, 7485, 11443, 309, 343, "Print",ExpressionUUID->"9e4404ec-30e7-4a1e-9514-a5fba8d34bc9"],
Cell[275398, 7796, 715, 18, 30, "Print",ExpressionUUID->"0ae83d76-f572-4758-ace5-1fceeef91877"],
Cell[276116, 7816, 16070, 400, 269, "Print",ExpressionUUID->"872b4f66-cc83-4bae-95b8-396fa1a632bf"],
Cell[292189, 8218, 713, 18, 30, "Print",ExpressionUUID->"32bce194-db25-466f-b891-d6e0e6d825fd"],
Cell[292905, 8238, 713, 18, 30, "Print",ExpressionUUID->"d2c1afaf-0342-4c1b-b0ee-f217d9a8cd41"],
Cell[293621, 8258, 713, 18, 30, "Print",ExpressionUUID->"5795bb82-7053-40b1-996d-f2c24ad56305"],
Cell[294337, 8278, 513, 11, 24, "Print",ExpressionUUID->"863a3a34-9981-4c59-a28e-8fef425e0ca0"],
Cell[294853, 8291, 511, 11, 24, "Print",ExpressionUUID->"78eccc98-a3d7-41e7-ae50-28de5af8960e"],
Cell[295367, 8304, 511, 11, 24, "Print",ExpressionUUID->"5d51f034-e669-4770-acd7-5d678aa6db13"],
Cell[295881, 8317, 713, 18, 30, "Print",ExpressionUUID->"57593b4e-a5a4-422f-8bd9-e13ab244b55d"],
Cell[296597, 8337, 715, 18, 30, "Print",ExpressionUUID->"6b53b647-0e7e-40c1-a396-7a478913aa15"],
Cell[297315, 8357, 843, 22, 30, "Print",ExpressionUUID->"5baf1c92-d316-4b59-b3e3-4765df10905e"],
Cell[298161, 8381, 513, 11, 24, "Print",ExpressionUUID->"f81abaa4-a5c3-4c14-a6c7-c6ba22ba3a55"],
Cell[298677, 8394, 513, 11, 24, "Print",ExpressionUUID->"c975cc1b-4b17-4848-92d4-c2f79362d11d"],
Cell[299193, 8407, 511, 11, 24, "Print",ExpressionUUID->"c1546f40-73c2-44bc-8604-42fd30606d4c"],
Cell[299707, 8420, 511, 11, 24, "Print",ExpressionUUID->"8d72e4bb-8017-48d5-9e76-55a4ee434a1c"],
Cell[300221, 8433, 1573, 41, 27, "Print",ExpressionUUID->"6d1cd5b4-dbb2-4256-80fd-9bbab419b24b"],
Cell[301797, 8476, 511, 11, 24, "Print",ExpressionUUID->"3a0fcb14-d82a-484d-a100-aa122712e89f"],
Cell[302311, 8489, 511, 11, 24, "Print",ExpressionUUID->"49f1a18b-05b4-40db-a300-54de0879a4b3"],
Cell[302825, 8502, 2443, 69, 64, "Print",ExpressionUUID->"2367a51d-51c2-40f6-9eaf-be75da0bf89e"],
Cell[305271, 8573, 513, 11, 24, "Print",ExpressionUUID->"5c2c51c3-492e-42dc-9224-1e7c61e75dbd"],
Cell[305787, 8586, 510, 11, 24, "Print",ExpressionUUID->"5e8f9b6b-2ec9-4995-b8c7-d4b96d4f8f34"],
Cell[306300, 8599, 10900, 286, 296, "Print",ExpressionUUID->"73e07da2-4c57-4cc7-9a4a-be07a117f391"],
Cell[317203, 8887, 6285, 168, 116, "Print",ExpressionUUID->"afa679bd-efb5-4626-a609-fdda81ef8111"],
Cell[323491, 9057, 713, 18, 30, "Print",ExpressionUUID->"a8c37479-715a-4de7-bc35-a83b8618ee2e"],
Cell[324207, 9077, 11057, 297, 227, "Print",ExpressionUUID->"ca68b6c9-22d5-48f3-92b6-fd48fbeaed80"],
Cell[335267, 9376, 846, 22, 30, "Print",ExpressionUUID->"d832884a-a632-4be5-acfa-cf558ae1ad41"],
Cell[336116, 9400, 2086, 58, 45, "Print",ExpressionUUID->"fdf66f9b-fe39-48aa-a7d9-58d60cf36b83"],
Cell[338205, 9460, 13211, 349, 438, "Print",ExpressionUUID->"1bc49ffc-2d60-4481-95c7-cac0d06e49a6"],
Cell[351419, 9811, 2355, 64, 65, "Print",ExpressionUUID->"a58a8b55-3e47-4391-a13d-c196241fafda"],
Cell[353777, 9877, 3569, 98, 123, "Print",ExpressionUUID->"ff5d1716-f883-4b55-a465-cfbe69ffb06c"],
Cell[357349, 9977, 511, 11, 24, "Print",ExpressionUUID->"3ab0b2cd-81c7-48fe-b439-f54953c11abb"],
Cell[357863, 9990, 511, 11, 24, "Print",ExpressionUUID->"9fbd59aa-4d03-480d-8754-39626b32637c"],
Cell[358377, 10003, 513, 11, 24, "Print",ExpressionUUID->"a36d8a82-cb8c-4f67-b42c-957fe91c38ec"],
Cell[358893, 10016, 511, 11, 24, "Print",ExpressionUUID->"8fbf5758-ed61-4bd6-b0dc-4d4af9ed9a2e"],
Cell[359407, 10029, 511, 11, 24, "Print",ExpressionUUID->"d868e764-2f54-45df-a7d6-37855950fca7"],
Cell[359921, 10042, 511, 11, 24, "Print",ExpressionUUID->"8ca2fd98-9263-4298-8417-03444359585d"],
Cell[360435, 10055, 1697, 46, 34, "Print",ExpressionUUID->"440bc8d8-c6e9-4508-90e9-f3ee2a621851"],
Cell[362135, 10103, 8910, 242, 197, "Print",ExpressionUUID->"6addf379-bf82-4f86-b26a-c9f6ba1665bc"],
Cell[371048, 10347, 713, 18, 30, "Print",ExpressionUUID->"d66474ac-c324-4d3e-b693-0215def55a22"],
Cell[371764, 10367, 1372, 38, 27, "Print",ExpressionUUID->"12623f3d-5324-4e61-95f0-d1229be5fbb8"],
Cell[373139, 10407, 511, 11, 24, "Print",ExpressionUUID->"e0c7077d-93a7-40d6-b529-75585bb5b982"],
Cell[373653, 10420, 857, 23, 27, "Print",ExpressionUUID->"e6d694a0-7564-4f81-b1e7-59bdf62432fa"],
Cell[374513, 10445, 2906, 82, 49, "Print",ExpressionUUID->"fc0bfbfc-b41c-4f0b-8652-ab6953b008da"],
Cell[377422, 10529, 11187, 296, 318, "Print",ExpressionUUID->"cd569dd6-3e14-4344-99dd-9940def32d9b"],
Cell[388612, 10827, 713, 18, 30, "Print",ExpressionUUID->"f0e492bd-e61b-4f54-bedd-844241010833"],
Cell[389328, 10847, 31715, 801, 532, "Print",ExpressionUUID->"77a1297b-e117-49c4-9aeb-768efd83c32a"],
Cell[421046, 11650, 713, 18, 30, "Print",ExpressionUUID->"87365d43-e8e1-44bb-a49a-be1f491d7d24"],
Cell[421762, 11670, 713, 18, 30, "Print",ExpressionUUID->"390c9cc2-910c-4bbb-9141-be531d94c5a1"],
Cell[422478, 11690, 712, 18, 30, "Print",ExpressionUUID->"436dda17-a588-4238-b6c8-5067ef0b0eb9"],
Cell[423193, 11710, 3575, 97, 72, "Print",ExpressionUUID->"e946966f-18db-4a4f-b3ab-c044c8e15388"],
Cell[426771, 11809, 511, 11, 24, "Print",ExpressionUUID->"6d5d730b-ad52-42dc-b1c0-e35da0ebe5d9"],
Cell[427285, 11822, 513, 11, 24, "Print",ExpressionUUID->"07f92dda-89c6-48f8-ba7f-ce60743a986c"],
Cell[427801, 11835, 715, 18, 30, "Print",ExpressionUUID->"44d918ae-7bbe-4a2d-8ff2-8816a724a359"],
Cell[428519, 11855, 713, 18, 30, "Print",ExpressionUUID->"4a516b36-5b31-474d-9167-02d73cf83c2c"],
Cell[429235, 11875, 845, 22, 30, "Print",ExpressionUUID->"9113327b-41c6-478b-bfd6-1427c3e2d45e"],
Cell[430083, 11899, 2074, 58, 38, "Print",ExpressionUUID->"152ff3c2-8cd2-4dad-9791-64721babaab0"],
Cell[432160, 11959, 511, 11, 24, "Print",ExpressionUUID->"76abc5db-2a45-4311-8707-635651d27900"],
Cell[432674, 11972, 511, 11, 24, "Print",ExpressionUUID->"6129e7dc-9f40-470f-81ab-b09373965ea8"],
Cell[433188, 11985, 511, 11, 24, "Print",ExpressionUUID->"118c1c1d-e592-4fb2-aec5-b93d2b46effa"],
Cell[433702, 11998, 1573, 41, 27, "Print",ExpressionUUID->"a42aeca7-d706-449f-bddb-9575339e14f6"],
Cell[435278, 12041, 513, 11, 24, "Print",ExpressionUUID->"664079a6-1506-48e9-9365-45fe333e0f8e"],
Cell[435794, 12054, 513, 11, 24, "Print",ExpressionUUID->"a77cc4ae-a293-47b6-a789-92b569c51d76"],
Cell[436310, 12067, 2443, 69, 64, "Print",ExpressionUUID->"3e4eaf6e-550d-4355-a4c7-6a4a9ab6372e"],
Cell[438756, 12138, 1364, 38, 24, "Print",ExpressionUUID->"a554723e-d1e8-4f38-8dde-cc20d70fc8d7"],
Cell[440123, 12178, 511, 11, 24, "Print",ExpressionUUID->"6e5e2df8-5ec6-45cf-abe3-8e81df6f3247"],
Cell[440637, 12191, 18677, 482, 532, "Print",ExpressionUUID->"a41a95b8-6480-4e7d-b9fa-54359a0f4575"],
Cell[459317, 12675, 7821, 211, 138, "Print",ExpressionUUID->"bd8dfe33-ab5b-4a1c-8b2d-6797365a6e43"],
Cell[467141, 12888, 713, 18, 30, "Print",ExpressionUUID->"4c130c9a-1d6e-4082-ab4a-9047f089671c"],
Cell[467857, 12908, 26712, 710, 755, "Print",ExpressionUUID->"7d79df75-d217-490b-ad67-db59297cc874"],
Cell[494572, 13620, 2451, 69, 73, "Print",ExpressionUUID->"5ed444a5-69fd-4490-ba06-1376311a8b4a"],
Cell[497026, 13691, 3569, 98, 123, "Print",ExpressionUUID->"f2c86484-3c0f-49a4-90f3-d047d49ad326"],
Cell[500598, 13791, 24407, 664, 788, "Print",ExpressionUUID->"cd97ee47-65af-4b83-936a-b629c8de2fa7"],
Cell[525008, 14457, 3866, 108, 97, "Print",ExpressionUUID->"f6109210-2356-488b-9c24-33293306c387"],
Cell[528877, 14567, 3162, 87, 84, "Print",ExpressionUUID->"597cf909-f32b-4b95-91ba-552a5c17841c"],
Cell[532042, 14656, 687, 16, 24, "Print",ExpressionUUID->"40bfe940-af9e-4f4b-9522-45965b561d2e"],
Cell[532732, 14674, 690, 16, 24, "Print",ExpressionUUID->"d48bf212-58fd-4e3c-a05f-c6a4020dddc8"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[533471, 14696, 1409, 42, 94, "Input",ExpressionUUID->"faeb4f4c-b9bf-4e73-b248-f80d8d01448c"],
Cell[534883, 14740, 2148, 78, 132, "Output",ExpressionUUID->"4de6b962-8e7f-44e6-9527-46df7d91c744"]
}, Open  ]],
Cell[CellGroupData[{
Cell[537068, 14823, 2132, 66, 115, "Input",ExpressionUUID->"2e0cc489-f98a-40c9-8a4e-d4c12c6f382b"],
Cell[539203, 14891, 406, 9, 34, "Output",ExpressionUUID->"34b5d89c-580b-4e1d-9bef-c93c3ecc535a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[539646, 14905, 1790, 53, 115, "Input",ExpressionUUID->"c0762316-a112-49a8-9065-f9de213fdac6"],
Cell[541439, 14960, 521, 14, 52, "Output",ExpressionUUID->"b5b80419-2d9c-4958-ae2a-de3252b15b33"]
}, Open  ]],
Cell[CellGroupData[{
Cell[541997, 14979, 547, 16, 30, "Input",ExpressionUUID->"68cc9844-0c52-4c79-9c06-40bfc334faae"],
Cell[542547, 14997, 1314, 43, 50, "Output",ExpressionUUID->"b3414028-b3a7-49d7-b4ff-f44919f99dde"]
}, Open  ]],
Cell[CellGroupData[{
Cell[543898, 15045, 596, 17, 30, "Input",ExpressionUUID->"f66f7ce8-78d7-4364-9dfb-22b75b8fd6e5"],
Cell[544497, 15064, 1561, 52, 50, "Output",ExpressionUUID->"4db20855-08b1-4699-8f8b-253e2f5b9b5d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[546095, 15121, 547, 16, 30, "Input",ExpressionUUID->"d22c2c4d-adec-4ea0-8139-3eed2bf0fb07"],
Cell[546645, 15139, 682, 21, 50, "Output",ExpressionUUID->"84dd8487-13f0-4a69-a3cf-ea503c78c6b2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[547364, 15165, 374, 10, 30, "Input",ExpressionUUID->"f23fa17f-b3e2-4fcf-b441-c7086d7cab6f"],
Cell[547741, 15177, 438, 12, 37, "Output",ExpressionUUID->"d4549bb3-5475-4c06-90b7-62b4f25a0d7e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[548216, 15194, 374, 10, 30, "Input",ExpressionUUID->"a17b9de9-068b-4fd8-b0c7-daf19b800c0a"],
Cell[548593, 15206, 314, 7, 37, "Output",ExpressionUUID->"34a936b4-0ef6-4bc2-bd8f-00c33def21f4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[548944, 15218, 452, 11, 30, "Input",ExpressionUUID->"3fbdba00-9c1a-4b98-8c7e-076f65f5dc5f"],
Cell[549399, 15231, 473, 13, 46, "Output",ExpressionUUID->"462c2c49-f200-4c39-b125-69cd08af9b9c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[549909, 15249, 364, 9, 30, "Input",ExpressionUUID->"94a8be1f-44d3-425d-a7ba-4273091a4b9f"],
Cell[550276, 15260, 484, 13, 37, "Output",ExpressionUUID->"2bd1ada7-32a1-47a4-87d0-0d4e71ff80c7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[550797, 15278, 338, 9, 30, "Input",ExpressionUUID->"c837c307-f74a-472f-91d6-1586079abb67"],
Cell[551138, 15289, 645, 20, 49, "Output",ExpressionUUID->"487056d5-0347-4b79-ad32-55fe018ece87"]
}, Open  ]],
Cell[CellGroupData[{
Cell[551820, 15314, 337, 9, 30, "Input",ExpressionUUID->"2e2bda83-2d81-4cd6-a2fd-93b622a0fc91"],
Cell[552160, 15325, 752, 24, 49, "Output",ExpressionUUID->"9b6711ee-f846-403d-a803-26148dd2142c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[552949, 15354, 338, 9, 30, "Input",ExpressionUUID->"85d44100-6ffc-4ec8-aa57-066a04be2989"],
Cell[553290, 15365, 843, 27, 49, "Output",ExpressionUUID->"4e8e6d65-4a8d-4e82-b206-5238af9d24d5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[554170, 15397, 360, 9, 30, "Input",ExpressionUUID->"86f25be3-bdb0-4783-a06f-612e6979c625"],
Cell[554533, 15408, 618, 19, 49, "Output",ExpressionUUID->"e2668828-49c0-4508-ab97-f9551076e070"]
}, Open  ]],
Cell[CellGroupData[{
Cell[555188, 15432, 362, 9, 30, "Input",ExpressionUUID->"47ac2f1f-db2c-4b34-9a14-0f9fa295f784"],
Cell[555553, 15443, 793, 25, 49, "Output",ExpressionUUID->"0c91c1a2-640a-49aa-85d1-4d98bb9433ad"]
}, Open  ]],
Cell[CellGroupData[{
Cell[556383, 15473, 364, 9, 30, "Input",ExpressionUUID->"c9c57200-cf0f-4bb2-bd05-761ca215782c"],
Cell[556750, 15484, 440, 12, 37, "Output",ExpressionUUID->"06f50b11-5cf6-4fd4-8808-5afcfcb2590e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[557227, 15501, 362, 9, 30, "Input",ExpressionUUID->"6d8c0b4b-e40d-4a00-8205-aea2f69bbe49"],
Cell[557592, 15512, 388, 10, 37, "Output",ExpressionUUID->"d3156280-b9fa-4637-baa8-3d282de291f6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[558017, 15527, 364, 9, 30, "Input",ExpressionUUID->"1142eb20-cb5c-445a-a249-e403001f15f4"],
Cell[558384, 15538, 366, 10, 37, "Output",ExpressionUUID->"df347c8d-a476-421d-a114-6b5254a86e61"]
}, Open  ]],
Cell[CellGroupData[{
Cell[558787, 15553, 362, 9, 30, "Input",ExpressionUUID->"3de4bb40-277d-48ff-af7e-a561cc9b6c24"],
Cell[559152, 15564, 768, 24, 49, "Output",ExpressionUUID->"125ca11f-0a61-4839-b596-6b36f6f90b5b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[559957, 15593, 362, 9, 30, "Input",ExpressionUUID->"5fabedbc-7426-41b3-a52d-8bde9a8d12f8"],
Cell[560322, 15604, 718, 22, 49, "Output",ExpressionUUID->"259ed9d6-5b5d-4255-afcc-5399b4198b82"]
}, Open  ]],
Cell[CellGroupData[{
Cell[561077, 15631, 366, 9, 30, "Input",ExpressionUUID->"b57dd5aa-11be-45db-8b73-2eef923b0b01"],
Cell[561446, 15642, 1492, 49, 86, "Output",ExpressionUUID->"bf3892f2-e0fc-4d17-86e0-94130eb04dd1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[562975, 15696, 362, 9, 30, "Input",ExpressionUUID->"b21cf3c4-10b6-4483-9fbf-b17c44b175d5"],
Cell[563340, 15707, 1108, 35, 49, "Output",ExpressionUUID->"4e738943-fdd8-45af-b664-eb2150bf1aa3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[564485, 15747, 364, 9, 30, "Input",ExpressionUUID->"4ed2f4ea-1eb0-498c-b281-1bab4b153840"],
Cell[564852, 15758, 758, 23, 49, "Output",ExpressionUUID->"3cab56b1-833d-4ac2-866a-f8f02cb1756d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[565647, 15786, 362, 9, 30, "Input",ExpressionUUID->"03178bd1-f0c6-414b-9c14-cdf073d9651c"],
Cell[566012, 15797, 312, 7, 37, "Output",ExpressionUUID->"0028a4e6-de59-451b-bdfe-d55a8406f3ac"]
}, Open  ]],
Cell[CellGroupData[{
Cell[566361, 15809, 1548, 45, 115, "Input",ExpressionUUID->"0af2787d-78e0-4da3-a08d-160ec2335b16"],
Cell[567912, 15856, 271, 6, 34, "Output",ExpressionUUID->"8b7a0f96-c463-441c-9981-dd9371a0e7e7"]
}, Open  ]]
}, Closed]]
}
]
*)

